@@ -11,7 +11,7 @@ import ldap
 import logging
 import pytest
 from random import sample
-from ldap.controls import SimplePagedResultsControl
+from ldap.controls import SimplePagedResultsControl, GetEffectiveRightsControl
 from lib389 import DirSrv, Entry
 from lib389._constants import *
 from lib389.properties import *
@@ -19,7 +19,13 @@ from lib389.tasks import *
 from lib389.utils import *
 from sss_control import SSSRequestControl
 
-logging.getLogger(__name__).setLevel(logging.DEBUG)
+DEBUGGING = False
+
+if DEBUGGING:
+    logging.getLogger(__name__).setLevel(logging.DEBUG)
+else:
+    logging.getLogger(__name__).setLevel(logging.INFO)
+
 log = logging.getLogger(__name__)
 
 TEST_USER_NAME = 'simplepaged_test'
@@ -227,7 +233,13 @@ def paged_search(topology, suffix, controls, search_flt, searchreq_attrlist):
     pages = 0
     pctrls = []
     all_results = []
-    req_ctrl = controls[0]
+    req_pr_ctrl = controls[0]
+    log.info('Running simple paged result search with - '
+             'search suffix: {}; filter: {}; attr list {}; '
+             'page_size = {}; controls: {}.'.format(suffix, search_flt,
+                                                    searchreq_attrlist,
+                                                    req_pr_ctrl.size,
+                                                    str(controls)))
     msgid = topology.standalone.search_ext(suffix,
                                            ldap.SCOPE_SUBTREE,
                                            search_flt,
@@ -236,6 +248,7 @@ def paged_search(topology, suffix, controls, search_flt, searchreq_attrlist):
     while True:
         log.info('Getting page %d' % (pages,))
         rtype, rdata, rmsgid, rctrls = topology.standalone.result3(msgid)
+        log.debug('Data: {}'.format(rdata))
         all_results.extend(rdata)
         pages += 1
         pctrls = [
@@ -247,7 +260,8 @@ def paged_search(topology, suffix, controls, search_flt, searchreq_attrlist):
         if pctrls:
             if pctrls[0].cookie:
                 # Copy cookie from response control to request control
-                req_ctrl.cookie = pctrls[0].cookie
+                log.debug('Cookie: {}'.format(pctrls[0].cookie))
+                req_pr_ctrl.cookie = pctrls[0].cookie
                 msgid = topology.standalone.search_ext(suffix,
                                                        ldap.SCOPE_SUBTREE,
                                                        search_flt,
@@ -268,16 +282,15 @@ def test_search_success(topology, test_user, page_size, users_num):
     """Verify that search with a simple paged results control
     returns all entries it should without errors.
 
-    @Feature: Simple paged results
+    :Feature: Simple paged results
 
-    @Setup: Standalone instance, test user for binding,
-    variated number of users for the search base
+    :Setup: Standalone instance, test user for binding,
+            variated number of users for the search base
 
-    @Steps:
-    1. Bind as test user
-    2. Search through added users with a simple paged control
+    :Steps: 1. Bind as test user
+            2. Search through added users with a simple paged control
 
-    @Assert: All users should be found
+    :Assert: All users should be found
     """
 
     users_list = add_users(topology, users_num, DEFAULT_SUFFIX)
@@ -288,7 +301,6 @@ def test_search_success(topology, test_user, page_size, users_num):
         log.info('Set user bind')
         topology.standalone.simple_bind_s(TEST_USER_DN, TEST_USER_PWD)
 
-        log.info('Create simple paged results control instance')
         req_ctrl = SimplePagedResultsControl(True, size=page_size, cookie='')
 
         all_results = paged_search(topology, DEFAULT_SUFFIX, [req_ctrl],
@@ -297,11 +309,12 @@ def test_search_success(topology, test_user, page_size, users_num):
         log.info('%d results' % len(all_results))
         assert len(all_results) == len(users_list)
     finally:
-        log.info('Set Directory Manager bind back')
+        log.info('Set Directory Manager bind back (test_search_success)')
         topology.standalone.simple_bind_s(DN_DM, PASSWORD)
         del_users(topology, users_list)
 
 
+
 @pytest.mark.parametrize("page_size,users_num,suffix,attr_name,attr_value,expected_err", [
                         (50, 200, 'cn=config,%s' % DN_LDBM, 'nsslapd-idlistscanlimit', '100',
                          ldap.UNWILLING_TO_PERFORM),
@@ -319,18 +332,17 @@ def test_search_limits_fail(topology, test_user, page_size, users_num,
     throws expected exceptoins when corresponding limits are
     exceeded.
 
-    @Feature: Simple paged results
+    :Feature: Simple paged results
 
-    @Setup: Standalone instance, test user for binding,
-    variated number of users for the search base
+    :Setup: Standalone instance, test user for binding,
+            variated number of users for the search base
 
-    @Steps:
-    1. Bind as test user
-    2. Set limit attribute to the value that will cause
-    an expected exception
-    3. Search through added users with a simple paged control
+    :Steps: 1. Bind as test user
+            2. Set limit attribute to the value that will cause
+               an expected exception
+            3. Search through added users with a simple paged control
 
-    @Assert: Should fail with appropriate exception
+    :Assert: Should fail with appropriate exception
     """
 
     users_list = add_users(topology, users_num, DEFAULT_SUFFIX)
@@ -397,7 +409,7 @@ def test_search_limits_fail(topology, test_user, page_size, users_num,
         if expected_err == ldap.UNAVAILABLE_CRITICAL_EXTENSION:
             topology.standalone.open()
 
-        log.info('Set Directory Manager bind back')
+        log.info('Set Directory Manager bind back (test_search_limits_fail)')
         topology.standalone.simple_bind_s(DN_DM, PASSWORD)
         del_users(topology, users_list)
         change_conf_attr(topology, suffix, attr_name, attr_value_bck)
@@ -408,17 +420,16 @@ def test_search_sort_success(topology, test_user):
     and a server side sort control returns all entries
     it should without errors.
 
-    @Feature: Simple paged results
+    :Feature: Simple paged results
 
-    @Setup: Standalone instance, test user for binding,
-    variated number of users for the search base
+    :Setup: Standalone instance, test user for binding,
+            variated number of users for the search base
 
-    @Steps:
-    1. Bind as test user
-    2. Search through added users with a simple paged control
-    and a server side sort control
+    :Steps: 1. Bind as test user
+            2. Search through added users with a simple paged control
+               and a server side sort control
 
-    @Assert: All users should be found and sorted
+    :Assert: All users should be found and sorted
     """
 
     users_num = 50
@@ -431,7 +442,6 @@ def test_search_sort_success(topology, test_user):
         log.info('Set user bind')
         topology.standalone.simple_bind_s(TEST_USER_DN, TEST_USER_PWD)
 
-        log.info('Create simple paged results control instance')
         req_ctrl = SimplePagedResultsControl(True, size=page_size, cookie='')
         sort_ctrl = SSSRequestControl(True, ['sn'])
 
@@ -447,7 +457,7 @@ def test_search_sort_success(topology, test_user):
         log.info('Assert that list is sorted')
         assert all(r_nums[i] <= r_nums[i+1] for i in range(len(r_nums)-1))
     finally:
-        log.info('Set Directory Manager bind back')
+        log.info('Set Directory Manager bind back (test_search_sort_success)')
         topology.standalone.simple_bind_s(DN_DM, PASSWORD)
         del_users(topology, users_list)
 
@@ -456,18 +466,17 @@ def test_search_abandon(topology, test_user):
     """Verify that search with simple paged results control
     can be abandon
 
-    @Feature: Simple paged results
+    :Feature: Simple paged results
 
-    @Setup: Standalone instance, test user for binding,
-    variated number of users for the search base
+    :Setup: Standalone instance, test user for binding,
+            variated number of users for the search base
 
-    @Steps:
-    1. Bind as test user
-    2. Search through added users with a simple paged control
-    3. Abandon the search
+    :Steps: 1. Bind as test user
+            2. Search through added users with a simple paged control
+            3. Abandon the search
 
-    @Assert: It will throw an ldap.TIMEOUT exception, while trying
-    to get the rest of the search results
+    :Assert: It will throw an ldap.TIMEOUT exception, while trying
+             to get the rest of the search results
     """
 
     users_num = 10
@@ -497,7 +506,7 @@ def test_search_abandon(topology, test_user):
         with pytest.raises(ldap.TIMEOUT):
             topology.standalone.result3(msgid, timeout=5)
     finally:
-        log.info('Set Directory Manager bind back')
+        log.info('Set Directory Manager bind back (test_search_abandon)')
         topology.standalone.simple_bind_s(DN_DM, PASSWORD)
         del_users(topology, users_list)
 
@@ -507,19 +516,18 @@ def test_search_with_timelimit(topology, test_user):
     to completion, each with a timelimit, it wouldn't fail, if we sleep
     for a time more than the timelimit.
 
-    @Feature: Simple paged results
+    :Feature: Simple paged results
 
-    @Setup: Standalone instance, test user for binding,
-    variated number of users for the search base
+    :Setup: Standalone instance, test user for binding,
+            variated number of users for the search base
 
-    @Steps:
-    1. Bind as test user
-    2. Search through added users with a simple paged control
-    and timelimit set to 5
-    3. When the returned cookie is empty, wait 10 seconds
-    4. Perform steps 2 and 3 three times in a row
+    :Steps: 1. Bind as test user
+            2. Search through added users with a simple paged control
+               and timelimit set to 5
+            3. When the returned cookie is empty, wait 10 seconds
+            4. Perform steps 2 and 3 three times in a row
 
-    @Assert: No error happens
+    :Assert: No error happens
     """
 
     users_num = 100
@@ -576,34 +584,33 @@ def test_search_with_timelimit(topology, test_user):
                 else:
                     break
     finally:
-        log.info('Set Directory Manager bind back')
+        log.info('Set Directory Manager bind back (test_search_with_timelimit)')
         topology.standalone.simple_bind_s(DN_DM, PASSWORD)
         del_users(topology, users_list)
 
 
 @pytest.mark.parametrize('aci_subject',
                          ('dns = "localhost.localdomain"',
-                          'ip = "::1"'))
+                          'ip = "::1" or ip = "127.0.0.1"'))
 def test_search_dns_ip_aci(topology, test_user, aci_subject):
     """Verify that after performing multiple simple paged searches
     to completion on the suffix with DNS or IP based ACI
 
-    @Feature: Simple paged results
+    :Feature: Simple paged results
 
-    @Setup: Standalone instance, test user for binding,
-    variated number of users for the search base
+    :Setup: Standalone instance, test user for binding,
+            variated number of users for the search base
 
-    @Steps:
-    1. Back up and remove all previous ACI from suffix
-    2. Add an anonymous ACI for DNS check
-    3. Bind as test user
-    4. Search through added users with a simple paged control
-    5. Perform steps 4 three times in a row
-    6. Return ACI to the initial state
-    7. Go through all steps onece again, but use IP subjectdn
-    insted of DNS
+    :Steps: 1. Back up and remove all previous ACI from suffix
+            2. Add an anonymous ACI for DNS check
+            3. Bind as test user
+            4. Search through added users with a simple paged control
+            5. Perform steps 4 three times in a row
+            6. Return ACI to the initial state
+            7. Go through all steps onece again, but use IP subjectdn
+               insted of DNS
 
-    @Assert: No error happens, all users should be found and sorted
+    :Assert: No error happens, all users should be found and sorted
     """
 
     users_num = 100
@@ -646,7 +653,7 @@ def test_search_dns_ip_aci(topology, test_user, aci_subject):
         log.info('If we are here, then no error has happened. We are good.')
 
     finally:
-        log.info('Set Directory Manager bind back')
+        log.info('Set Directory Manager bind back (test_search_dns_ip_aci)')
         topology.standalone.simple_bind_s(DN_DM, PASSWORD)
         log.info('Restore ACI')
         topology.standalone.modify_s(DEFAULT_SUFFIX, [(ldap.MOD_DELETE,
@@ -663,18 +670,17 @@ def test_search_multiple_paging(topology, test_user):
     """Verify that after performing multiple simple paged searches
     on a single connection without a complition, it wouldn't fail.
 
-    @Feature: Simple paged results
+    :Feature: Simple paged results
 
-    @Setup: Standalone instance, test user for binding,
-    variated number of users for the search base
+    :Setup: Standalone instance, test user for binding,
+            variated number of users for the search base
 
-    @Steps:
-    1. Bind as test user
-    2. Initiate the search with a simple paged control
-    3. Acquire the returned cookie only one time
-    4. Perform steps 2 and 3 three times in a row
+    :Steps: 1. Bind as test user
+            2. Initiate the search with a simple paged control
+            3. Acquire the returned cookie only one time
+            4. Perform steps 2 and 3 three times in a row
 
-    @Assert: No error happens
+    :Assert: No error happens
     """
 
     users_num = 100
@@ -713,7 +719,7 @@ def test_search_multiple_paging(topology, test_user):
                                                    searchreq_attrlist,
                                                    serverctrls=controls)
     finally:
-        log.info('Set Directory Manager bind back')
+        log.info('Set Directory Manager bind back (test_search_multiple_paging)')
         topology.standalone.simple_bind_s(DN_DM, PASSWORD)
         del_users(topology, users_list)
 
@@ -724,18 +730,17 @@ def test_search_invalid_cookie(topology, test_user, invalid_cookie):
     search with the simple paged results control throws
     a TypeError exception
 
-    @Feature: Simple paged results
+    :Feature: Simple paged results
 
-    @Setup: Standalone instance, test user for binding,
-    variated number of users for the search base
+    :Setup: Standalone instance, test user for binding,
+            variated number of users for the search base
 
-    @Steps:
-    1. Bind as test user
-    2. Initiate the search with a simple paged control
-    3. Put an invalid cookie (-1, 1000) to the control
-    4. Continue the search
+    :Steps: 1. Bind as test user
+            2. Initiate the search with a simple paged control
+            3. Put an invalid cookie (-1, 1000) to the control
+            4. Continue the search
 
-    @Assert: It will throw an TypeError exception
+    :Assert: It will throw an TypeError exception
     """
 
     users_num = 100
@@ -769,7 +774,7 @@ def test_search_invalid_cookie(topology, test_user, invalid_cookie):
                                                    searchreq_attrlist,
                                                    serverctrls=controls)
     finally:
-        log.info('Set Directory Manager bind back')
+        log.info('Set Directory Manager bind back (test_search_invalid_cookie)')
         topology.standalone.simple_bind_s(DN_DM, PASSWORD)
         del_users(topology, users_list)
 
@@ -778,17 +783,16 @@ def test_search_abandon_with_zero_size(topology, test_user):
     """Verify that search with simple paged results control
     can be abandon using page_size = 0
 
-    @Feature: Simple paged results
+    :Feature: Simple paged results
 
-    @Setup: Standalone instance, test user for binding,
-    variated number of users for the search base
+    :Setup: Standalone instance, test user for binding,
+            variated number of users for the search base
 
-    @Steps:
-    1. Bind as test user
-    2. Search through added users with a simple paged control
-    and page_size = 0
+    :Steps: 1. Bind as test user
+            2. Search through added users with a simple paged control
+               and page_size = 0
 
-    @Assert: No cookie should be returned at all
+    :Assert: No cookie should be returned at all
     """
 
     users_num = 10
@@ -818,7 +822,7 @@ def test_search_abandon_with_zero_size(topology, test_user):
         ]
         assert not pctrls[0].cookie
     finally:
-        log.info('Set Directory Manager bind back')
+        log.info('Set Directory Manager bind back (test_search_abandon_with_zero_size)')
         topology.standalone.simple_bind_s(DN_DM, PASSWORD)
         del_users(topology, users_list)
 
@@ -828,18 +832,17 @@ def test_search_pagedsizelimit_success(topology, test_user):
     returns all entries it should without errors while
     valid value set to nsslapd-pagedsizelimit.
 
-    @Feature: Simple paged results
+    :Feature: Simple paged results
 
-    @Setup: Standalone instance, test user for binding,
-    10 users for the search base
+    :Setup: Standalone instance, test user for binding,
+            10 users for the search base
 
-    @Steps:
-    1. Set nsslapd-pagedsizelimit: 20
-    2. Bind as test user
-    3. Search through added users with a simple paged control
-    using page_size = 10
+    :Steps: 1. Set nsslapd-pagedsizelimit: 20
+            2. Bind as test user
+            3. Search through added users with a simple paged control
+               using page_size = 10
 
-    @Assert: All users should be found
+    :Assert: All users should be found
     """
 
     users_num = 10
@@ -856,7 +859,6 @@ def test_search_pagedsizelimit_success(topology, test_user):
         log.info('Set user bind')
         topology.standalone.simple_bind_s(TEST_USER_DN, TEST_USER_PWD)
 
-        log.info('Create simple paged results control instance')
         req_ctrl = SimplePagedResultsControl(True, size=page_size, cookie='')
         controls = [req_ctrl]
 
@@ -867,7 +869,7 @@ def test_search_pagedsizelimit_success(topology, test_user):
         assert len(all_results) == len(users_list)
 
     finally:
-        log.info('Set Directory Manager bind back')
+        log.info('Set Directory Manager bind back (test_search_pagedsizelimit_success)')
         topology.standalone.simple_bind_s(DN_DM, PASSWORD)
         del_users(topology, users_list)
         change_conf_attr(topology, DN_CONFIG,
@@ -882,27 +884,27 @@ def test_search_nspagedsizelimit(topology, test_user,
     nsslapd-pagedsizelimit while performing search with
     the simple paged results control.
 
-    @Feature: Simple paged results
+    :Feature: Simple paged results
 
-    @Setup: Standalone instance, test user for binding,
-    10 users for the search base
+    :Setup: Standalone instance, test user for binding,
+            10 users for the search base
 
-    @Steps:
-    1. Set nsslapd-pagedsizelimit: 5
-    2. Set nsPagedSizeLimit: 15
-    3. Bind as test user
-    4. Search through added users with a simple paged control
-    using page_size = 10
-    5. Bind as Directory Manager
-    6. Restore all values
-    7. Set nsslapd-pagedsizelimit: 15
-    8. Set nsPagedSizeLimit: 5
-    9. Bind as test user
-    10. Search through added users with a simple paged control
-    using page_size = 10
+    :Steps: 1. Set nsslapd-pagedsizelimit: 5
+            2. Set nsPagedSizeLimit: 15
+            3. Bind as test user
+            4. Search through added users with a simple paged control
+               using page_size = 10
+            5. Bind as Directory Manager
+            6. Restore all values
+            7. Set nsslapd-pagedsizelimit: 15
+            8. Set nsPagedSizeLimit: 5
+            9. Bind as test user
+            10. Search through added users with a simple paged control
+                using page_size = 10
 
-    @Assert: After the steps 1-4, it should PASS.
-    After the steps 7-10, it should throw SIZELIMIT_EXCEEDED exception
+    :Assert: After the steps 1-4, it should PASS.
+             After the steps 7-10, it should throw
+             SIZELIMIT_EXCEEDED exception
     """
 
     users_num = 10
@@ -919,7 +921,6 @@ def test_search_nspagedsizelimit(topology, test_user,
         log.info('Set user bind')
         topology.standalone.simple_bind_s(TEST_USER_DN, TEST_USER_PWD)
 
-        log.info('Create simple paged results control instance')
         req_ctrl = SimplePagedResultsControl(True, size=page_size, cookie='')
         controls = [req_ctrl]
 
@@ -936,7 +937,7 @@ def test_search_nspagedsizelimit(topology, test_user,
             assert len(all_results) == len(users_list)
 
     finally:
-        log.info('Set Directory Manager bind back')
+        log.info('Set Directory Manager bind back (test_search_nspagedsizelimit)')
         topology.standalone.simple_bind_s(DN_DM, PASSWORD)
         del_users(topology, users_list)
         change_conf_attr(topology, DN_CONFIG,
@@ -953,27 +954,27 @@ def test_search_paged_limits(topology, test_user, conf_attr_values, expected_rs)
     nsslapd-lookthroughlimit can limit the administrator
     search abilities.
 
-    @Feature: Simple paged results
+    :Feature: Simple paged results
 
-    @Setup: Standalone instance, test user for binding,
-    10 users for the search base
+    :Setup: Standalone instance, test user for binding,
+            10 users for the search base
 
-    @Steps:
-    1. Set nsslapd-sizelimit and nsslapd-pagedsizelimit to 5000
-    2. Set nsslapd-idlistscanlimit: 120
-    3. Set nsslapd-lookthroughlimit: 122
-    4. Bind as test user
-    5. Search through added users with a simple paged control
-    using page_size = 10
-    6. Bind as Directory Manager
-    7. Set nsslapd-idlistscanlimit: 100
-    8. Set nsslapd-lookthroughlimit: 100
-    9. Bind as test user
-    10. Search through added users with a simple paged control
-    using page_size = 10
+    :Steps: 1. Set nsslapd-sizelimit and nsslapd-pagedsizelimit to 5000
+            2. Set nsslapd-idlistscanlimit: 120
+            3. Set nsslapd-lookthroughlimit: 122
+            4. Bind as test user
+            5. Search through added users with a simple paged control
+               using page_size = 10
+            6. Bind as Directory Manager
+            7. Set nsslapd-idlistscanlimit: 100
+            8. Set nsslapd-lookthroughlimit: 100
+            9. Bind as test user
+            10. Search through added users with a simple paged control
+                using page_size = 10
 
-    @Assert: After the steps 1-4, it should PASS.
-    After the steps 7-10, it should throw ADMINLIMIT_EXCEEDED exception
+    :Assert: After the steps 1-4, it should PASS.
+             After the steps 7-10, it should throw
+             ADMINLIMIT_EXCEEDED exception
     """
 
     users_num = 101
@@ -994,7 +995,6 @@ def test_search_paged_limits(topology, test_user, conf_attr_values, expected_rs)
         log.info('Set user bind')
         topology.standalone.simple_bind_s(TEST_USER_DN, TEST_USER_PWD)
 
-        log.info('Create simple paged results control instance')
         req_ctrl = SimplePagedResultsControl(True, size=page_size, cookie='')
         controls = [req_ctrl]
 
@@ -1010,7 +1010,7 @@ def test_search_paged_limits(topology, test_user, conf_attr_values, expected_rs)
             log.info('%d results' % len(all_results))
             assert len(all_results) == len(users_list)
     finally:
-        log.info('Set Directory Manager bind back')
+        log.info('Set Directory Manager bind back (test_search_paged_limits)')
         topology.standalone.simple_bind_s(DN_DM, PASSWORD)
         del_users(topology, users_list)
         change_conf_attr(topology, DN_CONFIG,
@@ -1031,28 +1031,28 @@ def test_search_paged_user_limits(topology, test_user, conf_attr_values, expecte
     override nsslapd-idlistscanlimit and nsslapd-lookthroughlimit
     while performing search with the simple paged results control.
 
-    @Feature: Simple paged results
+    :Feature: Simple paged results
 
-    @Setup: Standalone instance, test user for binding,
-    10 users for the search base
+    :Setup: Standalone instance, test user for binding,
+            10 users for the search base
 
-    @Steps:
-    1. Set nsslapd-idlistscanlimit: 1000
-    2. Set nsslapd-lookthroughlimit: 1000
-    3. Set nsPagedIDListScanLimit: 120
-    4. Set nsPagedLookthroughLimit: 122
-    5. Bind as test user
-    6. Search through added users with a simple paged control
-    using page_size = 10
-    7. Bind as Directory Manager
-    8. Set nsPagedIDListScanLimit: 100
-    9. Set nsPagedLookthroughLimit: 100
-    10. Bind as test user
-    11. Search through added users with a simple paged control
-    using page_size = 10
+    :Steps: 1. Set nsslapd-idlistscanlimit: 1000
+            2. Set nsslapd-lookthroughlimit: 1000
+            3. Set nsPagedIDListScanLimit: 120
+            4. Set nsPagedLookthroughLimit: 122
+            5. Bind as test user
+            6. Search through added users with a simple paged control
+               using page_size = 10
+            7. Bind as Directory Manager
+            8. Set nsPagedIDListScanLimit: 100
+            9. Set nsPagedLookthroughLimit: 100
+            10. Bind as test user
+            11. Search through added users with a simple paged control
+                using page_size = 10
 
-    @Assert: After the steps 1-4, it should PASS.
-    After the steps 8-11, it should throw ADMINLIMIT_EXCEEDED exception
+    :Assert: After the steps 1-4, it should PASS.
+             After the steps 8-11, it should throw
+             ADMINLIMIT_EXCEEDED exception
     """
 
     users_num = 101
@@ -1073,7 +1073,6 @@ def test_search_paged_user_limits(topology, test_user, conf_attr_values, expecte
         log.info('Set user bind')
         topology.standalone.simple_bind_s(TEST_USER_DN, TEST_USER_PWD)
 
-        log.info('Create simple paged results control instance')
         req_ctrl = SimplePagedResultsControl(True, size=page_size, cookie='')
         controls = [req_ctrl]
 
@@ -1089,7 +1088,7 @@ def test_search_paged_user_limits(topology, test_user, conf_attr_values, expecte
             log.info('%d results' % len(all_results))
             assert len(all_results) == len(users_list)
     finally:
-        log.info('Set Directory Manager bind back')
+        log.info('Set Directory Manager bind back (test_search_paged_user_limits)')
         topology.standalone.simple_bind_s(DN_DM, PASSWORD)
         del_users(topology, users_list)
         change_conf_attr(topology, 'cn=config,%s' % DN_LDBM,
@@ -1102,6 +1101,47 @@ def test_search_paged_user_limits(topology, test_user, conf_attr_values, expecte
                          'nsPagedLookthroughLimit', user_lookthrough_attr_bck)
 
 
+def test_ger_basic(topology, test_user):
+    """Verify that search with a simple paged results control
+    and get effective rights control returns all entries
+    it should without errors.
+
+    :Feature: Simple paged results
+
+    :Setup: Standalone instance, test user for binding,
+            variated number of users for the search base
+
+    :Steps: 1. Search through added users with a simple paged control
+               and get effective rights control
+
+    :Assert: All users should be found, every found entry should have
+             an 'attributeLevelRights' returned
+    """
+
+    users_list = add_users(topology, 20, DEFAULT_SUFFIX)
+    search_flt = r'(uid=test*)'
+    searchreq_attrlist = ['dn', 'sn']
+    page_size = 4
+
+    try:
+        log.info('Set bind to directory manager')
+        topology.standalone.simple_bind_s(DN_DM, PASSWORD)
+
+        spr_ctrl = SimplePagedResultsControl(True, size=page_size, cookie='')
+        ger_ctrl = GetEffectiveRightsControl(True, "dn: " + DN_DM)
+
+        all_results = paged_search(topology, DEFAULT_SUFFIX, [spr_ctrl, ger_ctrl],
+                                   search_flt, searchreq_attrlist)
+
+        log.info('{} results'.format(len(all_results)))
+        assert len(all_results) == len(users_list)
+        log.info('Check for attributeLevelRights')
+        assert all(attrs['attributeLevelRights'][0] for dn, attrs in all_results)
+    finally:
+        log.info('Remove added users')
+        del_users(topology, users_list)
+
+
 def test_multi_suffix_search(topology, test_user, new_suffixes):
     """Verify that page result search returns empty cookie
     if there is no returned entry.
@@ -1128,6 +1168,9 @@ def test_multi_suffix_search(topology, test_user, new_suffixes):
     page_size = 4
     users_num = 20
 
+    log.info('Clear the access log')
+    topology.standalone.deleteAccessLogs()
+
     users_list_1 = add_users(topology, users_num / 2, NEW_SUFFIX_1)
     users_list_2 = add_users(topology, users_num / 2, NEW_SUFFIX_2)
 
@@ -1135,7 +1178,6 @@ def test_multi_suffix_search(topology, test_user, new_suffixes):
         log.info('Set DM bind')
         topology.standalone.simple_bind_s(DN_DM, PASSWORD)
 
-        log.info('Create simple paged results control instance')
         req_ctrl = SimplePagedResultsControl(True, size=page_size, cookie='')
 
         all_results = paged_search(topology, NEW_SUFFIX_1, [req_ctrl],
@@ -1144,13 +1186,15 @@ def test_multi_suffix_search(topology, test_user, new_suffixes):
         log.info('{} results'.format(len(all_results)))
         assert len(all_results) == users_num
 
-        log.info('Waiting for logs to be updated')
-        time.sleep(30)
+        log.info('Restart the server to flush the logs')
+        topology.standalone.restart(timeout=10)
+
         access_log_lines = topology.standalone.ds_access_log.match('.*pr_cookie=.*')
         pr_cookie_list = ([line.rsplit('=', 1)[-1] for line in access_log_lines])
         pr_cookie_list = [int(pr_cookie) for pr_cookie in pr_cookie_list]
         log.info('Assert that last pr_cookie == -1 and others pr_cookie == 0')
-        assert all((pr_cookie == 0 for pr_cookie in pr_cookie_list[0:-1]))
+        pr_cookie_zeros = list(pr_cookie == 0 for pr_cookie in pr_cookie_list[0:-1])
+        assert all(pr_cookie_zeros)
         assert pr_cookie_list[-1] == -1
     finally:
         log.info('Remove added users')
@@ -1158,6 +1202,114 @@ def test_multi_suffix_search(topology, test_user, new_suffixes):
         del_users(topology, users_list_2)
 
 
+@pytest.mark.parametrize('conf_attr_value', (None, '-1', '1000'))
+def test_maxsimplepaged_per_conn_success(topology, test_user, conf_attr_value):
+    """Verify that nsslapd-maxsimplepaged-per-conn acts according design
+
+    :Feature: Simple paged results
+
+    :Setup: Standalone instance, test user for binding,
+            20 users for the search base
+
+    :Steps: 1. Set nsslapd-maxsimplepaged-per-conn in cn=config
+               to the next values: no value, -1, some positive
+            2. Search through the added users with a simple paged control
+               using page size = 4
+
+    :Assert: If no value or value = -1 - all users should be found,
+             default behaviour;
+             If the value is positive, the value is the max simple paged
+             results requests per connection.
+    """
+
+    users_list = add_users(topology, 20, DEFAULT_SUFFIX)
+    search_flt = r'(uid=test*)'
+    searchreq_attrlist = ['dn', 'sn']
+    page_size = 4
+    if conf_attr_value:
+        max_per_con_bck = change_conf_attr(topology, DN_CONFIG,
+                                           'nsslapd-maxsimplepaged-per-conn',
+                                           conf_attr_value)
+
+    try:
+        log.info('Set user bind')
+        topology.standalone.simple_bind_s(TEST_USER_DN, TEST_USER_PWD)
+
+        req_ctrl = SimplePagedResultsControl(True, size=page_size, cookie='')
+
+        all_results = paged_search(topology, DEFAULT_SUFFIX, [req_ctrl],
+                                   search_flt, searchreq_attrlist)
+
+        log.info('{} results'.format(len(all_results)))
+        assert len(all_results) == len(users_list)
+    finally:
+        log.info('Remove added users')
+        topology.standalone.simple_bind_s(DN_DM, PASSWORD)
+        del_users(topology, users_list)
+        if conf_attr_value:
+            change_conf_attr(topology, DN_CONFIG,
+                             'nsslapd-maxsimplepaged-per-conn', max_per_con_bck)
+
+
+@pytest.mark.parametrize('conf_attr_value', ('0', '1'))
+def test_maxsimplepaged_per_conn_failure(topology, test_user, conf_attr_value):
+    """Verify that nsslapd-maxsimplepaged-per-conn acts according design
+
+    :Feature: Simple paged results
+
+    :Setup: Standalone instance, test user for binding,
+            20 users for the search base
+
+    :Steps: 1. Set nsslapd-maxsimplepaged-per-conn = 0 in cn=config
+            2. Search through the added users with a simple paged control
+               using page size = 4
+            3. Set nsslapd-maxsimplepaged-per-conn = 1 in cn=config
+            4. Search through the added users with a simple paged control
+               using page size = 4 two times, but don't close the connections
+
+    :Assert: During the searches UNWILLING_TO_PERFORM should be throwned
+    """
+
+    users_list = add_users(topology, 20, DEFAULT_SUFFIX)
+    search_flt = r'(uid=test*)'
+    searchreq_attrlist = ['dn', 'sn']
+    page_size = 4
+    max_per_con_bck = change_conf_attr(topology, DN_CONFIG,
+                                       'nsslapd-maxsimplepaged-per-conn',
+                                       conf_attr_value)
+
+    try:
+        log.info('Set user bind')
+        topology.standalone.simple_bind_s(TEST_USER_DN, TEST_USER_PWD)
+
+        log.info('Create simple paged results control instance')
+        req_ctrl = SimplePagedResultsControl(True, size=page_size, cookie='')
+
+        with pytest.raises(ldap.UNWILLING_TO_PERFORM):
+            msgid = topology.standalone.search_ext(DEFAULT_SUFFIX,
+                                                ldap.SCOPE_SUBTREE,
+                                                search_flt,
+                                                searchreq_attrlist,
+                                                serverctrls=[req_ctrl])
+            rtype, rdata, rmsgid, rctrls = topology.standalone.result3(msgid)
+
+            # If nsslapd-maxsimplepaged-per-conn = 1,
+            # it should pass this point, but failed on the next search
+            assert conf_attr_value == '1'
+            msgid = topology.standalone.search_ext(DEFAULT_SUFFIX,
+                                                ldap.SCOPE_SUBTREE,
+                                                search_flt,
+                                                searchreq_attrlist,
+                                                serverctrls=[req_ctrl])
+            rtype, rdata, rmsgid, rctrls = topology.standalone.result3(msgid)
+    finally:
+        log.info('Remove added users')
+        topology.standalone.simple_bind_s(DN_DM, PASSWORD)
+        del_users(topology, users_list)
+        change_conf_attr(topology, DN_CONFIG,
+                         'nsslapd-maxsimplepaged-per-conn', max_per_con_bck)
+
+
 if __name__ == '__main__':
     # Run isolated
     # -s for DEBUG mode
