@@ -12,6 +12,7 @@ import time
 import ldap
 import logging
 import pytest
+import socket
 from lib389 import DirSrv, Entry, tools, tasks
 from lib389.tools import DirSrvTools
 from lib389._constants import *
@@ -53,8 +54,9 @@ def topology(request):
     standalone.create()
     standalone.open()
 
-    # Clear out the tmp dir
-    standalone.clearTmpDir(__file__)
+    def fin():
+        standalone.delete()
+    request.addfinalizer(fin)
 
     return TopologyStandalone(standalone)
 
@@ -210,13 +212,21 @@ def test_rootdn_access_day_of_week(topology):
     days = ('Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat')
     day = int(time.strftime("%w", time.gmtime()))
 
-    if day > 3:
+    if day == 6:
+        # Handle the roll over from Saturday into Sunday
+        deny_days = days[1] + ', ' + days[2]
+        allow_days = days[6] + ',' + days[0]
+    elif day > 3:
         deny_days = days[0] + ', ' + days[1]
         allow_days = days[day] + ',' + days[day - 1]
     else:
         deny_days = days[4] + ',' + days[5]
         allow_days = days[day] + ',' + days[day + 1]
 
+    log.info('Today:        ' + days[day])
+    log.info('Allowed days: ' + allow_days)
+    log.info('Deny days:    ' + deny_days)
+
     #
     # Set the deny days
     #
@@ -293,8 +303,12 @@ def test_rootdn_access_denied_ip(topology):
     log.info('Running test_rootdn_access_denied_ip...')
 
     try:
-        topology.standalone.modify_s(PLUGIN_DN, [(ldap.MOD_REPLACE, 'rootdn-deny-ip', '127.0.0.1'),
-                                  (ldap.MOD_ADD, 'rootdn-deny-ip', '::1')])
+        topology.standalone.modify_s(PLUGIN_DN, [(ldap.MOD_REPLACE,
+                                                  'rootdn-deny-ip',
+                                                  '127.0.0.1'),
+                                                 (ldap.MOD_ADD,
+                                                  'rootdn-deny-ip',
+                                                  '::1')])
     except ldap.LDAPError as e:
         log.fatal('test_rootdn_access_denied_ip: Failed to set rootDN plugin config: error ' +
                   e.message['desc'])
@@ -362,9 +376,15 @@ def test_rootdn_access_denied_host(topology):
     '''
 
     log.info('Running test_rootdn_access_denied_host...')
-
+    hostname = socket.gethostname()
+    localhost = DirSrvTools.getLocalhost()
     try:
-        topology.standalone.modify_s(PLUGIN_DN, [(ldap.MOD_ADD, 'rootdn-deny-host', 'localhost.localdomain')])
+        topology.standalone.modify_s(PLUGIN_DN, [(ldap.MOD_ADD,
+                                                  'rootdn-deny-host',
+                                                  hostname)])
+        topology.standalone.modify_s(PLUGIN_DN, [(ldap.MOD_ADD,
+                                                  'rootdn-deny-host',
+                                                  localhost)])
     except ldap.LDAPError as e:
         log.fatal('test_rootdn_access_denied_host: Failed to set deny host: error ' +
                   e.message['desc'])
@@ -539,8 +559,15 @@ def test_rootdn_access_allowed_host(topology):
         log.fatal('test_rootdn_access_allowed_host: : failed to bind as user1')
         assert False
 
+    hostname = socket.gethostname()
+    localhost = DirSrvTools.getLocalhost()
     try:
-        topology.standalone.modify_s(PLUGIN_DN, [(ldap.MOD_ADD, 'rootdn-allow-host', 'localhost.localdomain')])
+        topology.standalone.modify_s(PLUGIN_DN, [(ldap.MOD_ADD,
+                                                  'rootdn-allow-host',
+                                                  localhost)])
+        topology.standalone.modify_s(PLUGIN_DN, [(ldap.MOD_ADD,
+                                                  'rootdn-allow-host',
+                                                  hostname)])
     except ldap.LDAPError as e:
         log.fatal('test_rootdn_access_allowed_host: Failed to set allowed host: error ' +
                   e.message['desc'])
@@ -751,28 +778,8 @@ def test_rootdn_config_validate(topology):
     log.info('test_rootdn_config_validate: PASSED')
 
 
-def test_rootdn_final(topology):
-    topology.standalone.delete()
-    log.info('Root DN Access Control test suite PASSED')
-
-
-def run_isolated():
-    global installation1_prefix
-    installation1_prefix = None
-
-    topo = topology(True)
-    test_rootdn_init(topo)
-    test_rootdn_access_specific_time(topo)
-    test_rootdn_access_day_of_week(topo)
-    test_rootdn_access_allowed_ip(topo)
-    test_rootdn_access_denied_ip(topo)
-    test_rootdn_access_allowed_host(topo)
-    test_rootdn_access_denied_host(topo)
-    test_rootdn_config_validate(topo)
-
-    test_rootdn_final(topo)
-
-
 if __name__ == '__main__':
-    run_isolated()
-
+    # Run isolated
+    # -s for DEBUG mode
+    CURRENT_FILE = os.path.realpath(__file__)
+    pytest.main("-s %s" % CURRENT_FILE)
