@@ -7,13 +7,12 @@
 # --- END COPYRIGHT BLOCK ---
 #
 import os
-import sys
 import time
 import ldap
 import logging
 import pytest
-from lib389 import DirSrv, Entry, tools, tasks
-from lib389.tools import DirSrvTools
+from subprocess import Popen
+from lib389 import DirSrv, Entry
 from lib389._constants import *
 from lib389.properties import *
 from lib389.tasks import *
@@ -44,6 +43,7 @@ log = logging.getLogger(__name__)
 
 installation1_prefix = None
 
+
 class TopologyStandalone(object):
     def __init__(self, standalone):
         standalone.open()
@@ -71,37 +71,41 @@ def topology(request):
     standalone.open()
 
     # Delete each instance in the end
-#    def fin():
-#        standalone.delete()
-#    request.addfinalizer(fin)
+    def fin():
+        standalone.delete()
+    request.addfinalizer(fin)
 
     # Clear out the tmp dir
     standalone.clearTmpDir(__file__)
 
     return TopologyStandalone(standalone)
 
+
 def pattern_accesslog(file, log_pattern):
-    try:
-        pattern_accesslog.last_pos += 1
-    except AttributeError:
-        pattern_accesslog.last_pos = 0
+    for i in range(5):
+        try:
+            pattern_accesslog.last_pos += 1
+        except AttributeError:
+            pattern_accesslog.last_pos = 0
 
-    found = None
-    file.seek(pattern_accesslog.last_pos)
+        found = None
+        file.seek(pattern_accesslog.last_pos)
 
-    # Use a while true iteration because 'for line in file: hit a
-    # python bug that break file.tell()
-    while True:
-        line = file.readline()
-        found = log_pattern.search(line)
-        if ((line == '') or (found)):
-            break
+        # Use a while true iteration because 'for line in file: hit a
+        # python bug that break file.tell()
+        while True:
+            line = file.readline()
+            found = log_pattern.search(line)
+            if ((line == '') or (found)):
+                break
+
+        pattern_accesslog.last_pos = file.tell()
+        if found:
+            return line
+        else:
+            time.sleep(1)
+    return None
 
-    pattern_accesslog.last_pos = file.tell()
-    if found:
-        return line
-    else:
-        return None
 
 def check_op_result(server, op, dn, superior, exists, rc):
     targetdn = dn
@@ -144,6 +148,7 @@ def check_op_result(server, op, dn, superior, exists, rc):
         expstr = 'fail with %s' % rc.__name__
 
     log.info('%s %s, which should %s.' % (opstr, targetdn, expstr))
+    time.sleep(1)
     hit = 0
     try:
         if op == 'search':
@@ -184,6 +189,7 @@ def check_op_result(server, op, dn, superior, exists, rc):
 
     log.info('PASSED\n')
 
+
 def test_ticket1347760(topology):
     """
     Prevent revealing the entry info to whom has no access rights.
@@ -245,6 +251,7 @@ def test_ticket1347760(topology):
             assert False
         else:
             log.info('Cause found - %s' % cause)
+    time.sleep(1)
 
     log.info('Bind case 2-2. the bind user\'s suffix does not exist, bind should fail with error %s' % ldap.INVALID_CREDENTIALS.__name__)
     log.info('Bind as {%s,%s} who does not exist.' % (BOGUSSUFFIX, 'bogus'))
@@ -261,6 +268,7 @@ def test_ticket1347760(topology):
             assert False
         else:
             log.info('Cause found - %s' % cause)
+    time.sleep(1)
 
     log.info('Bind case 2-3. the bind user\'s password is wrong, bind should fail with error %s' % ldap.INVALID_CREDENTIALS.__name__)
     log.info('Bind as {%s,%s} who does not exist.' % (BINDDN, 'bogus'))
@@ -277,6 +285,7 @@ def test_ticket1347760(topology):
             assert False
         else:
             log.info('Cause found - %s' % cause)
+    time.sleep(1)
 
     log.info('Adding aci for %s to %s.' % (BINDDN, BINDOU))
     acival = '(targetattr="*")(version 3.0; acl "%s"; allow(all) userdn = "ldap:///%s";)' % (BUID, BINDDN)
@@ -284,6 +293,7 @@ def test_ticket1347760(topology):
     log.info('Bind as {%s,%s}' % (DN_DM, PASSWORD))
     topology.standalone.simple_bind_s(DN_DM, PASSWORD)
     topology.standalone.modify_s(BINDOU, [(ldap.MOD_ADD, 'aci', acival)])
+    time.sleep(1)
 
     log.info('Bind case 3. the bind user has the right to read the entry itself, bind should be successful.')
     log.info('Bind as {%s,%s} which should be ok.\n' % (BINDDN, BINDPW))
@@ -391,6 +401,7 @@ def test_ticket1347760(topology):
     log.info('Bind as {%s,%s}' % (DN_DM, PASSWORD))
     topology.standalone.simple_bind_s(DN_DM, PASSWORD)
     topology.standalone.modify_s(DEFAULT_SUFFIX, [(ldap.MOD_ADD, 'aci', acival)])
+    time.sleep(1)
 
     log.info('Bind as {%s,%s}.' % (BINDDN, BINDPW))
     try:
@@ -398,6 +409,7 @@ def test_ticket1347760(topology):
     except ldap.LDAPError as e:
         log.info('Desc ' + e.message['desc'])
         assert False
+    time.sleep(1)
 
     exists = False
     rc = ldap.NO_SUCH_OBJECT
@@ -430,11 +442,32 @@ def test_ticket1347760(topology):
     log.info('Delete case. the deleting entry does not exist, it should fail with %s' % rc.__name__)
     check_op_result(topology.standalone, 'delete', BOGUSDN, None, exists, rc)
 
+    log.info('Inactivate %s' % BINDDN)
+    nsinactivate = '%s/sbin/ns-inactivate.pl' % topology.standalone.prefix
+    p = Popen([nsinactivate, '-Z', 'standalone', '-D', DN_DM, '-w', PASSWORD, '-I', BINDDN])
+    assert(p.wait() == 0)
+
+    log.info('Bind as {%s,%s} which should fail with %s.' % (BINDDN, BUID, ldap.UNWILLING_TO_PERFORM.__name__))
+    try:
+        topology.standalone.simple_bind_s(BINDDN, BUID)
+    except ldap.LDAPError as e:
+        log.info("Exception (expected): %s" % type(e).__name__)
+        log.info('Desc ' + e.message['desc'])
+        assert isinstance(e, ldap.UNWILLING_TO_PERFORM)
+
+    log.info('Bind as {%s,%s} which should fail with %s.' % (BINDDN, 'bogus', ldap.INVALID_CREDENTIALS.__name__))
+    try:
+        topology.standalone.simple_bind_s(BINDDN, 'bogus')
+    except ldap.LDAPError as e:
+        log.info("Exception (expected): %s" % type(e).__name__)
+        log.info('Desc ' + e.message['desc'])
+        assert isinstance(e, ldap.INVALID_CREDENTIALS)
+
     log.info('SUCCESS')
 
+
 if __name__ == '__main__':
     # Run isolated
     # -s for DEBUG mode
-
     CURRENT_FILE = os.path.realpath(__file__)
     pytest.main("-s %s" % CURRENT_FILE)
