@@ -3,7 +3,7 @@
 # All rights reserved.
 #
 # License: GPL (version 3 or any later version).
-# See LICENSE for details. 
+# See LICENSE for details.
 # --- END COPYRIGHT BLOCK ---
 #
 '''
@@ -14,13 +14,11 @@ Created on Nov 7, 2013
 import os
 import sys
 import ldap
-import socket
 import time
 import logging
 import pytest
 import re
-from lib389 import DirSrv, Entry, tools
-from lib389.tools import DirSrvTools
+from lib389 import DirSrv, Entry
 from lib389._constants import *
 from lib389.properties import *
 
@@ -254,9 +252,10 @@ def topology(request):
         log.fatal('Replication is not working.')
         assert False
 
-    # clear the tmp directory
-    master.clearTmpDir(__file__)
-
+    def fin():
+        master.delete()
+        consumer.delete()
+    request.addfinalizer(fin)
     #
     # Here we have two instances master and consumer
     # with replication working.
@@ -653,39 +652,12 @@ def test_ticket47490_nine(topology):
     if res is not None:
         assert False
 
-
-def test_ticket47490_final(topology):
-    topology.master.delete()
-    topology.consumer.delete()
     log.info('Testcase PASSED')
 
 
-def run_isolated():
-    '''
-        run_isolated is used to run these test cases independently of a test scheduler (xunit, py.test..)
-        To run isolated without py.test, you need to
-            - edit this file and comment '@pytest.fixture' line before 'topology' function.
-            - set the installation prefix
-            - run this program
-    '''
-    global installation_prefix
-    installation_prefix = None
-
-    topo = topology(True)
-    test_ticket47490_init(topo)
-    test_ticket47490_one(topo)
-    test_ticket47490_two(topo)
-    test_ticket47490_three(topo)
-    test_ticket47490_four(topo)
-    test_ticket47490_five(topo)
-    test_ticket47490_six(topo)
-    test_ticket47490_seven(topo)
-    test_ticket47490_eight(topo)
-    test_ticket47490_nine(topo)
-
-    test_ticket47490_final(topo)
-
-
 if __name__ == '__main__':
-    run_isolated()
+    # Run isolated
+    # -s for DEBUG mode
+    CURRENT_FILE = os.path.realpath(__file__)
+    pytest.main("-s %s" % CURRENT_FILE)
 
