@@ -158,8 +158,10 @@ def topology(request):
         log.fatal('Replication is not working.')
         assert False
 
-    # clear the tmp directory
-    master1.clearTmpDir(__file__)
+    def fin():
+        master1.delete()
+        master2.delete()
+    request.addfinalizer(fin)
 
     # Here we have two instances master and consumer
     # with replication working.
@@ -192,9 +194,8 @@ def test_ticket47653_init(topology):
     topology.master1.modify_s(DN_CONFIG, mod)
     topology.master2.modify_s(DN_CONFIG, mod)
 
-    # get read of anonymous ACI for use 'read-search' aci in SEARCH test
-    ACI_ANONYMOUS = "(targetattr!=\"userPassword\")(version 3.0; acl \"Enable anonymous access\"; allow (read, search, compare) userdn=\"ldap:///anyone\";)"
-    mod = [(ldap.MOD_DELETE, 'aci', ACI_ANONYMOUS)]
+    # remove all aci's and start with a clean slate
+    mod = [(ldap.MOD_DELETE, 'aci', None)]
     topology.master1.modify_s(SUFFIX, mod)
     topology.master2.modify_s(SUFFIX, mod)
 
@@ -441,33 +442,8 @@ def test_ticket47653_modify(topology):
         assert ent.getValue('postalCode') == '1929'
 
 
-def test_ticket47653_final(topology):
-    topology.master1.delete()
-    topology.master2.delete()
-    log.info('Testcase PASSED')
-
-
-def run_isolated():
-    '''
-        run_isolated is used to run these test cases independently of a test scheduler (xunit, py.test..)
-        To run isolated without py.test, you need to
-            - edit this file and comment '@pytest.fixture' line before 'topology' function.
-            - set the installation prefix
-            - run this program
-    '''
-    global installation1_prefix
-    global installation2_prefix
-    installation1_prefix = None
-    installation2_prefix = None
-
-    topo = topology(True)
-    test_ticket47653_init(topo)
-
-    test_ticket47653_add(topo)
-    test_ticket47653_modify(topo)
-
-    test_ticket47653_final(topo)
-
-
 if __name__ == '__main__':
-    run_isolated()
+    # Run isolated
+    # -s for DEBUG mode
+    CURRENT_FILE = os.path.realpath(__file__)
+    pytest.main("-s %s" % CURRENT_FILE)
