@@ -3,7 +3,7 @@
 # All rights reserved.
 #
 # License: GPL (version 3 or any later version).
-# See LICENSE for details. 
+# See LICENSE for details.
 # --- END COPYRIGHT BLOCK ---
 #
 import os
@@ -67,8 +67,6 @@ def topology(request):
     '''
     global installation_prefix
 
-
-
     standalone = DirSrv(verbose=False)
     if installation_prefix:
         args_instance[SER_DEPLOYED_DIR] = installation_prefix
@@ -92,8 +90,9 @@ def topology(request):
     # Used to retrieve configuration information (dbdir, confdir...)
     standalone.open()
 
-    # clear the tmp directory
-    standalone.clearTmpDir(__file__)
+    def fin():
+        standalone.delete()
+    request.addfinalizer(fin)
 
     # Here we have standalone instance up and running
     return TopologyStandalone(standalone)
@@ -437,6 +436,7 @@ def _config_file(topology, action='save'):
         shutil.copy(dse_ldif, sav_file)
     else:
         shutil.copy(sav_file, dse_ldif)
+    time.sleep(1)
 
 
 def _pattern_errorlog(file, log_pattern):
@@ -974,48 +974,8 @@ def test_ticket47823_invalid_config_7(topology):
         pass
 
 
-def test_ticket47823_final(topology):
-    topology.standalone.delete()
-    log.info('Testcase PASSED')
-
-
-def run_isolated():
-    '''
-        run_isolated is used to run these test cases independently of a test scheduler (xunit, py.test..)
-        To run isolated without py.test, you need to
-            - edit this file and comment '@pytest.fixture' line before 'topology' function.
-            - set the installation prefix
-            - run this program
-    '''
-    global installation_prefix
-    installation_prefix = None
-
-    topo = topology(True)
-    test_ticket47823_init(topo)
-
-    # run old/new config style that makes uniqueness checking on one subtree
-    test_ticket47823_one_container_add(topo)
-    test_ticket47823_one_container_mod(topo)
-    test_ticket47823_one_container_modrdn(topo)
-
-    # run old config style that makes uniqueness checking on each defined subtrees
-    test_ticket47823_multi_containers_add(topo)
-    test_ticket47823_multi_containers_mod(topo)
-    test_ticket47823_multi_containers_modrdn(topo)
-    test_ticket47823_across_multi_containers_add(topo)
-    test_ticket47823_across_multi_containers_mod(topo)
-    test_ticket47823_across_multi_containers_modrdn(topo)
-
-    test_ticket47823_invalid_config_1(topo)
-    test_ticket47823_invalid_config_2(topo)
-    test_ticket47823_invalid_config_3(topo)
-    test_ticket47823_invalid_config_4(topo)
-    test_ticket47823_invalid_config_5(topo)
-    test_ticket47823_invalid_config_6(topo)
-    test_ticket47823_invalid_config_7(topo)
-
-    test_ticket47823_final(topo)
-
-
 if __name__ == '__main__':
-    run_isolated()
+    # Run isolated
+    # -s for DEBUG mode
+    CURRENT_FILE = os.path.realpath(__file__)
+    pytest.main("-s %s" % CURRENT_FILE)
