@@ -3,7 +3,7 @@
 # All rights reserved.
 #
 # License: GPL (version 3 or any later version).
-# See LICENSE for details. 
+# See LICENSE for details.
 # --- END COPYRIGHT BLOCK ---
 #
 import os
@@ -25,15 +25,22 @@ installation_prefix = None
 
 CONFIG_DN = 'cn=config'
 ENCRYPTION_DN = 'cn=encryption,%s' % CONFIG_DN
+MY_SECURE_PORT = '36363'
 RSA = 'RSA'
 RSA_DN = 'cn=%s,%s' % (RSA, ENCRYPTION_DN)
-LDAPSPORT = '10636'
 SERVERCERT = 'Server-Cert'
 plus_all_ecount = 0
 plus_all_dcount = 0
 plus_all_ecount_noweak = 0
 plus_all_dcount_noweak = 0
 
+# Cipher counts tend to change with each new verson of NSS
+nss_version = ''
+NSS320 = '3.20.0'
+NSS321 = '3.21.0'  # RHEL6
+NSS323 = '3.23.0'  # F22
+NSS325 = '3.25.0'  # F23/F24
+
 
 class TopologyStandalone(object):
     def __init__(self, standalone):
@@ -73,8 +80,9 @@ def topology(request):
     # Used to retrieve configuration information (dbdir, confdir...)
     standalone.open()
 
-    # clear the tmp directory
-    standalone.clearTmpDir(__file__)
+    def fin():
+        standalone.delete()
+    request.addfinalizer(fin)
 
     # Here we have standalone instance up and running
     return TopologyStandalone(standalone)
@@ -88,13 +96,17 @@ def _header(topology, label):
     topology.standalone.log.info("###############################################")
 
 
-def test_ticket47838_init(topology):
+def test_47838_init(topology):
     """
     Generate self signed cert and import it to the DS cert db.
     Enable SSL
     """
     _header(topology, 'Testing Ticket 47838 - harden the list of ciphers available by default')
 
+    onss_version = os.popen("rpm -q nss | awk -F'-' '{print $2}'", "r")
+    global nss_version
+    nss_version = onss_version.readline()
+
     conf_dir = topology.standalone.confdir
 
     log.info("\n######################### Checking existing certs ######################\n")
@@ -115,6 +127,7 @@ def test_ticket47838_init(topology):
     noisewdfd = open(noisefile, "w")
     noisewdfd.write(noise.readline())
     noisewdfd.close()
+    time.sleep(1)
 
     log.info("\n######################### Create key3.db and cert8.db database ######################\n")
     os.system("ls %s" % pwdfile)
@@ -125,7 +138,8 @@ def test_ticket47838_init(topology):
     os.system('certutil -G -d %s -z %s -f %s' % (conf_dir, noisefile, pwdfile))
 
     log.info("\n######################### Creating self-signed CA certificate ######################\n")
-    os.system('( echo y ; echo ; echo y ) | certutil -S -n "CA certificate" -s "cn=CAcert" -x -t "CT,," -m 1000 -v 120 -d %s -z %s -f %s -2' % (conf_dir, noisefile, pwdfile))
+    os.system('( echo y ; echo ; echo y ) | certutil -S -n "CA certificate" -s "cn=CAcert" -x -t "CT,," -m 1000 -v 120 -d %s -z %s -f %s -2' %
+              (conf_dir, noisefile, pwdfile))
 
     log.info("\n######################### Exporting the CA certificate to cacert.asc ######################\n")
     cafile = '%s/cacert.asc' % conf_dir
@@ -149,6 +163,7 @@ def test_ticket47838_init(topology):
     pinfd = open(pinfile, "w")
     pinfd.write(pintxt)
     pinfd.close()
+    time.sleep(1)
 
     log.info("\n######################### enable SSL in the directory server with all ciphers ######################\n")
     topology.standalone.simple_bind_s(DN_DM, PASSWORD)
@@ -160,7 +175,7 @@ def test_ticket47838_init(topology):
 
     topology.standalone.modify_s(CONFIG_DN, [(ldap.MOD_REPLACE, 'nsslapd-security', 'on'),
                                              (ldap.MOD_REPLACE, 'nsslapd-ssl-check-hostname', 'off'),
-                                             (ldap.MOD_REPLACE, 'nsslapd-secureport', LDAPSPORT)])
+                                             (ldap.MOD_REPLACE, 'nsslapd-secureport', MY_SECURE_PORT)])
 
     topology.standalone.add_s(Entry((RSA_DN, {'objectclass': "top nsEncryptionModule".split(),
                                               'cn': RSA,
@@ -188,7 +203,7 @@ def comp_nsSSLEnableCipherCount(topology, ecount):
     assert ecount == enabledciphercnt
 
 
-def test_ticket47838_run_0(topology):
+def test_47838_run_0(topology):
     """
     Check nsSSL3Ciphers: +all
     All ciphers are enabled except null.
@@ -198,10 +213,9 @@ def test_ticket47838_run_0(topology):
 
     topology.standalone.simple_bind_s(DN_DM, PASSWORD)
     topology.standalone.modify_s(CONFIG_DN, [(ldap.MOD_REPLACE, 'nsslapd-errorlog-level', '64')])
-
+    time.sleep(5)
     log.info("\n######################### Restarting the server ######################\n")
     topology.standalone.restart(timeout=120)
-
     enabled = os.popen('egrep "SSL alert:" %s | egrep \": enabled\" | wc -l' % topology.standalone.errlog)
     disabled = os.popen('egrep "SSL alert:" %s | egrep \": disabled\" | wc -l' % topology.standalone.errlog)
     ecount = int(enabled.readline().rstrip())
@@ -209,8 +223,13 @@ def test_ticket47838_run_0(topology):
 
     log.info("Enabled ciphers: %d" % ecount)
     log.info("Disabled ciphers: %d" % dcount)
-    assert ecount >= 60
-    assert dcount <= 7
+    if nss_version >= NSS320:
+       assert ecount >= 53
+       assert dcount <= 17
+    else:
+       assert ecount >= 60
+       assert dcount <= 7
+
     global plus_all_ecount
     global plus_all_dcount
     plus_all_ecount = ecount
@@ -223,7 +242,7 @@ def test_ticket47838_run_0(topology):
     comp_nsSSLEnableCipherCount(topology, ecount)
 
 
-def test_ticket47838_run_1(topology):
+def test_47838_run_1(topology):
     """
     Check nsSSL3Ciphers: +all
     All ciphers are enabled except null.
@@ -233,6 +252,7 @@ def test_ticket47838_run_1(topology):
 
     topology.standalone.simple_bind_s(DN_DM, PASSWORD)
     topology.standalone.modify_s(CONFIG_DN, [(ldap.MOD_REPLACE, 'nsslapd-errorlog-level', '64')])
+    time.sleep(1)
     # Make sure allowWeakCipher is not set.
     topology.standalone.modify_s(ENCRYPTION_DN, [(ldap.MOD_DELETE, 'allowWeakCipher', None)])
 
@@ -241,6 +261,7 @@ def test_ticket47838_run_1(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.47838_0' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(1)
     topology.standalone.start(timeout=120)
 
     enabled = os.popen('egrep "SSL alert:" %s | egrep \": enabled\" | wc -l' % topology.standalone.errlog)
@@ -265,7 +286,7 @@ def test_ticket47838_run_1(topology):
     comp_nsSSLEnableCipherCount(topology, ecount)
 
 
-def test_ticket47838_run_2(topology):
+def test_47838_run_2(topology):
     """
     Check nsSSL3Ciphers: +rsa_aes_128_sha,+rsa_aes_256_sha
     rsa_aes_128_sha, tls_rsa_aes_128_sha, rsa_aes_256_sha, tls_rsa_aes_256_sha are enabled.
@@ -280,6 +301,7 @@ def test_ticket47838_run_2(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.47838_1' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(1)
     topology.standalone.start(timeout=120)
 
     enabled = os.popen('egrep "SSL alert:" %s | egrep \": enabled\" | wc -l' % topology.standalone.errlog)
@@ -297,7 +319,7 @@ def test_ticket47838_run_2(topology):
     comp_nsSSLEnableCipherCount(topology, ecount)
 
 
-def test_ticket47838_run_3(topology):
+def test_47838_run_3(topology):
     """
     Check nsSSL3Ciphers: -all
     All ciphers are disabled.
@@ -312,6 +334,7 @@ def test_ticket47838_run_3(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.47838_2' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(1)
     topology.standalone.start(timeout=120)
 
     enabled = os.popen('egrep "SSL alert:" %s | egrep \": enabled\" | wc -l' % topology.standalone.errlog)
@@ -328,7 +351,7 @@ def test_ticket47838_run_3(topology):
     comp_nsSSLEnableCipherCount(topology, ecount)
 
 
-def test_ticket47838_run_4(topology):
+def test_47838_run_4(topology):
     """
     Check no nsSSL3Ciphers
     Default ciphers are enabled.
@@ -343,6 +366,7 @@ def test_ticket47838_run_4(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.47838_3' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(1)
     topology.standalone.start(timeout=120)
 
     enabled = os.popen('egrep "SSL alert:" %s | egrep \": enabled\" | wc -l' % topology.standalone.errlog)
@@ -354,7 +378,10 @@ def test_ticket47838_run_4(topology):
     log.info("Disabled ciphers: %d" % dcount)
     global plus_all_ecount
     global plus_all_dcount
-    assert ecount == 12
+    if nss_version >= NSS323:
+        assert ecount == 29
+    else:
+        assert ecount == 20
     assert dcount == (plus_all_ecount + plus_all_dcount - ecount)
     weak = os.popen('egrep "SSL alert:" %s | egrep \": enabled\" | egrep "WEAK CIPHER" | wc -l' % topology.standalone.errlog)
     wcount = int(weak.readline().rstrip())
@@ -364,7 +391,7 @@ def test_ticket47838_run_4(topology):
     comp_nsSSLEnableCipherCount(topology, ecount)
 
 
-def test_ticket47838_run_5(topology):
+def test_47838_run_5(topology):
     """
     Check nsSSL3Ciphers: default
     Default ciphers are enabled.
@@ -379,6 +406,7 @@ def test_ticket47838_run_5(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.47838_4' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(1)
     topology.standalone.start(timeout=120)
 
     enabled = os.popen('egrep "SSL alert:" %s | egrep \": enabled\" | wc -l' % topology.standalone.errlog)
@@ -390,7 +418,10 @@ def test_ticket47838_run_5(topology):
     log.info("Disabled ciphers: %d" % dcount)
     global plus_all_ecount
     global plus_all_dcount
-    assert ecount == 12
+    if nss_version >= NSS323:
+        assert ecount == 29
+    else:
+        assert ecount == 23
     assert dcount == (plus_all_ecount + plus_all_dcount - ecount)
     weak = os.popen('egrep "SSL alert:" %s | egrep \": enabled\" | egrep "WEAK CIPHER" | wc -l' % topology.standalone.errlog)
     wcount = int(weak.readline().rstrip())
@@ -400,7 +431,7 @@ def test_ticket47838_run_5(topology):
     comp_nsSSLEnableCipherCount(topology, ecount)
 
 
-def test_ticket47838_run_6(topology):
+def test_47838_run_6(topology):
     """
     Check nsSSL3Ciphers: +all,-rsa_rc4_128_md5
     All ciphers are disabled.
@@ -415,6 +446,7 @@ def test_ticket47838_run_6(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.47838_5' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(1)
     topology.standalone.start(timeout=120)
 
     enabled = os.popen('egrep "SSL alert:" %s | egrep \": enabled\" | wc -l' % topology.standalone.errlog)
@@ -434,7 +466,7 @@ def test_ticket47838_run_6(topology):
     comp_nsSSLEnableCipherCount(topology, ecount)
 
 
-def test_ticket47838_run_7(topology):
+def test_47838_run_7(topology):
     """
     Check nsSSL3Ciphers: -all,+rsa_rc4_128_md5
     All ciphers are disabled.
@@ -449,6 +481,7 @@ def test_ticket47838_run_7(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.47838_6' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(1)
     topology.standalone.start(timeout=120)
 
     enabled = os.popen('egrep "SSL alert:" %s | egrep \": enabled\" | wc -l' % topology.standalone.errlog)
@@ -466,7 +499,7 @@ def test_ticket47838_run_7(topology):
     comp_nsSSLEnableCipherCount(topology, ecount)
 
 
-def test_ticket47838_run_8(topology):
+def test_47838_run_8(topology):
     """
     Check nsSSL3Ciphers: default + allowWeakCipher: off
     Strong Default ciphers are enabled.
@@ -481,6 +514,7 @@ def test_ticket47838_run_8(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.47838_7' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(1)
     topology.standalone.start(timeout=120)
 
     enabled = os.popen('egrep "SSL alert:" %s | egrep \": enabled\" | wc -l' % topology.standalone.errlog)
@@ -492,7 +526,10 @@ def test_ticket47838_run_8(topology):
     log.info("Disabled ciphers: %d" % dcount)
     global plus_all_ecount
     global plus_all_dcount
-    assert ecount == 12
+    if nss_version >= NSS323:
+       assert ecount == 29
+    else:
+       assert ecount == 23
     assert dcount == (plus_all_ecount + plus_all_dcount - ecount)
     weak = os.popen('egrep "SSL alert:" %s | egrep \": enabled\" | egrep "WEAK CIPHER" | wc -l' % topology.standalone.errlog)
     wcount = int(weak.readline().rstrip())
@@ -502,7 +539,7 @@ def test_ticket47838_run_8(topology):
     comp_nsSSLEnableCipherCount(topology, ecount)
 
 
-def test_ticket47838_run_9(topology):
+def test_47838_run_9(topology):
     """
     Check no nsSSL3Ciphers
     Default ciphers are enabled.
@@ -520,6 +557,7 @@ def test_ticket47838_run_9(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.47838_8' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(1)
     topology.standalone.start(timeout=120)
 
     enabled = os.popen('egrep "SSL alert:" %s | egrep \": enabled\" | wc -l' % topology.standalone.errlog)
@@ -529,17 +567,23 @@ def test_ticket47838_run_9(topology):
 
     log.info("Enabled ciphers: %d" % ecount)
     log.info("Disabled ciphers: %d" % dcount)
-    assert ecount == 23
+    if nss_version >= NSS323:
+        assert ecount == 36
+    else:
+        assert ecount == 30
     assert dcount == 0
     weak = os.popen('egrep "SSL alert:" %s | egrep \": enabled\" | egrep "WEAK CIPHER" | wc -l' % topology.standalone.errlog)
     wcount = int(weak.readline().rstrip())
     log.info("Weak ciphers in the default setting: %d" % wcount)
-    assert wcount == 11
+    if nss_version >= NSS320:
+        assert wcount == 7
+    else:
+        assert wcount == 11
 
     comp_nsSSLEnableCipherCount(topology, ecount)
 
 
-def test_ticket47838_run_10(topology):
+def test_47838_run_10(topology):
     """
     Check nsSSL3Ciphers: -TLS_RSA_WITH_NULL_MD5,+TLS_RSA_WITH_RC4_128_MD5,
         +TLS_RSA_EXPORT_WITH_RC4_40_MD5,+TLS_RSA_EXPORT_WITH_RC2_CBC_40_MD5,
@@ -562,6 +606,7 @@ def test_ticket47838_run_10(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.47838_9' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(1)
     topology.standalone.start(timeout=120)
 
     enabled = os.popen('egrep "SSL alert:" %s | egrep \": enabled\" | wc -l' % topology.standalone.errlog)
@@ -584,7 +629,7 @@ def test_ticket47838_run_10(topology):
     comp_nsSSLEnableCipherCount(topology, ecount)
 
 
-def test_ticket47838_run_11(topology):
+def test_47838_run_11(topology):
     """
     Check nsSSL3Ciphers: +fortezza
     SSL_GetImplementedCiphers does not return this as a secuire cipher suite
@@ -598,6 +643,7 @@ def test_ticket47838_run_11(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.47838_10' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(1)
     topology.standalone.start(timeout=120)
 
     errmsg = os.popen('egrep "SSL alert:" %s | egrep "is not available in NSS"' % topology.standalone.errlog)
@@ -611,7 +657,7 @@ def test_ticket47838_run_11(topology):
     comp_nsSSLEnableCipherCount(topology, 0)
 
 
-def test_ticket47928_run_0(topology):
+def test_47928_run_0(topology):
     """
     No SSL version config parameters.
     Check SSL3 (TLS1.0) is off.
@@ -629,11 +675,13 @@ def test_ticket47928_run_0(topology):
                                                  (ldap.MOD_DELETE, 'sslVersionMin', None),
                                                  (ldap.MOD_DELETE, 'sslVersionMax', None)])
     topology.standalone.modify_s(CONFIG_DN, [(ldap.MOD_REPLACE, 'nsslapd-errorlog-level', '64')])
+    time.sleep(5)
 
     log.info("\n######################### Restarting the server ######################\n")
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.47838_11' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(1)
     topology.standalone.start(timeout=120)
 
     errmsg = os.popen('egrep "SSL alert:" %s | egrep "Default SSL Version settings; Configuring the version range as min: TLS1.1"' % topology.standalone.errlog)
@@ -645,7 +693,7 @@ def test_ticket47928_run_0(topology):
         assert False
 
 
-def test_ticket47928_run_1(topology):
+def test_47928_run_1(topology):
     """
     No nsSSL3, nsTLS1; sslVersionMin > sslVersionMax
     Check sslVersionMax is ignored.
@@ -679,7 +727,7 @@ def test_ticket47928_run_1(topology):
         assert False
 
 
-def test_ticket47928_run_2(topology):
+def test_47928_run_2(topology):
     """
     nsSSL3: on; sslVersionMin: TLS1.1; sslVersionMax: TLS1.2
     Conflict between nsSSL3 and range; nsSSL3 is disabled
@@ -695,6 +743,7 @@ def test_ticket47928_run_2(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.47838_13' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(1)
     topology.standalone.start(timeout=120)
 
     errmsg = os.popen('egrep "SSL alert:" %s | egrep "Found unsecure configuration: nsSSL3: on"' % topology.standalone.errlog)
@@ -722,7 +771,7 @@ def test_ticket47928_run_2(topology):
         assert False
 
 
-def test_ticket47928_run_3(topology):
+def test_47928_run_3(topology):
     """
     nsSSL3: on; nsTLS1: off; sslVersionMin: TLS1.1; sslVersionMax: TLS1.2
     Conflict between nsSSL3/nsTLS1 and range; nsSSL3 is disabled; nsTLS1 is enabled.
@@ -739,6 +788,7 @@ def test_ticket47928_run_3(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.47838_14' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(1)
     topology.standalone.start(timeout=120)
 
     errmsg = os.popen('egrep "SSL alert:" %s | egrep "Found unsecure configuration: nsSSL3: on"' % topology.standalone.errlog)
@@ -766,7 +816,7 @@ def test_ticket47928_run_3(topology):
         assert False
 
 
-def test_ticket47838_run_last(topology):
+def test_47838_run_last(topology):
     """
     Check nsSSL3Ciphers: all <== invalid value
     All ciphers are disabled.
@@ -781,6 +831,7 @@ def test_ticket47838_run_last(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.47838_15' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(1)
     topology.standalone.start(timeout=120)
 
     errmsg = os.popen('egrep "SSL alert:" %s | egrep "invalid ciphers"' % topology.standalone.errlog)
@@ -796,46 +847,8 @@ def test_ticket47838_run_last(topology):
     topology.standalone.log.info("ticket47838, 47880, 47908, 47928 were successfully verified.")
 
 
-def test_ticket47838_final(topology):
-    topology.standalone.delete()
-    log.info('Testcase PASSED')
-
-
-def run_isolated():
-    '''
-        run_isolated is used to run these test cases independently of a test scheduler (xunit, py.test..)
-        To run isolated without py.test, you need to
-            - edit this file and comment '@pytest.fixture' line before 'topology' function.
-            - set the installation prefix
-            - run this program
-    '''
-    global installation_prefix
-    installation_prefix = None
-
-    topo = topology(True)
-    test_ticket47838_init(topo)
-
-    test_ticket47838_run_0(topo)
-    test_ticket47838_run_1(topo)
-    test_ticket47838_run_2(topo)
-    test_ticket47838_run_3(topo)
-    test_ticket47838_run_4(topo)
-    test_ticket47838_run_5(topo)
-    test_ticket47838_run_6(topo)
-    test_ticket47838_run_7(topo)
-    test_ticket47838_run_8(topo)
-    test_ticket47838_run_9(topo)
-    test_ticket47838_run_10(topo)
-    test_ticket47838_run_11(topo)
-    test_ticket47928_run_0(topo)
-    test_ticket47928_run_1(topo)
-    test_ticket47928_run_2(topo)
-    test_ticket47928_run_3(topo)
-
-    test_ticket47838_run_last(topo)
-
-    test_ticket47838_final(topo)
-
-
 if __name__ == '__main__':
-    run_isolated()
+    # Run isolated
+    # -s for DEBUG mode
+    CURRENT_FILE = os.path.realpath(__file__)
+    pytest.main("-s %s" % CURRENT_FILE)
