@@ -3,7 +3,7 @@
 # All rights reserved.
 #
 # License: GPL (version 3 or any later version).
-# See LICENSE for details. 
+# See LICENSE for details.
 # --- END COPYRIGHT BLOCK ---
 #
 '''
@@ -123,6 +123,11 @@ def topology(request):
     master2.create()
     master2.open()
 
+    def fin():
+        master1.delete()
+        master2.delete()
+    request.addfinalizer(fin)
+
     #
     # Now prepare the Master-Consumer topology
     #
@@ -469,35 +474,8 @@ def test_ticket47988_6(topology):
     assert (master2_schema_csn)
 
 
-def test_ticket47988_final(topology):
-    topology.master1.delete()
-    topology.master2.delete()
-    log.info('Testcase PASSED')
-
-
-def run_isolated():
-    '''
-        run_isolated is used to run these test cases independently of a test scheduler (xunit, py.test..)
-        To run isolated without py.test, you need to
-            - edit this file and comment '@pytest.fixture' line before 'topology' function.
-            - set the installation prefix
-            - run this program
-    '''
-    global installation1_prefix
-    global installation2_prefix
-    installation1_prefix = None
-    installation2_prefix = None
-
-    topo = topology(True)
-    test_ticket47988_init(topo)
-    test_ticket47988_1(topo)
-    test_ticket47988_2(topo)
-    test_ticket47988_3(topo)
-    test_ticket47988_4(topo)
-    test_ticket47988_5(topo)
-    test_ticket47988_6(topo)
-    test_ticket47988_final(topo)
-
 if __name__ == '__main__':
-    run_isolated()
-
+    # Run isolated
+    # -s for DEBUG mode
+    CURRENT_FILE = os.path.realpath(__file__)
+    pytest.main("-s %s" % CURRENT_FILE)
