@@ -1,9 +1,9 @@
 # --- BEGIN COPYRIGHT BLOCK ---
-# Copyright (C) 2015 Red Hat, Inc.
+# Copyright (C) 2016 Red Hat, Inc.
 # All rights reserved.
 #
 # License: GPL (version 3 or any later version).
-# See LICENSE for details. 
+# See LICENSE for details.
 # --- END COPYRIGHT BLOCK ---
 #
 import os
@@ -22,19 +22,18 @@ from lib389.properties import *
 
 log = logging.getLogger(__name__)
 
-installation_prefix = None
-
 CONFIG_DN = 'cn=config'
 ENCRYPTION_DN = 'cn=encryption,%s' % CONFIG_DN
 RSA = 'RSA'
 RSA_DN = 'cn=%s,%s' % (RSA, ENCRYPTION_DN)
-LDAPSPORT = '10636'
+LDAPSPORT = str(DEFAULT_SECURE_PORT)
 SERVERCERT = 'Server-Cert'
 plus_all_ecount = 0
 plus_all_dcount = 0
 plus_all_ecount_noweak = 0
 plus_all_dcount_noweak = 0
 
+
 class TopologyStandalone(object):
     def __init__(self, standalone):
         standalone.open()
@@ -46,11 +45,8 @@ def topology(request):
     '''
         This fixture is used to standalone topology for the 'module'.
     '''
-    global installation_prefix
-
-    if installation_prefix:
-        args_instance[SER_DEPLOYED_DIR] = installation_prefix
 
+    # Creating standalone instance ...
     standalone = DirSrv(verbose=False)
 
     # Args for the standalone instance
@@ -73,8 +69,9 @@ def topology(request):
     # Used to retrieve configuration information (dbdir, confdir...)
     standalone.open()
 
-    # clear the tmp directory
-    standalone.clearTmpDir(__file__)
+    def fin():
+        standalone.delete()
+    request.addfinalizer(fin)
 
     # Here we have standalone instance up and running
     return TopologyStandalone(standalone)
@@ -86,7 +83,7 @@ def _header(topology, label):
     topology.standalone.log.info("###############################################")
 
 
-def test_ticket48194_init(topology):
+def test_init(topology):
     """
     Generate self signed cert and import it to the DS cert db.
     Enable SSL
@@ -113,6 +110,7 @@ def test_ticket48194_init(topology):
     noisewdfd = open(noisefile, "w")
     noisewdfd.write(noise.readline())
     noisewdfd.close()
+    time.sleep(1)
 
     log.info("\n######################### Create key3.db and cert8.db database ######################\n")
     os.system("ls %s" % pwdfile)
@@ -123,7 +121,8 @@ def test_ticket48194_init(topology):
     os.system('certutil -G -d %s -z %s -f %s' % (conf_dir, noisefile, pwdfile))
 
     log.info("\n######################### Creating self-signed CA certificate ######################\n")
-    os.system('( echo y ; echo ; echo y ) | certutil -S -n "CA certificate" -s "cn=CAcert" -x -t "CT,," -m 1000 -v 120 -d %s -z %s -f %s -2' % (conf_dir, noisefile, pwdfile))
+    os.system('( echo y ; echo ; echo y ) | certutil -S -n "CA certificate" -s "cn=CAcert" -x -t "CT,," -m 1000 -v 120 -d %s -z %s -f %s -2' %
+              (conf_dir, noisefile, pwdfile))
 
     log.info("\n######################### Exporting the CA certificate to cacert.asc ######################\n")
     cafile = '%s/cacert.asc' % conf_dir
@@ -139,7 +138,8 @@ def test_ticket48194_init(topology):
     log.info("\n######################### Generate the server certificate ######################\n")
     ohostname = os.popen('hostname --fqdn', "r")
     myhostname = ohostname.readline()
-    os.system('certutil -S -n "%s" -s "cn=%s,ou=389 Directory Server" -c "CA certificate" -t "u,u,u" -m 1001 -v 120 -d %s -z %s -f %s' % (SERVERCERT, myhostname.rstrip(), conf_dir, noisefile, pwdfile))
+    os.system('certutil -S -n "%s" -s "cn=%s,ou=389 Directory Server" -c "CA certificate" -t "u,u,u" -m 1001 -v 120 -d %s -z %s -f %s' %
+              (SERVERCERT, myhostname.rstrip(), conf_dir, noisefile, pwdfile))
 
     log.info("\n######################### create the pin file ######################\n")
     pinfile = '%s/pin.txt' % (conf_dir)
@@ -147,6 +147,7 @@ def test_ticket48194_init(topology):
     pinfd = open(pinfile, "w")
     pinfd.write(pintxt)
     pinfd.close()
+    time.sleep(1)
 
     log.info("\n######################### enable SSL in the directory server with all ciphers ######################\n")
     topology.standalone.simple_bind_s(DN_DM, PASSWORD)
@@ -166,6 +167,7 @@ def test_ticket48194_init(topology):
                                               'nsSSLToken': 'internal (software)',
                                               'nsSSLActivation': 'on'})))
 
+
 def connectWithOpenssl(topology, cipher, expect):
     """
     Connect with the given cipher
@@ -208,7 +210,8 @@ def connectWithOpenssl(topology, cipher, expect):
                     proc.stdin.close()
                     assert False
 
-def test_ticket48194_run_0(topology):
+
+def test_run_0(topology):
     """
     Check nsSSL3Ciphers: +all
     All ciphers are enabled except null.
@@ -225,7 +228,8 @@ def test_ticket48194_run_0(topology):
     connectWithOpenssl(topology, 'RC4-SHA', True)
     connectWithOpenssl(topology, 'AES256-SHA256', True)
 
-def test_ticket48194_run_1(topology):
+
+def test_run_1(topology):
     """
     Check nsSSL3Ciphers: +all
     All ciphers are enabled except null.
@@ -242,12 +246,14 @@ def test_ticket48194_run_1(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.48194_0' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(2)
     topology.standalone.start(timeout=120)
 
     connectWithOpenssl(topology, 'RC4-SHA', False)
     connectWithOpenssl(topology, 'AES256-SHA256', True)
 
-def test_ticket48194_run_2(topology):
+
+def test_run_2(topology):
     """
     Check nsSSL3Ciphers: +rsa_aes_128_sha,+rsa_aes_256_sha
     rsa_aes_128_sha, tls_rsa_aes_128_sha, rsa_aes_256_sha, tls_rsa_aes_256_sha are enabled.
@@ -262,6 +268,7 @@ def test_ticket48194_run_2(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.48194_1' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(2)
     topology.standalone.start(timeout=120)
 
     connectWithOpenssl(topology, 'RC4-SHA', False)
@@ -269,7 +276,8 @@ def test_ticket48194_run_2(topology):
     connectWithOpenssl(topology, 'AES128-SHA', True)
     connectWithOpenssl(topology, 'AES256-SHA', True)
 
-def test_ticket48194_run_3(topology):
+
+def test_run_3(topology):
     """
     Check nsSSL3Ciphers: -all
     All ciphers are disabled.
@@ -284,12 +292,14 @@ def test_ticket48194_run_3(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.48194_2' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(1)
     topology.standalone.start(timeout=120)
 
     connectWithOpenssl(topology, 'RC4-SHA', False)
     connectWithOpenssl(topology, 'AES256-SHA256', False)
 
-def test_ticket48194_run_4(topology):
+
+def test_run_4(topology):
     """
     Check no nsSSL3Ciphers
     Default ciphers are enabled.
@@ -304,12 +314,14 @@ def test_ticket48194_run_4(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.48194_3' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(2)
     topology.standalone.start(timeout=120)
 
     connectWithOpenssl(topology, 'RC4-SHA', False)
     connectWithOpenssl(topology, 'AES256-SHA256', True)
 
-def test_ticket48194_run_5(topology):
+
+def test_run_5(topology):
     """
     Check nsSSL3Ciphers: default
     Default ciphers are enabled.
@@ -324,14 +336,16 @@ def test_ticket48194_run_5(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.48194_4' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(2)
     topology.standalone.start(timeout=120)
 
     connectWithOpenssl(topology, 'RC4-SHA', False)
     connectWithOpenssl(topology, 'AES256-SHA256', True)
 
-def test_ticket48194_run_6(topology):
+
+def test_run_6(topology):
     """
-    Check nsSSL3Ciphers: +all,-TLS_RSA_WITH_AES_256_CBC_SHA256 
+    Check nsSSL3Ciphers: +all,-TLS_RSA_WITH_AES_256_CBC_SHA256
     All ciphers are disabled.
     default allowWeakCipher
     """
@@ -344,13 +358,15 @@ def test_ticket48194_run_6(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.48194_5' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(2)
     topology.standalone.start(timeout=120)
 
     connectWithOpenssl(topology, 'RC4-SHA', False)
     connectWithOpenssl(topology, 'AES256-SHA256', False)
     connectWithOpenssl(topology, 'AES128-SHA', True)
 
-def test_ticket48194_run_7(topology):
+
+def test_run_7(topology):
     """
     Check nsSSL3Ciphers: -all,+rsa_rc4_128_md5
     All ciphers are disabled.
@@ -365,13 +381,15 @@ def test_ticket48194_run_7(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.48194_6' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(2)
     topology.standalone.start(timeout=120)
 
     connectWithOpenssl(topology, 'RC4-SHA', False)
     connectWithOpenssl(topology, 'AES256-SHA256', False)
     connectWithOpenssl(topology, 'RC4-MD5', True)
 
-def test_ticket48194_run_8(topology):
+
+def test_run_8(topology):
     """
     Check nsSSL3Ciphers: default + allowWeakCipher: off
     Strong Default ciphers are enabled.
@@ -386,12 +404,14 @@ def test_ticket48194_run_8(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.48194_7' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(2)
     topology.standalone.start(timeout=120)
 
     connectWithOpenssl(topology, 'RC4-SHA', False)
     connectWithOpenssl(topology, 'AES256-SHA256', True)
 
-def test_ticket48194_run_9(topology):
+
+def test_run_9(topology):
     """
     Check no nsSSL3Ciphers
     Default ciphers are enabled.
@@ -409,12 +429,14 @@ def test_ticket48194_run_9(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.48194_8' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(2)
     topology.standalone.start(timeout=120)
 
     connectWithOpenssl(topology, 'RC4-SHA', True)
     connectWithOpenssl(topology, 'AES256-SHA256', True)
 
-def test_ticket48194_run_10(topology):
+
+def test_run_10(topology):
     """
     Check nsSSL3Ciphers: -TLS_RSA_WITH_NULL_MD5,+TLS_RSA_WITH_RC4_128_MD5,
         +TLS_RSA_EXPORT_WITH_RC4_40_MD5,+TLS_RSA_EXPORT_WITH_RC2_CBC_40_MD5,
@@ -437,13 +459,15 @@ def test_ticket48194_run_10(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.48194_9' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(1)
     topology.standalone.start(timeout=120)
 
     connectWithOpenssl(topology, 'RC4-SHA', False)
     connectWithOpenssl(topology, 'RC4-MD5', True)
     connectWithOpenssl(topology, 'AES256-SHA256', False)
 
-def test_ticket48194_run_11(topology):
+
+def test_run_11(topology):
     """
     Check nsSSL3Ciphers: +fortezza
     SSL_GetImplementedCiphers does not return this as a secuire cipher suite
@@ -457,43 +481,15 @@ def test_ticket48194_run_11(topology):
     topology.standalone.stop(timeout=10)
     os.system('mv %s %s.48194_10' % (topology.standalone.errlog, topology.standalone.errlog))
     os.system('touch %s' % (topology.standalone.errlog))
+    time.sleep(1)
     topology.standalone.start(timeout=120)
 
     connectWithOpenssl(topology, 'RC4-SHA', False)
     connectWithOpenssl(topology, 'AES256-SHA256', False)
 
-def test_ticket48194_final(topology):
-    topology.standalone.delete()
-    log.info('Testcase PASSED')
-
-def run_isolated():
-    '''
-        run_isolated is used to run these test cases independently of a test scheduler (xunit, py.test..)
-        To run isolated without py.test, you need to
-            - edit this file and comment '@pytest.fixture' line before 'topology' function.
-            - set the installation prefix
-            - run this program
-    '''
-    global installation_prefix
-    installation_prefix = None
-
-    topo = topology(True)
-    test_ticket48194_init(topo)
-
-    test_ticket48194_run_0(topo)
-    test_ticket48194_run_1(topo)
-    test_ticket48194_run_2(topo)
-    test_ticket48194_run_3(topo)
-    test_ticket48194_run_4(topo)
-    test_ticket48194_run_5(topo)
-    test_ticket48194_run_6(topo)
-    test_ticket48194_run_7(topo)
-    test_ticket48194_run_8(topo)
-    test_ticket48194_run_9(topo)
-    test_ticket48194_run_10(topo)
-    test_ticket48194_run_11(topo)
-
-    test_ticket48194_final(topo)
 
 if __name__ == '__main__':
-    run_isolated()
+    # Run isolated
+    # -s for DEBUG mode
+    CURRENT_FILE = os.path.realpath(__file__)
+    pytest.main("-s %s" % CURRENT_FILE)
