@@ -59,13 +59,14 @@ def topology(request):
     # Delete each instance in the end
     def fin():
         standalone.delete()
-    #request.addfinalizer(fin)
+    request.addfinalizer(fin)
 
     # Clear out the tmp dir
     standalone.clearTmpDir(__file__)
 
     return TopologyStandalone(standalone)
 
+
 def test_ticket48745_init(topology):
     log.info("Initialization: add dummy entries for the tests")
     for cpt in range(MAX_ACCOUNTS):
@@ -78,6 +79,7 @@ def test_ticket48745_init(topology):
                                             'gidnumber': str(222),
                                             'homedirectory': "/home/tbordaz_%d" % cpt})))
 
+
 def test_ticket48745_homeDirectory_indexed_cis(topology):
     log.info("\n\nindex homeDirectory in caseIgnoreIA5Match and caseExactIA5Match")
     try:
@@ -102,11 +104,11 @@ def test_ticket48745_homeDirectory_indexed_cis(topology):
     #topology.standalone.start(timeout=10)
     args = {TASK_WAIT: True}
     topology.standalone.tasks.reindex(suffix=SUFFIX, attrname='homeDirectory', args=args)
-    
+
     log.info("Check indexing succeeded with a specified matching rule")
     file_path = os.path.join(topology.standalone.prefix, "var/log/dirsrv/slapd-%s/errors" % topology.standalone.serverid)
     file_obj = open(file_path, "r")
-    
+
     # Check if the MR configuration failure occurs
     regex = re.compile("unknown or invalid matching rule")
     while True:
@@ -114,21 +116,23 @@ def test_ticket48745_homeDirectory_indexed_cis(topology):
         found = regex.search(line)
         if ((line == '') or (found)):
             break
-        
+
     if (found):
         log.info("The configuration of a specific MR fails")
         log.info(line)
         assert 0
 
+
 def test_ticket48745_homeDirectory_mixed_value(topology):
     # Set a homedirectory value with mixed case
     name = "uid=%s1,%s" % (NEW_ACCOUNT, SUFFIX)
     mod = [(ldap.MOD_REPLACE, 'homeDirectory', MIXED_VALUE)]
     topology.standalone.modify_s(name, mod)
 
+
 def test_ticket48745_extensible_search_after_index(topology):
     name = "uid=%s1,%s" % (NEW_ACCOUNT, SUFFIX)
-    
+
     # check with the exact stored value
     log.info("Default: can retrieve an entry filter syntax with exact stored value")
     ent = topology.standalone.getEntry(SUFFIX, ldap.SCOPE_SUBTREE, "(homeDirectory=%s)" % MIXED_VALUE)
@@ -159,27 +163,9 @@ def test_ticket48745_extensible_search_after_index(topology):
     log.info("Default: can retrieve an entry filter caseIgnoreIA5Match with lowered stored value")
     ent = topology.standalone.getEntry(SUFFIX, ldap.SCOPE_SUBTREE, "(homeDirectory:caseIgnoreIA5Match:=%s)" % LOWER_VALUE)
 
-def test_ticket48745(topology):
-    """Write your testcase here...
-
-    Also, if you need any testcase initialization,
-    please, write additional fixture for that(include finalizer).
-    """
-
-    log.info('Test complete')
-
 
 if __name__ == '__main__':
     # Run isolated
     # -s for DEBUG mode
-#     global installation1_prefix
-#     installation1_prefix = None
-#     topo = topology(True)
-#     test_ticket48745_init(topo)
-# 
-#     test_ticket48745_homeDirectory_indexed_cis(topo)
-#     test_ticket48745_homeDirectory_mixed_value(topo)
-#     test_ticket48745_extensible_search_after_index(topo)
-
     CURRENT_FILE = os.path.realpath(__file__)
     pytest.main("-s %s" % CURRENT_FILE)
