@@ -59,7 +59,7 @@ def topology(request):
     # Delete each instance in the end
     def fin():
         standalone.delete()
-    #request.addfinalizer(fin)
+    request.addfinalizer(fin)
 
     # Clear out the tmp dir
     standalone.clearTmpDir(__file__)
@@ -102,11 +102,11 @@ def test_ticket48746_homeDirectory_indexed_cis(topology):
     #topology.standalone.start(timeout=10)
     args = {TASK_WAIT: True}
     topology.standalone.tasks.reindex(suffix=SUFFIX, attrname='homeDirectory', args=args)
-    
+
     log.info("Check indexing succeeded with a specified matching rule")
     file_path = os.path.join(topology.standalone.prefix, "var/log/dirsrv/slapd-%s/errors" % topology.standalone.serverid)
     file_obj = open(file_path, "r")
-    
+
     # Check if the MR configuration failure occurs
     regex = re.compile("unknown or invalid matching rule")
     while True:
@@ -114,7 +114,7 @@ def test_ticket48746_homeDirectory_indexed_cis(topology):
         found = regex.search(line)
         if ((line == '') or (found)):
             break
-        
+
     if (found):
         log.info("The configuration of a specific MR fails")
         log.info(line)
@@ -128,7 +128,7 @@ def test_ticket48746_homeDirectory_mixed_value(topology):
 
 def test_ticket48746_extensible_search_after_index(topology):
     name = "uid=%s1,%s" % (NEW_ACCOUNT, SUFFIX)
-    
+
     # check with the exact stored value
 #     log.info("Default: can retrieve an entry filter syntax with exact stored value")
 #     ent = topology.standalone.getEntry(name, ldap.SCOPE_BASE, "(homeDirectory=%s)" % MIXED_VALUE)
@@ -166,11 +166,11 @@ def test_ticket48746_homeDirectory_indexed_ces(topology):
     #topology.standalone.start(timeout=10)
     args = {TASK_WAIT: True}
     topology.standalone.tasks.reindex(suffix=SUFFIX, attrname='homeDirectory', args=args)
-    
+
     log.info("Check indexing succeeded with a specified matching rule")
     file_path = os.path.join(topology.standalone.prefix, "var/log/dirsrv/slapd-%s/errors" % topology.standalone.serverid)
     file_obj = open(file_path, "r")
-    
+
     # Check if the MR configuration failure occurs
     regex = re.compile("unknown or invalid matching rule")
     while True:
@@ -178,36 +178,15 @@ def test_ticket48746_homeDirectory_indexed_ces(topology):
         found = regex.search(line)
         if ((line == '') or (found)):
             break
-        
+
     if (found):
         log.info("The configuration of a specific MR fails")
         log.info(line)
         assert not found
 
-def test_ticket48746(topology):
-    """Write your testcase here...
-
-    Also, if you need any testcase initialization,
-    please, write additional fixture for that(include finalizer).
-    """
-
-    log.info('Test complete')
-
 
 if __name__ == '__main__':
     # Run isolated
     # -s for DEBUG mode
-#     global installation1_prefix
-#     installation1_prefix = None
-#     topo = topology(True)
-#     test_ticket48746_init(topo)
-#     
-# 
-#     test_ticket48746_homeDirectory_indexed_cis(topo)
-#     test_ticket48746_homeDirectory_mixed_value(topo)
-#     test_ticket48746_extensible_search_after_index(topo)
-#     # crash should occur here
-#     test_ticket48746_homeDirectory_indexed_ces(topo)
-    
     CURRENT_FILE = os.path.realpath(__file__)
     pytest.main("-s %s" % CURRENT_FILE)
