@@ -25,6 +25,7 @@ use sigtrap qw(die normal-signals);
 use Archive::Tar;
 use IO::Uncompress::AnyUncompress qw($AnyUncompressError);
 use Scalar::Util qw(looks_like_number);
+use DB;
 
 Getopt::Long::Configure ("bundling");
 Getopt::Long::Configure ("permute");
@@ -45,10 +46,10 @@ my $logversion = "8.2";
 my $sizeCount = "20";
 my $startFlag = 0;
 my $startTime = 0;
-my $startTimeInSecs = 0;
+my $startTimeInNsecs = 0;
 my $endFlag = 0;
 my $endTime = 0;
-my $endTimeInSecs = 0;
+my $endTimeInNsecs = 0;
 my $minEtime = 0;
 my $reportStats = "";
 my $dataLocation = "/tmp";
@@ -366,8 +367,8 @@ my %monthname = (
 #
 if ($startTime and $endTime){
 	# Make sure the end time is not earlier than the start time
-	my $testStart = convertTimeToSeconds($startTime);
-	my $testEnd = convertTimeToSeconds($endTime);
+	my $testStart = convertTimeToNanoseconds($startTime);
+	my $testEnd = convertTimeToNanoseconds($endTime);
 	if ($testStart > $testEnd){
 		print "Start time ($startTime) is greater than end time ($endTime)!\n";
 		exit 1;
@@ -393,7 +394,11 @@ sub statusreport {
 #                                        # 
 ##########################################
 
-if ($files[$#files] =~ m/access.rotationinfo/) {  $file_count--; }
+if ($files[$#files] =~ m/access.rotationinfo/) {
+	# Remove the rotationinfo file from the log array
+	delete $files[$#files];
+	$file_count--;
+}
 $logCount = $file_count;
 
 print "Processing $logCount Access Log(s)...\n";
@@ -403,10 +408,16 @@ print "Processing $logCount Access Log(s)...\n";
 #print "--------------------------------------------------\n";
 
 my $skipFirstFile = 0;
-if ($logCount > 1 && $files[0] =~ /\/access$/){
-	$files[$logCount] = $files[0];
-	$skipFirstFile = 1;
-	$file_count++;
+if ($logCount > 1){
+	# sort the log array
+	my @sorted_files = sort @files;
+	if($sorted_files[0] =~ /access$/){
+		# Move "access" to the end of the array
+		$sorted_files[$logCount] = $sorted_files[0];
+		$skipFirstFile = 1;
+		$file_count++;
+	}
+	@files = @sorted_files;
 }
 
 
@@ -466,7 +477,7 @@ sub doUncompress {
 	return $TARFH;
 }
 
-sub convertTimeToSeconds {
+sub convertTimeToNanoseconds {
 	my $log_line = shift;
 
 	my $logDate;
@@ -501,11 +512,11 @@ sub convertTimeToSeconds {
 
 	my $logTime;
 	my @timeComps;
-	my ($timeHour, $timeMinute, $timeSecond, $timeTotal);
+	my ($timeHour, $timeMinute, $timeSecond, $timeNanosecond, $timeTotal);
 	$timeTotal = 0;
-	if ($log_line =~ / *(:[0-9:]+)/i ){
+	if ($log_line =~ / *(:[0-9:\.]+)/i ){
 		$logTime = $1;
-		@timeComps = split /:/, $logTime;
+		@timeComps = split /:|\./, $logTime;
 		if ($#timeComps < 3) {
 			print "The time string ($log_line) is invalid, exiting...\n";
 			exit(1);
@@ -522,20 +533,26 @@ sub convertTimeToSeconds {
 			print "The time string ($log_line) has invalid second ($timeComps[3]), exiting...\n";
 			exit(1);
 		}
+		if ($#timeComps < 4 || !looks_like_number($timeComps[4]) || length $timeComps[4] != 9){
+			# This isn't an error for nano seconds, we just assume old log format and set nsec to 0
+			$timeNanosecond = 0;
+		} else {
+			$timeNanosecond = $timeComps[4];
+		}
 		$timeHour = $timeComps[1] * 3600;
 		$timeMinute = $timeComps[2] * 60;
 		$timeSecond = $timeComps[3];
 		$timeTotal = $timeHour + $timeMinute + $timeSecond;
 	}
 
-	return $timeTotal + $dateTotal;
+	return (($timeTotal + $dateTotal) * 1000000000) + $timeNanosecond;
 }
 
 if($startTime){
-	$startTimeInSecs = convertTimeToSeconds($startTime);
+	$startTimeInNsecs = convertTimeToNanoseconds($startTime);
 }
 if($endTime){
-	$endTimeInSecs = convertTimeToSeconds($endTime);
+	$endTimeInNsecs = convertTimeToNanoseconds($endTime);
 }
 
 $Archive::Tar::WARN = 0; # so new will shut up when reading a regular file
@@ -667,58 +684,61 @@ $allOps = $srchCount + $modCount + $addCount + $cmpCount + $delCount + $modrdnCo
 
 my $start;
 if($startTime){
-	if ($start =~ / *([0-9a-z:\/]+)/i){$start=$1;}
+	if ($start =~ / *([0-9a-z:\/\.]+)/i){$start=$1;}
 }
 my $end;
 if($endTime){
-	if ($end =~ / *([0-9a-z:\/]+)/i){$end =$1;}
+	if ($end =~ / *([0-9a-z:\/\.]+)/i){$end =$1;}
 }
 
 #
 # Get the start time in seconds
 #  
 my $logStart = $start;
-my $startTotal = convertTimeToSeconds($logStart);
+my $startTotal = convertTimeToNanoseconds($logStart);
 
 #
 # Get the end time in seconds
 #
 my $logEnd = $end;
-my $endTotal = convertTimeToSeconds($logEnd);
+my $endTotal = convertTimeToNanoseconds($logEnd);
 
 #
 # Tally the numbers
 #
-my $totalTimeInSecs = $endTotal - $startTotal;
-my $remainingTimeInSecs = $totalTimeInSecs;
+my $totalTimeInNsecs = $endTotal - $startTotal;
+my $remainingTimeInNsecs = $totalTimeInNsecs;
+
+my $totalTimeInSecs = $totalTimeInNsecs / 1000000000;
+my $remainingTimeInSecs = $remainingTimeInNsecs / 1000000000;
 
 #
 # Calculate the elapsed time
 #
 
 # days
-while(($remainingTimeInSecs - 86400) > 0){
+while(($remainingTimeInNsecs - (86400 * 1000000000)) > 0){
 	$elapsedDays++;
-	$remainingTimeInSecs =  $remainingTimeInSecs - 86400;
+	$remainingTimeInNsecs =  $remainingTimeInNsecs - (86400 * 1000000000);
 
 }
 
 # hours
 my $elapsedHours = 0;
-while(($remainingTimeInSecs - 3600) > 0){
+while(($remainingTimeInNsecs - (3600 * 1000000000 )) > 0){
 	$elapsedHours++;
-	$remainingTimeInSecs = $remainingTimeInSecs - 3600;
+	$remainingTimeInNsecs = $remainingTimeInNsecs - (3600 * 1000000000);
 }
 
 # minutes
 my $elapsedMinutes = 0;
-while($remainingTimeInSecs - 60 > 0){
+while($remainingTimeInNsecs - (60 * 1000000000) > 0){
 	$elapsedMinutes++;
-	$remainingTimeInSecs = $remainingTimeInSecs - 60;
+	$remainingTimeInNsecs = $remainingTimeInNsecs - (60 * 1000000000);
 }
 
 # seconds
-my $elapsedSeconds = $remainingTimeInSecs;
+my $elapsedSeconds = $remainingTimeInNsecs / 1000000000;
 
 #####################################
 #                                   #
@@ -754,19 +774,34 @@ if($reportStats ne ""){
 #
 # Generate stats first
 #
-$connStat = sprintf "(%.2f/sec)  (%.2f/min)\n",($connectionCount / $totalTimeInSecs), $connectionCount / ($totalTimeInSecs/60);
-$ldapiConnStat = sprintf "(%.2f/sec)  (%.2f/min)\n",($ldapiCount / $totalTimeInSecs), $ldapiCount / ($totalTimeInSecs/60);
-$sslConnStat = sprintf "(%.2f/sec)  (%.2f/min)\n",($sslCount / $totalTimeInSecs), $sslCount / ($totalTimeInSecs/60);
-$tlsConnStat = sprintf "(%.2f/sec)  (%.2f/min)\n",($startTLSCount / $totalTimeInSecs), $startTLSCount / ($totalTimeInSecs/60);
-$ldapConnStat = sprintf "(%.2f/sec)  (%.2f/min)\n",(($connectionCount - $sslCount - $ldapiCount) / $totalTimeInSecs),
-                                                    ($connectionCount - $sslCount - $ldapiCount) / ($totalTimeInSecs/60);
-$searchStat = sprintf "(%.2f/sec)  (%.2f/min)\n",($srchCount / $totalTimeInSecs), $srchCount / ($totalTimeInSecs/60);
-$modStat = sprintf "(%.2f/sec)  (%.2f/min)\n",$modCount / $totalTimeInSecs, $modCount/($totalTimeInSecs/60);
-$addStat = sprintf "(%.2f/sec)  (%.2f/min)\n",$addCount/$totalTimeInSecs, $addCount/($totalTimeInSecs/60);
-$deleteStat = sprintf "(%.2f/sec)  (%.2f/min)\n",$delCount/$totalTimeInSecs, $delCount/($totalTimeInSecs/60);
-$modrdnStat = sprintf "(%.2f/sec)  (%.2f/min)\n",$modrdnCount/$totalTimeInSecs, $modrdnCount/($totalTimeInSecs/60);
-$compareStat = sprintf "(%.2f/sec)  (%.2f/min)\n",$cmpCount/$totalTimeInSecs, $cmpCount/($totalTimeInSecs/60);
-$bindCountStat = sprintf "(%.2f/sec)  (%.2f/min)\n",$bindCount/$totalTimeInSecs, $bindCount/($totalTimeInSecs/60);
+if ($totalTimeInNsecs == 0){
+	$connStat = sprintf "(%.2f/sec)  (%.2f/min)\n","0", "0";
+	$ldapiConnStat = sprintf "(%.2f/sec)  (%.2f/min)\n","0", "0";
+	$sslConnStat = sprintf "(%.2f/sec)  (%.2f/min)\n","0", "0";
+	$tlsConnStat = sprintf "(%.2f/sec)  (%.2f/min)\n","0", "0";
+	$ldapConnStat = sprintf "(%.2f/sec)  (%.2f/min)\n","0", "0";
+	$searchStat = sprintf "(%.2f/sec)  (%.2f/min)\n","0", "0";
+	$modStat = sprintf "(%.2f/sec)  (%.2f/min)\n","0", "0";
+	$addStat = sprintf "(%.2f/sec)  (%.2f/min)\n","0", "0";
+	$deleteStat = sprintf "(%.2f/sec)  (%.2f/min)\n","0", "0";
+	$modrdnStat = sprintf "(%.2f/sec)  (%.2f/min)\n","0", "0";
+	$compareStat = sprintf "(%.2f/sec)  (%.2f/min)\n","0", "0";
+	$bindCountStat = sprintf "(%.2f/sec)  (%.2f/min)\n","0", "0";
+} else {
+	$connStat = sprintf "(%.2f/sec)  (%.2f/min)\n",($connectionCount / $totalTimeInSecs), $connectionCount / ($totalTimeInSecs/60);
+	$ldapiConnStat = sprintf "(%.2f/sec)  (%.2f/min)\n",($ldapiCount / $totalTimeInSecs), $ldapiCount / ($totalTimeInSecs/60);
+	$sslConnStat = sprintf "(%.2f/sec)  (%.2f/min)\n",($sslCount / $totalTimeInSecs), $sslCount / ($totalTimeInSecs/60);
+	$tlsConnStat = sprintf "(%.2f/sec)  (%.2f/min)\n",($startTLSCount / $totalTimeInSecs), $startTLSCount / ($totalTimeInSecs/60);
+	$ldapConnStat = sprintf "(%.2f/sec)  (%.2f/min)\n",(($connectionCount - $sslCount - $ldapiCount) / $totalTimeInSecs),
+                                                            ($connectionCount - $sslCount - $ldapiCount) / ($totalTimeInSecs/60);
+	$searchStat = sprintf "(%.2f/sec)  (%.2f/min)\n",($srchCount / $totalTimeInSecs), $srchCount / ($totalTimeInSecs/60);
+	$modStat = sprintf "(%.2f/sec)  (%.2f/min)\n",$modCount / $totalTimeInSecs, $modCount/($totalTimeInSecs/60);
+	$addStat = sprintf "(%.2f/sec)  (%.2f/min)\n",$addCount/$totalTimeInSecs, $addCount/($totalTimeInSecs/60);
+	$deleteStat = sprintf "(%.2f/sec)  (%.2f/min)\n",$delCount/$totalTimeInSecs, $delCount/($totalTimeInSecs/60);
+	$modrdnStat = sprintf "(%.2f/sec)  (%.2f/min)\n",$modrdnCount/$totalTimeInSecs, $modrdnCount/($totalTimeInSecs/60);
+	$compareStat = sprintf "(%.2f/sec)  (%.2f/min)\n",$cmpCount/$totalTimeInSecs, $cmpCount/($totalTimeInSecs/60);
+	$bindCountStat = sprintf "(%.2f/sec)  (%.2f/min)\n",$bindCount/$totalTimeInSecs, $bindCount/($totalTimeInSecs/60);
+}
 
 #
 # Continue with standard report
@@ -1697,15 +1732,15 @@ parseLineBind {
 
 	if($firstFile == 1 && $_ =~ /^\[/){
 		$start = $_;
-		if ($start =~ / *([0-9a-z:\/]+)/i){$start=$1;}
+		if ($start =~ / *([0-9a-z:\/\.]+)/i){$start=$1;}
 		$firstFile = 0;
 	}
-	if ($endFlag != 1 && $_ =~ /^\[/ && $_ =~ / *([0-9a-z:\/]+)/i){
+	if ($endFlag != 1 && $_ =~ /^\[/ && $_ =~ / *([0-9a-z:\/\.]+)/i){
 		$end =$1;
 	}
 	if ($startTime && !$startFlag) {
-		my $currentTimeInSecs = convertTimeToSeconds($_);
-		if ($currentTimeInSecs >= $startTimeInSecs) {
+		my $currentTimeInNsecs = convertTimeToNanoseconds($_);
+		if ($currentTimeInNsecs >= $startTimeInNsecs) {
 			$startFlag = 1;
 			($start) = $startTime =~ /\D*(\S*)/;
 		} else {
@@ -1713,8 +1748,8 @@ parseLineBind {
 		}
 	}
 	if ($endTime && !$endFlag) {
-		my $currentTimeInSecs = convertTimeToSeconds($_);
-		if ($currentTimeInSecs > $endTimeInSecs) {
+		my $currentTimeInNsecs = convertTimeToNanoseconds($_);
+		if ($currentTimeInNsecs > $endTimeInNsecs) {
 			$endFlag = 1;
 			($end) = $endTime =~ /\D*(\S*)/;
 		}
@@ -1867,15 +1902,15 @@ sub parseLineNormal
 	if($firstFile == 1 && $_ =~ /^\[/){
 		# if we are using startTime & endTime, this will get overwritten, which is ok
 		$start = $_;
-		if ($start =~ / *([0-9a-z:\/]+)/i){$start=$1;}
+		if ($start =~ / *([0-9a-z:\/\.]+)/i){$start=$1;}
 		$firstFile = 0;
 	}
-	if ($endFlag != 1 && $_ =~ /^\[/ && $_ =~ / *([0-9a-z:\/]+)/i){
+	if ($endFlag != 1 && $_ =~ /^\[/ && $_ =~ / *([0-9a-z:\/\.]+)/i){
 		$end =$1;
 	}
 	if ($startTime && !$startFlag) {
-		my $currentTimeInSecs = convertTimeToSeconds($_);
-		if ($currentTimeInSecs >= $startTimeInSecs) {
+		my $currentTimeInNsecs = convertTimeToNanoseconds($_);
+		if ($currentTimeInNsecs >= $startTimeInNsecs) {
 			$startFlag = 1;
 			($start) = $startTime =~ /\D*(\S*)/;
 		} else {
@@ -1883,8 +1918,8 @@ sub parseLineNormal
 		}
 	}
 	if ($endTime && !$endFlag) {
-		my $currentTimeInSecs = convertTimeToSeconds($_);
-		if ($currentTimeInSecs > $endTimeInSecs) {
+		my $currentTimeInNsecs = convertTimeToNanoseconds($_);
+		if ($currentTimeInNsecs > $endTimeInNsecs) {
 			$endFlag = 1;
 			($end) = $endTime =~ /\D*(\S*)/;
 		}
