@@ -65,6 +65,13 @@ typedef struct _memberof_get_groups_data
         Slapi_ValueSet **group_norm_vals;
 } memberof_get_groups_data;
 
+typedef struct _task_data
+{
+	char *dn;
+	char *bind_dn;
+	char *filter_str;
+} task_data;
+
 /*** function prototypes ***/
 
 /* exported functions */
@@ -142,7 +149,7 @@ static void memberof_task_destructor(Slapi_Task *task);
 static const char *fetch_attr(Slapi_Entry *e, const char *attrname,
                                               const char *default_val);
 static void memberof_fixup_task_thread(void *arg);
-static int memberof_fix_memberof(MemberOfConfig *config, char *dn, char *filter_str);
+static int memberof_fix_memberof(MemberOfConfig *config, Slapi_Task *task, task_data *td);
 static int memberof_fix_memberof_callback(Slapi_Entry *e, void *callback_data);
 static int memberof_entry_in_scope(MemberOfConfig *config, Slapi_DN *sdn);
 static int memberof_add_objectclass(char *auto_add_oc, const char *dn);
@@ -543,7 +550,7 @@ int memberof_postop_del(Slapi_PBlock *pb)
 			Slapi_Attr *attr = 0;
 
 			/* Loop through to find each grouping attribute separately. */
-			for (i = 0; configCopy.groupattrs[i] && ret == LDAP_SUCCESS; i++)
+			for (i = 0; configCopy.groupattrs && configCopy.groupattrs[i] && ret == LDAP_SUCCESS; i++)
 			{
 				if (0 == slapi_entry_attr_find(e, configCopy.groupattrs[i], &attr))
 				{
@@ -859,7 +866,7 @@ int memberof_postop_modrdn(Slapi_PBlock *pb)
 
 			/* get a list of member attributes present in the group
 			 * entry that is being renamed. */
-			for (i = 0; configCopy.groupattrs[i]; i++)
+			for (i = 0; configCopy.groupattrs && configCopy.groupattrs[i]; i++)
 			{
 				if(0 == slapi_entry_attr_find(post_e, configCopy.groupattrs[i], &attr))
 				{
@@ -893,7 +900,7 @@ int memberof_postop_modrdn(Slapi_PBlock *pb)
 					Slapi_Attr *attr = 0;
 
 					/* Loop through to find each grouping attribute separately. */
-					for (i = 0; configCopy.groupattrs[i] && ret == LDAP_SUCCESS; i++) {
+					for (i = 0; configCopy.groupattrs && configCopy.groupattrs[i] && ret == LDAP_SUCCESS; i++) {
 						if (0 == slapi_entry_attr_find(pre_e, configCopy.groupattrs[i], &attr)) {
 							if((ret = memberof_del_attr_list(pb, &configCopy, pre_sdn, attr))){
 								slapi_log_error( SLAPI_LOG_FATAL, MEMBEROF_PLUGIN_SUBSYSTEM,
@@ -1641,7 +1648,7 @@ memberof_modop_one_replace_r(Slapi_PBlock *pb, MemberOfConfig *config,
 		ll->next = stack;
 		
 		/* Go through each grouping attribute one at a time. */
-		for (i = 0; config->groupattrs[i]; i++)
+		for (i = 0; config->groupattrs && config->groupattrs[i]; i++)
 		{
 			slapi_entry_attr_find( e, config->groupattrs[i], &members );
 			if(members)
@@ -2158,7 +2165,7 @@ int memberof_is_direct_member(MemberOfConfig *config, Slapi_Value *groupdn,
 	if(group_e)
 	{
 		/* See if memberdn is referred to by any of the group attributes. */
-		for (i = 0; config->groupattrs[i]; i++)
+		for (i = 0; config->groupattrs && config->groupattrs[i]; i++)
 		{
 			slapi_entry_attr_find(group_e, config->groupattrs[i], &attr );
 			if(attr && (0 == slapi_attr_value_find(attr, slapi_value_get_berval(memberdn))))
@@ -2187,7 +2194,7 @@ static int memberof_is_grouping_attr(char *type, MemberOfConfig *config)
 	int match = 0;
 	int i = 0;
 
-	for (i = 0; config && config->groupattrs[i]; i++)
+	for (i = 0; config && config->groupattrs && config->groupattrs[i]; i++)
 	{
 		match = slapi_attr_types_equivalent(type, config->groupattrs[i]);
 		if (match)
@@ -2412,7 +2419,7 @@ memberof_replace_list(Slapi_PBlock *pb, MemberOfConfig *config,
 	slapi_pblock_get( pb, SLAPI_ENTRY_PRE_OP, &pre_e );
 	slapi_pblock_get( pb, SLAPI_ENTRY_POST_OP, &post_e );
 		
-	for (i = 0; config && config->groupattrs[i]; i++)
+	for (i = 0; config && config->groupattrs && config->groupattrs[i]; i++)
 	{
 		if(pre_e && post_e)
 		{
@@ -2625,13 +2632,6 @@ void memberof_unlock()
 	}
 }
 
-typedef struct _task_data
-{
-	char *dn;
-	char *bind_dn;
-	char *filter_str;
-} task_data;
-
 void memberof_fixup_task_thread(void *arg)
 {
 	MemberOfConfig configCopy = {0, 0, 0, 0};
@@ -2646,6 +2646,7 @@ void memberof_fixup_task_thread(void *arg)
 	slapi_task_inc_refcount(task);
 	slapi_log_error(SLAPI_LOG_PLUGIN, MEMBEROF_PLUGIN_SUBSYSTEM,
 	                "memberof_fixup_task_thread --> refcount incremented.\n" );
+
 	/* Fetch our task data from the task */
 	td = (task_data *)slapi_task_get_data(task);
 
@@ -2653,10 +2654,10 @@ void memberof_fixup_task_thread(void *arg)
 	slapi_td_set_dn(slapi_ch_strdup(td->bind_dn));
 
 	slapi_task_begin(task, 1);
-	slapi_task_log_notice(task, "Memberof task starts (arg: %s) ...\n", 
+	slapi_task_log_notice(task, "Memberof task starts (filter: %s) ...\n", 
 	                      td->filter_str);
 	slapi_log_error(SLAPI_LOG_FATAL, MEMBEROF_PLUGIN_SUBSYSTEM,
-	                "Memberof task starts (arg: %s) ...\n", td->filter_str);
+	                "Memberof task starts (filter: \"%s\") ...\n", td->filter_str);
 
 	/* We need to get the config lock first.  Trying to get the
 	 * config lock after we already hold the op lock can cause
@@ -2671,7 +2672,7 @@ void memberof_fixup_task_thread(void *arg)
 
 	if (usetxn) {
 		Slapi_DN *sdn = slapi_sdn_new_dn_byref(td->dn);
-		Slapi_Backend *be = slapi_be_select(sdn);
+		Slapi_Backend *be = slapi_be_select_exact(sdn);
 		slapi_sdn_free(&sdn);
 		if (be) {
 			fixup_pb = slapi_pblock_new();
@@ -2679,12 +2680,18 @@ void memberof_fixup_task_thread(void *arg)
 			rc = slapi_back_transaction_begin(fixup_pb);
 			if (rc) {
 				slapi_log_error(SLAPI_LOG_FATAL, MEMBEROF_PLUGIN_SUBSYSTEM,
-				  "memberof_fixup_task_thread: failed to start transaction\n");
+					"memberof_fixup_task_thread: failed to start transaction\n");
+				goto done;
 			}
 		} else {
 			slapi_log_error(SLAPI_LOG_FATAL, MEMBEROF_PLUGIN_SUBSYSTEM,
-			  "memberof_fixup_task_thread: failed to get be backend from %s\n",
-			  td->dn);
+				"memberof_fixup_task_thread: failed to get be backend from (%s)\n",
+				td->dn);
+			slapi_task_log_notice(task, "Memberof task - Failed to get be backend from (%s)\n",
+			                      td->dn);
+			rc = -1;
+			goto done;
+
 		}
 	}
 
@@ -2692,13 +2699,14 @@ void memberof_fixup_task_thread(void *arg)
 	memberof_lock();
 
 	/* do real work */
-	rc = memberof_fix_memberof(&configCopy, td->dn, td->filter_str);
+	rc = memberof_fix_memberof(&configCopy, task, td);
  
 	/* release the memberOf operation lock */
 	memberof_unlock();
 
+done:
 	if (usetxn && fixup_pb) {
-		if (rc) { /* failes */
+		if (rc) { /* failed */
 			slapi_back_transaction_abort(fixup_pb);
 		} else {
 			slapi_back_transaction_commit(fixup_pb);
@@ -2711,7 +2719,8 @@ void memberof_fixup_task_thread(void *arg)
 	slapi_task_log_status(task, "Memberof task finished.");
 	slapi_task_inc_progress(task);
 	slapi_log_error(SLAPI_LOG_FATAL, MEMBEROF_PLUGIN_SUBSYSTEM,
-	                "Memberof task finished (arg: %s) ...\n", td->filter_str);
+	                "Memberof task finished (filter: %s) result: %d\n",
+	                td->filter_str, rc);
 
 	/* this will queue the destruction of the task */
 	slapi_task_finish(task, rc);
@@ -2829,13 +2838,13 @@ memberof_task_destructor(Slapi_Task *task)
 		"memberof_task_destructor <--\n" );
 }
 
-int memberof_fix_memberof(MemberOfConfig *config, char *dn, char *filter_str)
+int memberof_fix_memberof(MemberOfConfig *config, Slapi_Task *task, task_data *td)
 {
 	int rc = 0;
 	Slapi_PBlock *search_pb = slapi_pblock_new();
 
-	slapi_search_internal_set_pb(search_pb, dn,
-		LDAP_SCOPE_SUBTREE, filter_str, 0, 0,
+	slapi_search_internal_set_pb(search_pb, td->dn,
+		LDAP_SCOPE_SUBTREE, td->filter_str, 0, 0,
 		0, 0,
 		memberof_get_plugin_id(),
 		0);	
@@ -2844,6 +2853,16 @@ int memberof_fix_memberof(MemberOfConfig *config, char *dn, char *filter_str)
 		config,
 		0, memberof_fix_memberof_callback,
 		0);
+	if (rc){
+		char *errmsg;
+		int result;
+
+		slapi_pblock_get(search_pb, SLAPI_PLUGIN_INTOP_RESULT, &result);
+		errmsg = ldap_err2string(result);
+		slapi_log_error(SLAPI_LOG_FATAL, MEMBEROF_PLUGIN_SUBSYSTEM,
+			"memberof_fix_memberof - Failed (%s)\n", errmsg );
+		slapi_task_log_notice(task, "Memberof task failed (%s)\n", errmsg );
+	}
 
 	slapi_pblock_destroy(search_pb);
 
