@@ -533,8 +533,9 @@ my_ber_scanf_value(BerElement *ber, Slapi_Value **value, PRBool *deleted)
 		goto loser;
 	}
 	
-    if (attrval)
-        ber_bvfree(attrval); 
+	if (attrval)
+		ber_bvfree(attrval);
+
 	return 0;
 
 loser:
@@ -866,8 +867,7 @@ multimaster_extop_NSDS50ReplicationEntry(Slapi_PBlock  *pb)
 						rc, connid, opid);
 	}
    
-    if (rc != 0)
-    {
+    if (LDAP_SUCCESS != rc) {
         /* just disconnect from the supplier. bulk import is stopped when
            connection object is destroyed */
         slapi_pblock_get (pb, SLAPI_CONNECTION, &conn);
