@@ -360,7 +360,7 @@ _usn_mod_next_usn(LDAPMod ***mods, Slapi_Backend *be)
 
     /* add next USN to the mods; "be" contains the usn counter */
     usn_berval.bv_val = counter_buf;
-    PR_snprintf(usn_berval.bv_val, USN_COUNTER_BUF_LEN, "%" NSPRIu64, 
+    snprintf(usn_berval.bv_val, USN_COUNTER_BUF_LEN, "%" NSPRIu64,
                 slapi_counter_get_value(be->be_usn_counter));
     usn_berval.bv_len = strlen(usn_berval.bv_val);
     bvals[0] = &usn_berval;
@@ -670,7 +670,7 @@ usn_rootdse_search(Slapi_PBlock *pb, Slapi_Entry* e, Slapi_Entry* entryAfter,
         /* nsslapd-entryusn-global: on*/
         /* root dse shows ...
          * lastusn: <num> */
-        PR_snprintf(attr, USN_LAST_USN_ATTR_CORE_LEN + 1, "%s", USN_LAST_USN);
+        snprintf(attr, USN_LAST_USN_ATTR_CORE_LEN + 1, "%s", USN_LAST_USN);
         for (be = slapi_get_first_backend(&cookie); be;
              be = slapi_get_next_backend(cookie)) {
             if (be->be_usn_counter) {
@@ -681,10 +681,10 @@ usn_rootdse_search(Slapi_PBlock *pb, Slapi_Entry* e, Slapi_Entry* entryAfter,
             /* get a next USN counter from be_usn_counter; 
              * then minus 1 from it (except if be_usn_counter has value 0) */
             if (slapi_counter_get_value(be->be_usn_counter)) {
-                PR_snprintf(usn_berval.bv_val, USN_COUNTER_BUF_LEN, "%" NSPRIu64,
+                snprintf(usn_berval.bv_val, USN_COUNTER_BUF_LEN, "%" NSPRIu64,
                             slapi_counter_get_value(be->be_usn_counter)-1);
             } else {
-                PR_snprintf(usn_berval.bv_val, USN_COUNTER_BUF_LEN, "-1");
+                snprintf(usn_berval.bv_val, USN_COUNTER_BUF_LEN, "-1");
             }
             usn_berval.bv_len = strlen(usn_berval.bv_val);
             slapi_entry_attr_replace(e, attr, vals);
@@ -693,7 +693,7 @@ usn_rootdse_search(Slapi_PBlock *pb, Slapi_Entry* e, Slapi_Entry* entryAfter,
         /* nsslapd-entryusn-global: off (default) */
         /* root dse shows ...
          * lastusn;<backend>: <num> */
-        PR_snprintf(attr, USN_LAST_USN_ATTR_CORE_LEN + 2, "%s;", USN_LAST_USN);
+        snprintf(attr, USN_LAST_USN_ATTR_CORE_LEN + 2, "%s;", USN_LAST_USN);
         attr_subp = attr + USN_LAST_USN_ATTR_CORE_LEN + 1;
         for (be = slapi_get_first_backend(&cookie); be;
              be = slapi_get_next_backend(cookie)) {
@@ -704,10 +704,10 @@ usn_rootdse_search(Slapi_PBlock *pb, Slapi_Entry* e, Slapi_Entry* entryAfter,
             /* get a next USN counter from be_usn_counter; 
              * then minus 1 from it (except if be_usn_counter has value 0) */
             if (slapi_counter_get_value(be->be_usn_counter)) {
-                PR_snprintf(usn_berval.bv_val, USN_COUNTER_BUF_LEN, "%" NSPRIu64,
+                snprintf(usn_berval.bv_val, USN_COUNTER_BUF_LEN, "%" NSPRIu64,
                             slapi_counter_get_value(be->be_usn_counter)-1);
             } else {
-                PR_snprintf(usn_berval.bv_val, USN_COUNTER_BUF_LEN, "-1");
+                snprintf(usn_berval.bv_val, USN_COUNTER_BUF_LEN, "-1");
             }
             usn_berval.bv_len = strlen(usn_berval.bv_val);
     
@@ -716,7 +716,7 @@ usn_rootdse_search(Slapi_PBlock *pb, Slapi_Entry* e, Slapi_Entry* entryAfter,
                 attr = (char *)slapi_ch_realloc(attr, attr_len);
                 attr_subp = attr + USN_LAST_USN_ATTR_CORE_LEN;
             }
-            PR_snprintf(attr_subp, attr_len - USN_LAST_USN_ATTR_CORE_LEN,
+            snprintf(attr_subp, attr_len - USN_LAST_USN_ATTR_CORE_LEN,
                                     "%s", be->be_name);
             slapi_entry_attr_replace(e, attr, vals);
         }
