@@ -678,7 +678,10 @@ static void entrycache_set_max_size(struct cache *cache, size_t bytes)
        cache_make_hashes(cache, CACHE_TYPE_ENTRY);
     }
     cache_unlock(cache);
-    if (! dblayer_is_cachesize_sane(&bytes)) {
+    /* This may already have been called by one of the functions in
+     * ldbm_instance_config
+     */
+    if (! util_is_cachesize_sane(&bytes)) {
        LDAPDebug(LDAP_DEBUG_ANY,
                 "WARNING -- Possible CONFIGURATION ERROR -- cachesize "
                 "(%lu) may be configured to use more than the available "
@@ -1046,7 +1049,7 @@ static int entrycache_replace(struct cache *cache, struct backentry *olde,
     if (!add_hash(cache->c_dntable, (void *)newndn, strlen(newndn), newe, (void **)&alte)) {
         LOG("entry cache replace (%s): can't add to dn table (returned %s)\n", 
             newndn, alte?slapi_entry_get_dn(alte->ep_entry):"none", 0);
-        cache_lock(cache);
+        cache_unlock(cache);
         return 1;
     }
     if (!add_hash(cache->c_idtable, &(newe->ep_id), sizeof(ID), newe, (void **)&alte)) {
@@ -1132,6 +1135,17 @@ entrycache_return(struct cache *cache, struct backentry **bep)
         ASSERT(e->ep_refcnt > 0);
         if (! --e->ep_refcnt) {
             if (e->ep_state & ENTRY_STATE_DELETED) {
+                const char* ndn = slapi_sdn_get_ndn(backentry_get_sdn(e));
+                if (ndn){
+                    /*
+                     * State is "deleted" and there are no more references,
+                     * so we need to remove the entry from the DN cache because
+                     * we don't/can't always call cache_remove().
+                     */
+                    if (remove_hash(cache->c_dntable, (void *)ndn, strlen(ndn)) == 0) {
+                        LOG("entrycache_return: failed to remove %s from dn table\n", ndn, 0, 0);
+                    }
+                }
                 backentry_free(bep);
             } else {
                 lru_add(cache, e);
@@ -1380,7 +1394,7 @@ entrycache_add_int(struct cache *cache, struct backentry *e, int state,
                 return 0;
             }
             if(remove_hash(cache->c_dntable, (void *)ndn, strlen(ndn)) == 0){
-                LOG("entrycache_add_int: failed to remove %s from dn table\n", 0, 0, 0);
+                LOG("entrycache_add_int: failed to remove %s from dn table\n", ndn, 0, 0);
             }
             e->ep_state |= ENTRY_STATE_NOTINCACHE;
             cache_unlock(cache);
@@ -1504,6 +1518,7 @@ int cache_lock_entry(struct cache *cache, struct backentry *e)
         if (! e->ep_mutexp) {
             e->ep_mutexp = PR_NewMonitor();
             if (!e->ep_mutexp) {
+                PR_Unlock(cache->c_emutexalloc_mutex);
                 LOG("<= cache_lock_entry (DELETED)\n", 0, 0, 0);
                 LDAPDebug1Arg(LDAP_DEBUG_ANY,
                               "cache_lock_entry: failed to create a lock for %s\n",
@@ -1613,7 +1628,10 @@ dncache_set_max_size(struct cache *cache, size_t bytes)
        cache_make_hashes(cache, CACHE_TYPE_DN);
     }
     cache_unlock(cache);
-    if (! dblayer_is_cachesize_sane(&bytes)) {
+    /* This may already have been called by one of the functions in
+     * ldbm_instance_config
+     */
+    if (! util_is_cachesize_sane(&bytes)) {
        LDAPDebug1Arg(LDAP_DEBUG_ANY,
                 "WARNING -- Possible CONFIGURATION ERROR -- cachesize "
                 "(%lu) may be configured to use more than the available "
