@@ -92,17 +92,27 @@ ldbm_instance_config_cachememsize_set(void *arg, void *value, char *errorbuf, in
     ldbm_instance *inst = (ldbm_instance *) arg;
     int retval = LDAP_SUCCESS;
     size_t val = (size_t) value;
-    size_t chkval = val;
+    size_t delta = 0;
 
     /* Do whatever we can to make sure the data is ok. */
+    /* There is an error here. We check the new val against our current mem-alloc 
+     * Issue is that we already are using system pages, so while our value *might*
+     * be valid, we may reject it here due to the current procs page usage.
+     * 
+     * So how do we solve this? If we are setting a SMALLER value than we
+     * currently have ALLOW it, because we already passed the cache sanity.
+     * If we are setting a LARGER value, we check the delta of the two, and make
+     * sure that it is sane.
+     */
 
     if (apply) {
-        if (!dblayer_is_cachesize_sane(&chkval)){
-            PR_snprintf(errorbuf, SLAPI_DSE_RETURNTEXT_SIZE,
-                    "Error: cachememsize value is too large.");
-            LDAPDebug( LDAP_DEBUG_ANY,"Error: cachememsize value is too large.\n",
-                    0, 0, 0);
-            return LDAP_UNWILLING_TO_PERFORM;
+        if (val > inst->inst_cache.c_maxsize) {
+            delta = val - inst->inst_cache.c_maxsize;
+            if (!util_is_cachesize_sane(&delta)){
+                slapi_create_errormsg(errorbuf, SLAPI_DSE_RETURNTEXT_SIZE, "Error: cachememsize value is too large.");
+                LDAPDebug0Args(LDAP_DEBUG_ANY, "Error: cachememsize value is too large.\n");
+                return LDAP_UNWILLING_TO_PERFORM;
+            }
         }
         cache_set_max_size(&(inst->inst_cache), val, CACHE_TYPE_ENTRY);
     }
@@ -124,17 +134,27 @@ ldbm_instance_config_dncachememsize_set(void *arg, void *value, char *errorbuf,
     ldbm_instance *inst = (ldbm_instance *) arg;
     int retval = LDAP_SUCCESS;
     size_t val = (size_t)value;
-    size_t chkval = val;
+    size_t delta = 0;
 
     /* Do whatever we can to make sure the data is ok. */
+    /* There is an error here. We check the new val against our current mem-alloc 
+     * Issue is that we already are using system pages, so while our value *might*
+     * be valid, we may reject it here due to the current procs page usage.
+     * 
+     * So how do we solve this? If we are setting a SMALLER value than we
+     * currently have ALLOW it, because we already passed the cache sanity.
+     * If we are setting a LARGER value, we check the delta of the two, and make
+     * sure that it is sane.
+     */
 
     if (apply) {
-        if (!dblayer_is_cachesize_sane(&chkval)){
-            PR_snprintf(errorbuf, SLAPI_DSE_RETURNTEXT_SIZE,
-                    "Error: dncachememsize value is too large.");
-            LDAPDebug( LDAP_DEBUG_ANY,"Error: dncachememsize value is too large.\n",
-                    0, 0, 0);
-            return LDAP_UNWILLING_TO_PERFORM;
+        if (val > inst->inst_dncache.c_maxsize) {
+            delta = val - inst->inst_dncache.c_maxsize;
+            if (!util_is_cachesize_sane(&delta)){
+                slapi_create_errormsg(errorbuf, SLAPI_DSE_RETURNTEXT_SIZE, "Error: dncachememsize value is too large.");
+                LDAPDebug0Args(LDAP_DEBUG_ANY,"Error: dncachememsize value is too large.\n");
+                return LDAP_UNWILLING_TO_PERFORM;
+            }
         }
         cache_set_max_size(&(inst->inst_dncache), val, CACHE_TYPE_DN);
     }
@@ -287,10 +307,9 @@ void
 ldbm_instance_config_setup_default(ldbm_instance *inst) 
 {
     config_info *config;
-    char err_buf[BUFSIZ];
 
     for (config = ldbm_instance_config; config->config_name != NULL; config++) {
-        ldbm_config_set((void *)inst, config->config_name, ldbm_instance_config, NULL /* use default */, err_buf, CONFIG_PHASE_INITIALIZATION, 1 /* apply */, LDAP_MOD_REPLACE);
+        ldbm_config_set((void *)inst, config->config_name, ldbm_instance_config, NULL /* use default */, NULL, CONFIG_PHASE_INITIALIZATION, 1 /* apply */, LDAP_MOD_REPLACE);
     }
 }
 
@@ -416,7 +435,7 @@ parse_ldbm_instance_config_entry(ldbm_instance *inst, Slapi_Entry *e, config_inf
         char *attr_name = NULL;
         Slapi_Value *sval = NULL;
         struct berval *bval;
-        char err_buf[BUFSIZ];
+        char err_buf[SLAPI_DSE_RETURNTEXT_SIZE];
         
         slapi_attr_get_type(attr, &attr_name);
 
@@ -776,9 +795,19 @@ ldbm_instance_modify_config_entry_callback(Slapi_PBlock *pb, Slapi_Entry* entryB
             }
 
         /* This assumes there is only one bval for this mod. */
-            rc = ldbm_config_set((void *) inst, attr_name,
-                ldbm_instance_config, mods[i]->mod_bvalues[0], returntext,
-                CONFIG_PHASE_RUNNING, apply_mod, mods[i]->mod_op);
+            if (mods[i]->mod_bvalues == NULL) {
+                /* This avoids the null pointer deref.
+                 * In ldbm_config.c ldbm_config_set, it checks for the NULL.
+                 * If it's a NULL, we get NO_SUCH_ATTRIBUTE error.
+                 */
+                rc = ldbm_config_set((void *) inst, attr_name,
+                    ldbm_instance_config, NULL, returntext,
+                    CONFIG_PHASE_RUNNING, apply_mod, mods[i]->mod_op);
+            } else {
+                rc = ldbm_config_set((void *) inst, attr_name,
+                    ldbm_instance_config, mods[i]->mod_bvalues[0], returntext,
+                    CONFIG_PHASE_RUNNING, apply_mod, mods[i]->mod_op);
+            }
         }
     }
 
@@ -799,7 +828,7 @@ out:
 void 
 ldbm_instance_config_internal_set(ldbm_instance *inst, char *attrname, char *value)
 {
-    char err_buf[BUFSIZ];
+    char err_buf[SLAPI_DSE_RETURNTEXT_SIZE];
     struct berval bval;
 
     bval.bv_val = value;
@@ -1126,6 +1155,11 @@ ldbm_instance_post_delete_instance_entry_callback(Slapi_PBlock *pb, Slapi_Entry*
                             rc = PR_Delete(dbp);
                         }
                         PR_ASSERT(rc == 0);
+                        if (rc != 0) {
+                            LDAPDebug1Arg(LDAP_DEBUG_ANY,
+                                "ldbm_instance_post_delete_instance_entry_callback:"
+                                " failed to delete %s\n", dbp);
+                        }
                         PR_smprintf_free(dbp);
                     }
                     PR_CloseDir(dirhandle);                
