@@ -131,8 +131,6 @@ int dblayer_terminate(struct ldbminfo *li);
 int dblayer_close_indexes(backend *be);
 int dblayer_open_file(backend *be, char* indexname, int create, struct attrinfo *ai, DB **ppDB);
 int dblayer_close_file(DB **db);
-void dblayer_sys_pages(size_t *pagesize, size_t *pages, size_t *procpages, size_t *availpages);
-int dblayer_is_cachesize_sane(size_t *cachesize);
 void dblayer_remember_disk_filled(struct ldbminfo *li);
 int dblayer_open_huge_file(const char *path, int oflag, int mode);
 int dblayer_instance_start(backend *be, int normal_mode);
@@ -170,6 +168,15 @@ int ldbm_back_get_info(Slapi_Backend *be, int cmd, void **info);
 int ldbm_back_set_info(Slapi_Backend *be, int cmd, void *info);
 int ldbm_back_ctrl_info(Slapi_Backend *be, int cmd, void *info);
 
+int dblayer_is_restored(void);
+void dblayer_set_restored(void);
+int dblayer_restore_file_check(struct ldbminfo *li);
+int dblayer_restore_file_init(struct ldbminfo *li);
+void dblayer_restore_file_update(struct ldbminfo *li, char *directory);
+int dblayer_import_file_init(ldbm_instance *inst);
+void dblayer_import_file_update(ldbm_instance *inst);
+int dblayer_import_file_check(ldbm_instance *inst);
+
 /*
  * dn2entry.c
  */
