@@ -100,7 +100,7 @@ do_bind( Slapi_PBlock *pb )
     Slapi_DN *sdn = NULL;
     int bind_sdn_in_pb = 0; /* is sdn set in the pb? */
     Slapi_Entry *referral;
-    char errorbuf[BUFSIZ];
+    char errorbuf[SLAPI_DSE_RETURNTEXT_SIZE] = {0};
     char **supported, **pmech;
     char authtypebuf[256]; /* >26 (strlen(SLAPD_AUTH_SASL)+SASL_MECHNAMEMAX+1) */
     Slapi_Entry *bind_target_entry = NULL;
@@ -165,7 +165,7 @@ do_bind( Slapi_PBlock *pb )
         slapi_sdn_free(&sdn);
         return;
     }
-    LDAPDebug( LDAP_DEBUG_TRACE, "BIND dn=\"%s\" method=%d version=%d\n",
+    LDAPDebug( LDAP_DEBUG_TRACE, "BIND dn=\"%s\" method=%" BERTAG_T " version=%d\n",
                dn?dn:"empty", method, version );
 
     /* target spec is used to decide which plugins are applicable for the operation */
@@ -655,7 +655,7 @@ do_bind( Slapi_PBlock *pb )
     }
 
     /* We could be serving multiple database backends.  Select the appropriate one */
-    if (slapi_mapping_tree_select(pb, &be, &referral, errorbuf) != LDAP_SUCCESS) {
+    if (slapi_mapping_tree_select(pb, &be, &referral, NULL, 0) != LDAP_SUCCESS) {
         send_nobackend_ldap_result( pb );
         be = NULL;
         goto free_and_return;
@@ -685,7 +685,7 @@ do_bind( Slapi_PBlock *pb )
             Slapi_DN *pb_sdn;
             slapi_pblock_get(pb, SLAPI_BIND_TARGET_SDN, &pb_sdn);
             if (!pb_sdn) {
-                PR_snprintf(errorbuf, sizeof(errorbuf), "Pre-bind plug-in set NULL dn\n");
+                slapi_create_errormsg(errorbuf, sizeof(errorbuf), "Pre-bind plug-in set NULL dn\n");
                 slapi_pblock_set(pb, SLAPI_PB_RESULT_TEXT, errorbuf);
                 send_ldap_result(pb, LDAP_OPERATIONS_ERROR, NULL, "", 0, NULL);
                 goto free_and_return;
@@ -698,7 +698,7 @@ do_bind( Slapi_PBlock *pb )
                 dn = slapi_sdn_get_dn(sdn);
                 if (!dn) {
                     const char *udn = slapi_sdn_get_udn(sdn);
-                    PR_snprintf(errorbuf, sizeof(errorbuf), "Pre-bind plug-in set corrupted dn %s\n", udn?udn:"");
+                    slapi_create_errormsg(errorbuf, sizeof(errorbuf), "Pre-bind plug-in set corrupted dn %s\n", udn?udn:"");
                     slapi_pblock_set(pb, SLAPI_PB_RESULT_TEXT, errorbuf);
                     send_ldap_result(pb, LDAP_OPERATIONS_ERROR, NULL, "", 0, NULL);
                     goto free_and_return;
@@ -713,7 +713,7 @@ do_bind( Slapi_PBlock *pb )
                         slapi_be_Rlock(be);
                         slapi_pblock_set( pb, SLAPI_BACKEND, be );
                     } else {
-                        PR_snprintf(errorbuf, sizeof(errorbuf), "No matching backend for %s\n", dn);
+                        slapi_create_errormsg(errorbuf, sizeof(errorbuf), "No matching backend for %s\n", dn);
                         slapi_pblock_set(pb, SLAPI_PB_RESULT_TEXT, errorbuf);
                         send_ldap_result(pb, LDAP_OPERATIONS_ERROR, NULL, "", 0, NULL);
                         goto free_and_return;
@@ -918,13 +918,13 @@ log_bind_access (
     } else if (msg) {
         slapi_log_access( LDAP_DEBUG_STATS, 
                           "conn=%" NSPRIu64 " op=%d BIND dn=\"%s\" "
-                          "method=%ld version=%d, %s\n",
+                          "method=%" BERTAG_T " version=%d, %s\n",
                           pb->pb_conn->c_connid, pb->pb_op->o_opid, dn,
                           method, version, msg );
     } else {
         slapi_log_access( LDAP_DEBUG_STATS, 
                           "conn=%" NSPRIu64 " op=%d BIND dn=\"%s\" "
-                          "method=%ld version=%d\n",
+                          "method=%" BERTAG_T " version=%d\n",
                           pb->pb_conn->c_connid, pb->pb_op->o_opid, dn,
                           method, version );
     }
