@@ -225,7 +225,7 @@ static void op_shared_delete (Slapi_PBlock *pb)
 	Slapi_Operation *operation;
 	Slapi_Entry *referral;
 	Slapi_Entry	*ecopy = NULL;
-	char errorbuf[BUFSIZ];
+	char errorbuf[SLAPI_DSE_RETURNTEXT_SIZE];
 	int				err;
 	char		*proxydn = NULL;
 	char		*proxystr = NULL;
@@ -290,7 +290,7 @@ static void op_shared_delete (Slapi_PBlock *pb)
 	 * We could be serving multiple database backends.  Select the
 	 * appropriate one.
 	 */
-	if ((err = slapi_mapping_tree_select(pb, &be, &referral, errorbuf)) != LDAP_SUCCESS) {
+	if ((err = slapi_mapping_tree_select(pb, &be, &referral, errorbuf, sizeof(errorbuf))) != LDAP_SUCCESS) {
 		send_ldap_result(pb, err, NULL, errorbuf, 0, NULL);
 		be = NULL;
 		goto free_and_return;
@@ -351,6 +351,11 @@ static void op_shared_delete (Slapi_PBlock *pb)
 					operation_out_of_disk_space();
 					goto free_and_return;
 				}
+				/* If the disk is full we don't want to make it worse ... */
+				if (operation_is_flag_set(operation,OP_FLAG_ACTION_LOG_AUDIT))
+				{ 
+					write_auditfail_log_entry(pb); /* Record the operation in the audit log */
+				}
 			}
 		}
 
