@@ -44,16 +44,87 @@
 #include <unistd.h>
 #endif /* USE_SYSCONF */
 
+static int
+set_workingdir()
+{
+	int rc = 0;
+	char *workingdir = config_get_workingdir();
+	char *errorlog = 0;
+	char *ptr = 0;
+	extern char *config_get_errorlog(void);
+	extern int config_set_workingdir(const char *attrname, char *value, char *errorbuf, int apply);
+	char errorbuf[SLAPI_DSE_RETURNTEXT_SIZE];
+
+	if ( NULL == workingdir ) {
+		errorlog = config_get_errorlog();
+		if (NULL == errorlog) {
+			rc = chdir("/");
+			if (0 == rc) {
+				if (config_set_workingdir(CONFIG_WORKINGDIR_ATTRIBUTE, "/", errorbuf, 1) == LDAP_OPERATIONS_ERROR) {
+					LDAPDebug1Arg(LDAP_DEBUG_ANY, "detach: set workingdir failed with \"%s\"\n", errorbuf);
+				}
+			} else {
+				LDAPDebug1Arg(LDAP_DEBUG_ANY, "detach: failed to chdir to %s\n", "/");
+			}
+		} else {
+			ptr = strrchr(errorlog, '/');
+			if (ptr) {
+				*ptr = '\0';
+			}
+			rc = chdir(errorlog);
+			if (0 == rc) {
+				if (config_set_workingdir(CONFIG_WORKINGDIR_ATTRIBUTE, errorlog, errorbuf, 1) == LDAP_OPERATIONS_ERROR) {
+					LDAPDebug1Arg(LDAP_DEBUG_ANY, "detach: set workingdir failed with \"%s\"\n", errorbuf);
+					rc = chdir("/");
+					if (0 == rc) {
+						if (config_set_workingdir(CONFIG_WORKINGDIR_ATTRIBUTE, "/", errorbuf, 1) == LDAP_OPERATIONS_ERROR) {
+							LDAPDebug1Arg(LDAP_DEBUG_ANY, "detach: set workingdir failed with \"%s\"\n", errorbuf);
+						}
+					} else {
+						LDAPDebug1Arg(LDAP_DEBUG_ANY, "detach: failed to chdir to %s\n", "/");
+					}
+				}
+			} else {
+				LDAPDebug1Arg(LDAP_DEBUG_ANY, "detach: failed to chdir to %s\n", errorlog);
+				rc = chdir("/");
+				if (0 == rc) {
+					if (config_set_workingdir(CONFIG_WORKINGDIR_ATTRIBUTE, "/", errorbuf, 1) == LDAP_OPERATIONS_ERROR) {
+						LDAPDebug1Arg(LDAP_DEBUG_ANY, "detach: set workingdir failed with \"%s\"\n", errorbuf);
+					}
+				} else {
+					LDAPDebug1Arg(LDAP_DEBUG_ANY, "detach: failed to chdir to %s\n", "/");
+				}
+			}
+			slapi_ch_free_string(&errorlog);
+		}
+	} else {
+		/* calling config_set_workingdir to check for validity of directory, don't apply */
+		if (config_set_workingdir(CONFIG_WORKINGDIR_ATTRIBUTE, workingdir, errorbuf, 0) == LDAP_OPERATIONS_ERROR) {
+			LDAPDebug1Arg(LDAP_DEBUG_ANY, "detach: set workingdir failed with \"%s\"\n", errorbuf);
+			rc = chdir("/");
+			if (0 == rc) {
+				if (config_set_workingdir(CONFIG_WORKINGDIR_ATTRIBUTE, "/", errorbuf, 1) == LDAP_OPERATIONS_ERROR) {
+					LDAPDebug1Arg(LDAP_DEBUG_ANY, "detach: set workingdir failed with \"%s\"\n", errorbuf);
+				}
+			} else {
+				LDAPDebug1Arg(LDAP_DEBUG_ANY, "detach: failed to chdir to %s\n", "/");
+			}
+		} else {
+			rc = chdir(workingdir);
+			if (rc) {
+				LDAPDebug1Arg(LDAP_DEBUG_ANY, "detach: failed to chdir to %s\n", workingdir);
+			}
+		}
+		slapi_ch_free_string(&workingdir);
+	}
+	return rc;
+}
+
 int
 detach( int slapd_exemode, int importexport_encrypt,
         int s_port, daemon_ports_t *ports_info )
 {
-	int		i, sd;
-	char *workingdir = 0;
-	char *errorlog = 0;
-	char *ptr = 0;
-	char errorbuf[BUFSIZ];
-	extern char *config_get_errorlog(void);
+	int i, sd;
 
 	if ( should_detach ) {
 		for ( i = 0; i < 5; i++ ) {
@@ -76,32 +147,12 @@ detach( int slapd_exemode, int importexport_encrypt,
 		}
 
 		/* call this right after the fork, but before closing stdin */
-		if (slapd_do_all_nss_ssl_init(slapd_exemode, importexport_encrypt,
-									  s_port, ports_info)) {
+		if (slapd_do_all_nss_ssl_init(slapd_exemode, importexport_encrypt, s_port, ports_info)) {
 			return 1;
 		}
 
-		workingdir = config_get_workingdir();
-		if ( NULL == workingdir ) {
-			errorlog = config_get_errorlog();
-			if ( NULL == errorlog ) {
-				(void) chdir( "/" );
-			} else {
-				if ((ptr = strrchr(errorlog, '/')) ||
-					(ptr = strrchr(errorlog, '\\'))) {
-					*ptr = 0;
-				}
-				(void) chdir( errorlog );
-				config_set_workingdir(CONFIG_WORKINGDIR_ATTRIBUTE, errorlog, errorbuf, 1);
-				slapi_ch_free_string(&errorlog);
-			}
-		} else {
-			/* calling config_set_workingdir to check for validity of directory, don't apply */
-			if (config_set_workingdir(CONFIG_WORKINGDIR_ATTRIBUTE, workingdir, errorbuf, 0) == LDAP_OPERATIONS_ERROR) {
-				return 1;
-			}
-			(void) chdir( workingdir );
-			slapi_ch_free_string(&workingdir);
+		if (set_workingdir()) {
+			LDAPDebug0Args(LDAP_DEBUG_ANY, "detach: set_workingdir failed.\n");
 		}
 
 		if ( (sd = open( "/dev/null", O_RDWR )) == -1 ) {
@@ -124,10 +175,12 @@ detach( int slapd_exemode, int importexport_encrypt,
 
 		g_set_detached(1);
 	} else { /* not detaching - call nss/ssl init */
-		if (slapd_do_all_nss_ssl_init(slapd_exemode, importexport_encrypt,
-									  s_port, ports_info)) {
+		if (slapd_do_all_nss_ssl_init(slapd_exemode, importexport_encrypt, s_port, ports_info)) {
 			return 1;
 		}
+		if (set_workingdir()) {
+			LDAPDebug0Args(LDAP_DEBUG_ANY, "detach: set_workingdir failed.\n");
+		}
 	}
 
 	(void) SIGNAL( SIGPIPE, SIG_IGN );
