@@ -70,6 +70,11 @@
 static PRCallOnceType ol_init_callOnce = {0,0};
 static PRLock *ol_init_lock = NULL;
 
+#if defined(USE_OPENLDAP)
+extern void getSSLVersionRangeOL(int *min, int *max);
+extern int getSSLVersionRange(char **min, char **max);
+#endif
+
 static PRStatus
 internal_ol_init_init(void)
 {
@@ -111,7 +116,7 @@ void
 slapi_ldap_unbind( LDAP *ld )
 {
     if ( ld != NULL ) {
-	ldap_unbind_ext( ld, NULL, NULL );
+        ldap_unbind_ext( ld, NULL, NULL );
     }
 }
 
@@ -201,46 +206,46 @@ slapi_urlparse_err2string( int err )
 
     switch( err ) {
     case 0:
-	s = "no error";
-	break;
+        s = "no error";
+        break;
     case LDAP_URL_ERR_BADSCOPE:
-	s = "invalid search scope";
-	break;
+        s = "invalid search scope";
+        break;
     case LDAP_URL_ERR_MEM:
-	s = "unable to allocate memory";
-	break;
+        s = "unable to allocate memory";
+        break;
     case LDAP_URL_ERR_PARAM:
-	s = "bad parameter to an LDAP URL function";
-	break;
+        s = "bad parameter to an LDAP URL function";
+        break;
 #if defined(USE_OPENLDAP)
     case LDAP_URL_ERR_BADSCHEME:
-	s = "does not begin with ldap://, ldaps://, or ldapi://";
-	break;
+        s = "does not begin with ldap://, ldaps://, or ldapi://";
+        break;
     case LDAP_URL_ERR_BADENCLOSURE:
-	s = "missing trailing '>' in enclosure";
-	break;
+        s = "missing trailing '>' in enclosure";
+        break;
     case LDAP_URL_ERR_BADURL:
-	s = "not a valid LDAP URL";
-	break;
+        s = "not a valid LDAP URL";
+        break;
     case LDAP_URL_ERR_BADHOST:
-	s = "hostname part of url is not valid or not given";
-	break;
+        s = "hostname part of url is not valid or not given";
+        break;
     case LDAP_URL_ERR_BADATTRS:
-	s = "attribute list not formatted correctly or missing";
-	break;
+        s = "attribute list not formatted correctly or missing";
+        break;
     case LDAP_URL_ERR_BADFILTER:
-	s = "search filter not correct";
-	break;
+        s = "search filter not correct";
+        break;
     case LDAP_URL_ERR_BADEXTS:
-	s = "extensions not specified correctly";
-	break;
+        s = "extensions not specified correctly";
+        break;
 #else /* !USE_OPENLDAP */
     case LDAP_URL_ERR_NOTLDAP:
-	s = "missing ldap:// or ldaps:// or ldapi://";
-	break;
+        s = "missing ldap:// or ldaps:// or ldapi://";
+        break;
     case LDAP_URL_ERR_NODN:
-	s = "missing suffix";
-	break;
+        s = "missing suffix";
+        break;
 #endif
     }
 
@@ -256,6 +261,10 @@ slapi_ldap_url_parse(const char *url, LDAPURLDesc **ludpp, int require_dn, int *
     PR_ASSERT(url);
     PR_ASSERT(ludpp);
     int rc;
+    /* This blocks NULL getting to strlen via url_to_use later in the function. */
+    if (url == NULL) {
+        return LDAP_PARAM_ERROR;
+    }
     const char *url_to_use = url;
 #if defined(USE_OPENLDAP)
     char *urlescaped = NULL;
@@ -339,7 +348,13 @@ slapi_ldap_url_parse(const char *url, LDAPURLDesc **ludpp, int require_dn, int *
            as the DN (adding a trailing / first if needed) and try to parse
            again
         */
-        char *urlcopy = slapi_ch_smprintf("%s%s%s", url_to_use, (url_to_use[len-1] == '/' ? "" : "/"), "");
+        char *urlcopy;
+        if (len > 0) {
+            urlcopy = slapi_ch_smprintf("%s%s%s", url_to_use, (url_to_use[len-1] == '/' ? "" : "/"), "");
+        } else {
+            /* When len == 0, this is effectively what we create ... */
+            urlcopy = slapi_ch_smprintf("/");
+        }
         if (*ludpp) {
             ldap_free_urldesc(*ludpp); /* free the old one, if any */
         }
@@ -483,33 +498,33 @@ slapi_ldap_create_proxyauth_control (
        so we just hard code it here */
     beropts = LBER_USE_DER; /* openldap seems to use DER by default */
     if (ctrlp == NULL) {
-	return LDAP_PARAM_ERROR;
+        return LDAP_PARAM_ERROR;
     }
     if (NULL == dn) {
-	dn = "";
+        dn = "";
     }
 
     if (NULL == (ber = ber_alloc_t(beropts))) {
-	return LDAP_NO_MEMORY;
+        return LDAP_NO_MEMORY;
     }
 
     if (usev2) {
-	berfmtstr = "s";
-	ctrloid = LDAP_CONTROL_PROXIEDAUTH;
+        berfmtstr = "s";
+        ctrloid = LDAP_CONTROL_PROXIEDAUTH;
     } else {
-	berfmtstr = "{s}";
-	ctrloid = LDAP_CONTROL_PROXYAUTH;
+        berfmtstr = "{s}";
+        ctrloid = LDAP_CONTROL_PROXYAUTH;
     }
 
     if (LBER_ERROR == ber_printf(ber, berfmtstr, dn)) {
-	ber_free(ber, 1);
-	return LDAP_ENCODING_ERROR;
+        ber_free(ber, 1);
+        return LDAP_ENCODING_ERROR;
     }
 
     if (LBER_ERROR == ber_flatten(ber, &bv)) {
         ber_bvfree(bv);
         ber_free(ber, 1);
-	return LDAP_ENCODING_ERROR;
+        return LDAP_ENCODING_ERROR;
     }
 	
     if (NULL == bv) {
@@ -560,45 +575,72 @@ setup_ol_tls_conn(LDAP *ld, int clientauth)
     int optval = 0;
     int ssl_strength = 0;
     int rc = 0;
+    const char *cacert = NULL;
 
     if (config_get_ssl_check_hostname()) {
-	ssl_strength = LDAP_OPT_X_TLS_HARD;
+        ssl_strength = LDAP_OPT_X_TLS_HARD;
     } else {
-	/* verify certificate only */
-	ssl_strength = LDAP_OPT_X_TLS_NEVER;
+        /* verify certificate only */
+        ssl_strength = LDAP_OPT_X_TLS_NEVER;
     }
 
     if ((rc = ldap_set_option(ld, LDAP_OPT_X_TLS_REQUIRE_CERT, &ssl_strength))) {
-	slapi_log_error(SLAPI_LOG_FATAL, "setup_ol_tls_conn",
-			"failed: unable to set REQUIRE_CERT option to %d\n", ssl_strength);
+        slapi_log_error(SLAPI_LOG_FATAL, "setup_ol_tls_conn",
+                        "failed: unable to set REQUIRE_CERT option to %d\n", ssl_strength);
     }
-    /* tell it where our cert db is */
+    if (slapi_client_uses_non_nss(ld)) {
+        cacert = slapi_get_cacertfile();
+        if (cacert) {
+            /* CA Cert PEM file exists.  Set the path to openldap option. */
+            rc = ldap_set_option(ld, LDAP_OPT_X_TLS_CACERTFILE, cacert);
+            if (rc) {
+                slapi_log_error(SLAPI_LOG_FATAL, "setup_ol_tls_conn",
+                                "Could not set CA cert path [%s]: %d:%s\n",
+                                cacert, rc, ldap_err2string(rc));
+            }
+        }
+        if (slapi_client_uses_openssl(ld)) {
+            const int crlcheck = LDAP_OPT_X_TLS_CRL_ALL;
+            /* Sets the CRL evaluation strategy. */
+            rc = ldap_set_option(ld, LDAP_OPT_X_TLS_CRLCHECK, &crlcheck);
+            if (rc) {
+                slapi_log_error(SLAPI_LOG_FATAL, "setup_ol_tls_conn",
+                                "Could not set CRLCHECK [%d]: %d:%s\n",
+                                crlcheck, rc, ldap_err2string(rc));
+            }
+        }
+    }
+    /* tell it where our cert db/file is */
     if ((rc = ldap_set_option(ld, LDAP_OPT_X_TLS_CACERTDIR, certdir))) {
-	slapi_log_error(SLAPI_LOG_FATAL, "setup_ol_tls_conn",
-			"failed: unable to set CACERTDIR option to %s\n", certdir);
+        slapi_log_error(SLAPI_LOG_FATAL, "setup_ol_tls_conn",
+                        "failed: unable to set CACERTDIR option to %s\n", certdir);
     }
     slapi_ch_free_string(&certdir);
 #if defined(LDAP_OPT_X_TLS_PROTOCOL_MIN)
-    optval = LDAP_OPT_X_TLS_PROTOCOL_SSL3;
+    getSSLVersionRangeOL(&optval, NULL);
     if ((rc = ldap_set_option(ld, LDAP_OPT_X_TLS_PROTOCOL_MIN, &optval))) {
-	slapi_log_error(SLAPI_LOG_FATAL, "setup_ol_tls_conn",
-			"failed: unable to set minimum TLS protocol level to SSL3\n");
+        char *minstr = NULL;
+        (void)getSSLVersionRange(&minstr, NULL);
+        slapi_log_error(SLAPI_LOG_FATAL, "setup_ol_tls_conn",
+                        "failed: unable to set minimum TLS protocol level to %s\n", minstr);
+        slapi_ch_free_string(&minstr);
     }
 #endif /* LDAP_OPT_X_TLS_PROTOCOL_MIN */
     if (clientauth) {
-	rc = slapd_SSL_client_auth(ld);
-	if (rc) {
-	    slapi_log_error(SLAPI_LOG_FATAL, "setup_ol_tls_conn",
-			    "failed: unable to setup connection for TLS/SSL EXTERNAL client cert authentication - %d\n", rc);
-	}
+        rc = slapd_SSL_client_auth(ld);
+        if (rc) {
+            slapi_log_error(SLAPI_LOG_FATAL, "setup_ol_tls_conn",
+                            "failed: unable to setup connection for TLS/SSL EXTERNAL client cert authentication - %d\n", rc);
+        }
     }
 
     /* have to do this last - this creates the new TLS handle and sets/copies
        all of the parameters set above into that TLS handle context - note
-       that optval is ignored - what matters is that it is not NULL */
+       that optval is zero, meaning create a context for a client */
+    optval = 0;
     if ((rc = ldap_set_option(ld, LDAP_OPT_X_TLS_NEWCTX, &optval))) {
-	slapi_log_error(SLAPI_LOG_FATAL, "setup_ol_tls_conn",
-			"failed: unable to create new TLS context\n");
+        slapi_log_error(SLAPI_LOG_FATAL, "setup_ol_tls_conn",
+                        "failed: unable to create new TLS context - %d\n", rc);
     }
 
     return rc;
@@ -616,8 +658,8 @@ setup_ol_tls_conn(LDAP *ld, int clientauth)
   on the secure setting (389 for ldap, 636 for ldaps, 389 for starttls)
   secure takes 1 of 3 values - 0 means regular ldap, 1 means ldaps, 2
   means regular ldap with starttls.
-  filename is the ldapi file name - if this is given, and no other options
-  are given, ldapi is assumed.
+  ldapi_socket is the ldapi file name 
+     if this is given, and no other options are given, ldapi is assumed.
  */
 /* util_sasl_path: the string argument for putenv.
    It must be a global or a static */
@@ -627,12 +669,12 @@ LDAP *
 slapi_ldap_init_ext(
     const char *ldapurl, /* full ldap url */
     const char *hostname, /* can also use this to override
-			     host in url */
+                             host in url */
     int port, /* can also use this to override port in url */
     int secure, /* 0 for ldap, 1 for ldaps, 2 for starttls -
-		   override proto in url */
+                   override proto in url */
     int shared, /* if true, LDAP* will be shared among multiple threads */
-    const char *filename /* for ldapi */
+    const char *ldapi_socket /* for ldapi */
 )
 {
     LDAPURLDesc	*ludp = NULL;
@@ -686,16 +728,16 @@ slapi_ldap_init_ext(
     /* use secure setting from url if none given */
     if (!secure && ludp) {
         if (secureurl) {
-            secure = 1;
+            secure = SLAPI_LDAP_INIT_FLAG_SSL;
         } else if (0/* starttls option - not supported yet in LDAP URLs */) {
-            secure = 2;
+            secure = SLAPI_LDAP_INIT_FLAG_startTLS;
         }
     }
 
     /* ldap_url_parse doesn't yet handle ldapi */
     /*
-      if (!filename && ludp && ludp->lud_file) {
-      filename = ludp->lud_file;
+      if (!ldapi_socket && ludp && ludp->lud_file) {
+      ldapi_socket = ludp->lud_file;
       }
     */
 
@@ -743,10 +785,11 @@ slapi_ldap_init_ext(
     } else {
         char *makeurl = NULL;
 
-        if (filename) {
-            makeurl = slapi_ch_smprintf("ldapi://%s/", filename);
+        if (ldapi_socket) {
+            makeurl = slapi_ch_smprintf("ldapi://%s/", ldapi_socket);
         } else { /* host port */
-            makeurl = convert_to_openldap_uri(hostname, port, (secure == 1 ? "ldaps" : "ldap"));
+            makeurl = convert_to_openldap_uri(hostname, port,
+                                              (secure == SLAPI_LDAP_INIT_FLAG_SSL ? "ldaps" : "ldap"));
         }
         if (PR_SUCCESS != PR_CallOnce(&ol_init_callOnce, internal_ol_init_init)) {
             slapi_log_error(SLAPI_LOG_FATAL, "slapi_ldap_init_ext",
@@ -777,15 +820,15 @@ slapi_ldap_init_ext(
          * hostname (such as localhost.localdomain).
          */
         if((rc = ldap_set_option(ld, LDAP_OPT_X_SASL_NOCANON, LDAP_OPT_ON))){
-        	slapi_log_error(SLAPI_LOG_FATAL, "slapi_ldap_init_ext",
+            slapi_log_error(SLAPI_LOG_FATAL, "slapi_ldap_init_ext",
                 "Could not set ldap option LDAP_OPT_X_SASL_NOCANON for (%s), error %d (%s)\n",
                 ldapurl, rc, ldap_err2string(rc) );
         }
     }
 #else /* !USE_OPENLDAP */
-    if (filename) {
+    if (ldapi_socket) {
         /* ldapi in mozldap client is not yet supported */
-    } else if (secure == 1) {
+    } else if (secure == SLAPI_LDAP_INIT_FLAG_SSL) {
         ld = ldapssl_init(hostname, port, secure);
     } else { /* regular ldap and/or starttls */
         /*
@@ -809,7 +852,7 @@ slapi_ldap_init_ext(
         }
     }
 
-    if ((ld != NULL) && !filename) {
+    if (ld && !ldapi_socket) {
         /*
          * Set the outbound LDAP I/O timeout based on the server config.
          */
@@ -857,7 +900,7 @@ slapi_ldap_init_ext(
              * LDAP* if it has already gone through ldapssl_init -
              * so, use NULL if using starttls
              */
-            if (secure == 1) {
+            if (secure == SLAPI_LDAP_INIT_FLAG_SSL) {
                 myld = ld;
             }
 
@@ -881,7 +924,7 @@ slapi_ldap_init_ext(
                     SLAPI_COMPONENT_NAME_NSPR " error %d - %s)\n",
                     prerr, slapd_pr_strerror(prerr));
             }
-            if (secure == 1) {
+            if (secure == SLAPI_LDAP_INIT_FLAG_SSL) {
                 /* tell bind code we are using SSL */
                 ldap_set_option(ld, LDAP_OPT_SSL, LDAP_OPT_ON);
             }
@@ -889,7 +932,7 @@ slapi_ldap_init_ext(
         }
     }
 
-    if (ld && (secure == 2)) {
+    if (ld && (secure == SLAPI_LDAP_INIT_FLAG_startTLS)) {
         /*
          * We don't have a way to stash context data with the LDAP*, so we
          * stash the information in the client controls (currently unused).
@@ -919,8 +962,8 @@ slapi_ldap_init_ext(
     slapi_log_error(SLAPI_LOG_SHELL, "slapi_ldap_init_ext",
             "Success: set up conn to [%s:%d]%s\n",
             hostname, port,
-            (secure == 2) ? " using startTLS" :
-            ((secure == 1) ? " using SSL" : ""));
+            (secure == SLAPI_LDAP_INIT_FLAG_startTLS) ? " using startTLS" :
+            ((secure == SLAPI_LDAP_INIT_FLAG_SSL) ? " using SSL" : ""));
 done:
     ldap_free_urldesc(ludp);
 
@@ -974,7 +1017,7 @@ ldaputil_get_saslpath()
 LDAP *
 slapi_ldap_init( char *ldaphost, int ldapport, int secure, int shared )
 {
-    return slapi_ldap_init_ext(NULL, ldaphost, ldapport, secure, shared, NULL);
+    return slapi_ldap_init_ext(NULL, ldaphost, ldapport, secure, shared, NULL/*, NULL*/);
 }
 
 /*
@@ -1011,20 +1054,20 @@ slapi_ldap_bind(
     ldap_get_option(ld, LDAP_OPT_CLIENT_CONTROLS, &clientctrls);
     if (clientctrls && clientctrls[0] &&
         slapi_control_present(clientctrls, START_TLS_OID, NULL, NULL)) {
-        secure = 2;
+        secure = SLAPI_LDAP_INIT_FLAG_startTLS;
     } else {
 #if defined(USE_OPENLDAP)
-	/* openldap doesn't have a SSL/TLS yes/no flag - so grab the
-	   ldapurl, parse it, and see if it is a secure one */
-	char *ldapurl = NULL;
+        /* openldap doesn't have a SSL/TLS yes/no flag - so grab the
+           ldapurl, parse it, and see if it is a secure one */
+        char *ldapurl = NULL;
 
-	ldap_get_option(ld, LDAP_OPT_URI, &ldapurl);
-	if (ldapurl && !PL_strncasecmp(ldapurl, "ldaps", 5)) {
-	    secure = 1;
-	}
-	slapi_ch_free_string(&ldapurl);
+        ldap_get_option(ld, LDAP_OPT_URI, &ldapurl);
+        if (ldapurl && !PL_strncasecmp(ldapurl, "ldaps", 5)) {
+            secure = SLAPI_LDAP_INIT_FLAG_SSL;
+        }
+        slapi_ch_free_string(&ldapurl);
 #else /* !USE_OPENLDAP */
-	ldap_get_option(ld, LDAP_OPT_SSL, &secure);
+        ldap_get_option(ld, LDAP_OPT_SSL, &secure);
 #endif
     }
     ldap_controls_free(clientctrls);
@@ -1032,24 +1075,28 @@ slapi_ldap_bind(
 
     if ((secure > 0) && mech && !strcmp(mech, LDAP_SASL_EXTERNAL)) {
 #if defined(USE_OPENLDAP)
-	/* we already set up a tls context in slapi_ldap_init_ext() - this will
-	   free those old settings and context and create a new one */
-	rc = setup_ol_tls_conn(ld, 1);
+        /*
+         * we already set up a tls context in slapi_ldap_init_ext() - this will
+         * free those old settings and context and create a new one
+         */
+        rc = setup_ol_tls_conn(ld, 1);
 #else
-	/* SSL connections will use the server's security context
-	   and cert for client auth */
-	rc = slapd_SSL_client_auth(ld);
+        /*
+         * SSL connections will use the server's security context
+         * and cert for client auth
+         */
+        rc = slapd_SSL_client_auth(ld);
 #endif
-	if (rc != 0) {
-	    slapi_log_error(SLAPI_LOG_FATAL, "slapi_ldap_bind",
-			    "Error: could not configure the server for cert "
-			    "auth - error %d - make sure the server is "
-			    "correctly configured for SSL/TLS\n", rc);
-	    goto done;
-	} else {
-	    slapi_log_error(SLAPI_LOG_SHELL, "slapi_ldap_bind",
-			    "Set up conn to use client auth\n");
-	}
+        if (rc != 0) {
+            slapi_log_error(SLAPI_LOG_FATAL, "slapi_ldap_bind",
+                    "Error: could not configure the server for cert "
+                    "auth - error %d - make sure the server is "
+                    "correctly configured for SSL/TLS\n", rc);
+            goto done;
+        } else {
+            slapi_log_error(SLAPI_LOG_SHELL, "slapi_ldap_bind",
+                "Set up conn to use client auth\n");
+        }
         bvcreds.bv_val = NULL; /* ignore username and passed in creds */
         bvcreds.bv_len = 0; /* for external auth */
         bindid = NULL;
@@ -1058,73 +1105,73 @@ slapi_ldap_bind(
         bvcreds.bv_len = creds ? strlen(creds) : 0;
     }
 
-    if (secure == 2) { /* send start tls */
-	rc = ldap_start_tls_s(ld, NULL /* serverctrls?? */, NULL);
-	if (LDAP_SUCCESS != rc) {
-	    slapi_log_error(SLAPI_LOG_FATAL, "slapi_ldap_bind",
-			    "Error: could not send startTLS request: "
-			    "error %d (%s) errno %d (%s)\n",
-			    rc, ldap_err2string(rc), errno, slapd_system_strerror(errno));
-	    goto done;
-	}
-	slapi_log_error(SLAPI_LOG_SHELL, "slapi_ldap_bind",
-			"startTLS started on connection\n");
+    if (secure == SLAPI_LDAP_INIT_FLAG_startTLS) { /* send start tls */
+        rc = ldap_start_tls_s(ld, NULL /* serverctrls?? */, NULL);
+        if (LDAP_SUCCESS != rc) {
+            slapi_log_error(SLAPI_LOG_FATAL, "slapi_ldap_bind",
+                    "Error: could not send startTLS request: "
+                    "error %d (%s) errno %d (%s)\n",
+                    rc, ldap_err2string(rc), errno, slapd_system_strerror(errno));
+            goto done;
+        }
+        slapi_log_error(SLAPI_LOG_SHELL, "slapi_ldap_bind",
+                "startTLS started on connection\n");
     }
 
     /* The connection has been set up - now do the actual bind, depending on
        the mechanism and arguments */
     if (!mech || (mech == LDAP_SASL_SIMPLE) ||
-	!strcmp(mech, LDAP_SASL_EXTERNAL)) {
-	int mymsgid = 0;
+        !strcmp(mech, LDAP_SASL_EXTERNAL)) {
+        int mymsgid = 0;
 
-	slapi_log_error(SLAPI_LOG_SHELL, "slapi_ldap_bind",
-			"attempting %s bind with id [%s] creds [%s]\n",
-			mech ? mech : "SIMPLE",
-			bindid, creds);
-	if ((rc = ldap_sasl_bind(ld, bindid, mech, &bvcreds, serverctrls,
-	                         NULL /* clientctrls */, &mymsgid))) {
-	    char *hostname = NULL;
-	    char *host_port = NULL;
-	    char *ptr = NULL;
-	    int myerrno = errno;
-	    int gaierr = 0;
+        slapi_log_error(SLAPI_LOG_SHELL, "slapi_ldap_bind",
+                "attempting %s bind with id [%s] creds [%s]\n",
+                mech ? mech : "SIMPLE",
+                bindid, creds);
+        if ((rc = ldap_sasl_bind(ld, bindid, mech, &bvcreds, serverctrls,
+                                 NULL /* clientctrls */, &mymsgid))) {
+            char *hostname = NULL;
+            char *host_port = NULL;
+            char *ptr = NULL;
+            int myerrno = errno;
+            int gaierr = 0;
 
-	    ldap_get_option(ld, LDAP_OPT_HOST_NAME, &host_port);
-	    if (host_port) {
-	        ptr = strchr(host_port, ':');
-	        if (ptr) {
-	            hostname = slapi_ch_strdup(host_port);
-	            *(hostname + (ptr - host_port)) = '\0';
-	        }
-	    }
-	    if (0 == myerrno) {
-	        struct addrinfo *result = NULL;
-	        gaierr = getaddrinfo(hostname, NULL, NULL, &result);
-	        myerrno = errno;
-	        if (result) {
-	            freeaddrinfo(result);
-	        }
-	    }
+            ldap_get_option(ld, LDAP_OPT_HOST_NAME, &host_port);
+            if (host_port) {
+                ptr = strchr(host_port, ':');
+                if (ptr) {
+                    hostname = slapi_ch_strdup(host_port);
+                    *(hostname + (ptr - host_port)) = '\0';
+                }
+            }
+            if (0 == myerrno) {
+                struct addrinfo *result = NULL;
+                gaierr = getaddrinfo(hostname, NULL, NULL, &result);
+                myerrno = errno;
+                if (result) {
+                    freeaddrinfo(result);
+                }
+            }
 
-	    slapi_log_error(SLAPI_LOG_FATAL, "slapi_ldap_bind",
-			    "Error: could not send bind request for id "
-			    "[%s] authentication mechanism [%s]: error %d (%s), system error %d (%s), "
-			    "network error %d (%s, host \"%s\")\n",
-			    bindid ? bindid : "(anon)",
-			    mech ? mech : "SIMPLE",
-			    rc, ldap_err2string(rc),
-			    PR_GetError(), slapd_pr_strerror(PR_GetError()),
-			    myerrno ? myerrno : gaierr,
-			    myerrno ? slapd_system_strerror(myerrno) : gai_strerror(gaierr),
-			    host_port ? host_port : "unknown host");
-	    slapi_ch_free_string(&hostname);
-	    slapi_ch_free_string(&host_port);
-	    goto done;
-	}
+            slapi_log_error(SLAPI_LOG_FATAL, "slapi_ldap_bind",
+                    "Error: could not send bind request for id "
+                    "[%s] authentication mechanism [%s]: error %d (%s), system error %d (%s), "
+                    "network error %d (%s, host \"%s\")\n",
+                    bindid ? bindid : "(anon)",
+                    mech ? mech : "SIMPLE",
+                    rc, ldap_err2string(rc),
+                    PR_GetError(), slapd_pr_strerror(PR_GetError()),
+                    myerrno ? myerrno : gaierr,
+                    myerrno ? slapd_system_strerror(myerrno) : gai_strerror(gaierr),
+                    host_port ? host_port : "unknown host");
+            slapi_ch_free_string(&hostname);
+            slapi_ch_free_string(&host_port);
+            goto done;
+        }
 
-	if (msgidp) { /* let caller process result */
-	    *msgidp = mymsgid;
-	} else { /* process results */
+        if (msgidp) { /* let caller process result */
+            *msgidp = mymsgid;
+        } else { /* process results */
             struct timeval default_timeout, *bind_timeout;
             
             if ((timeout == NULL) || ((timeout->tv_sec == 0) && (timeout->tv_usec == 0))) {
@@ -1137,87 +1184,89 @@ slapi_ldap_bind(
                     /* take the one provided by the caller. It should be the one defined in the protocol */
                     bind_timeout = timeout;
             }
-	    rc = ldap_result(ld, mymsgid, LDAP_MSG_ALL, bind_timeout, &result);
-	    if (-1 == rc) { /* error */
-		rc = slapi_ldap_get_lderrno(ld, NULL, NULL);
-		slapi_log_error(SLAPI_LOG_FATAL, "slapi_ldap_bind",
-				"Error reading bind response for id "
-				"[%s] authentication mechanism [%s]: error %d (%s) errno %d (%s)\n",
-				bindid ? bindid : "(anon)",
-				mech ? mech : "SIMPLE",
-				rc, ldap_err2string(rc), errno, slapd_system_strerror(errno));
-		goto done;
-	    } else if (rc == 0) { /* timeout */
-		rc = LDAP_TIMEOUT;
-		slapi_log_error(SLAPI_LOG_FATAL, "slapi_ldap_bind",
-				"Error: timeout after [%ld.%ld] seconds reading "
-				"bind response for [%s] authentication mechanism [%s]\n",
-				bind_timeout->tv_sec, bind_timeout->tv_usec,
-				bindid ? bindid : "(anon)",
-				mech ? mech : "SIMPLE");
-		goto done;
-	    }
-        /* if we got here, we were able to read success result */
-        /* Get the controls sent by the server if requested */
-        if ((rc = ldap_parse_result(ld, result, &err, NULL, NULL,
-                      NULL, returnedctrls, 0)) != LDAP_SUCCESS) {
-            slapi_log_error(SLAPI_LOG_FATAL, "slapi_ldap_bind",
-                "Error: could not parse bind result: error %d (%s) errno %d (%s)\n",
-                rc, ldap_err2string(rc), errno, slapd_system_strerror(errno));
-            goto done;
-        }
+            rc = ldap_result(ld, mymsgid, LDAP_MSG_ALL, bind_timeout, &result);
+            if (-1 == rc) { /* error */
+                rc = slapi_ldap_get_lderrno(ld, NULL, NULL);
+                slapi_log_error(SLAPI_LOG_FATAL, "slapi_ldap_bind",
+                        "Error reading bind response for id "
+                        "[%s] authentication mechanism [%s]: error %d (%s) errno %d (%s)\n",
+                        bindid ? bindid : "(anon)",
+                        mech ? mech : "SIMPLE",
+                        rc, ldap_err2string(rc), errno, slapd_system_strerror(errno));
+                goto done;
+            } else if (rc == 0) { /* timeout */
+                rc = LDAP_TIMEOUT;
+                slapi_log_error(SLAPI_LOG_FATAL, "slapi_ldap_bind",
+                        "Error: timeout after [%ld.%ld] seconds reading "
+                        "bind response for [%s] authentication mechanism [%s]\n",
+                        bind_timeout->tv_sec, bind_timeout->tv_usec,
+                        bindid ? bindid : "(anon)",
+                        mech ? mech : "SIMPLE");
+                goto done;
+            }
+            /*
+             * If we got here, we were able to read success result.
+             * Get the controls sent by the server if requested
+             */
+            if ((rc = ldap_parse_result(ld, result, &err, NULL, NULL,
+                                        NULL, returnedctrls, 0)) != LDAP_SUCCESS) {
+                slapi_log_error(SLAPI_LOG_FATAL, "slapi_ldap_bind",
+                        "Error: could not parse bind result: error %d (%s) errno %d (%s)\n",
+                        rc, ldap_err2string(rc), errno, slapd_system_strerror(errno));
+                goto done;
+            }
 
-        /* check the result code from the bind operation */
-        if(err){
-            rc = err;
-            slapi_log_error(SLAPI_LOG_FATAL, "slapi_ldap_bind",
-                            "Error: could not bind id "
-                            "[%s] authentication mechanism [%s]: error %d (%s) errno %d (%s)\n",
-                            bindid ? bindid : "(anon)",
-                            mech ? mech : "SIMPLE",
-                            rc, ldap_err2string(rc), errno, slapd_system_strerror(errno));
-            goto done;
-        }
+            /* check the result code from the bind operation */
+            if(err){
+                rc = err;
+                slapi_log_error(SLAPI_LOG_FATAL, "slapi_ldap_bind",
+                         "Error: could not bind id "
+                         "[%s] authentication mechanism [%s]: error %d (%s) errno %d (%s)\n",
+                         bindid ? bindid : "(anon)",
+                         mech ? mech : "SIMPLE",
+                         rc, ldap_err2string(rc), errno, slapd_system_strerror(errno));
+                goto done;
+            }
 
-	    /* parse the bind result and get the ldap error code */
-	    if ((rc = ldap_parse_sasl_bind_result(ld, result, &servercredp,
-						  0))) {
-		rc = slapi_ldap_get_lderrno(ld, NULL, NULL);
-		slapi_log_error(SLAPI_LOG_FATAL, "slapi_ldap_bind",
-				"Error: could not read bind results for id "
-				"[%s] authentication mechanism [%s]: error %d (%s) errno %d (%s)\n",
-				bindid ? bindid : "(anon)",
-				mech ? mech : "SIMPLE",
-				rc, ldap_err2string(rc), errno, slapd_system_strerror(errno));
-		goto done;
-	    }
-	}
+            /* parse the bind result and get the ldap error code */
+            if ((rc = ldap_parse_sasl_bind_result(ld, result, &servercredp, 0))) {
+                rc = slapi_ldap_get_lderrno(ld, NULL, NULL);
+                slapi_log_error(SLAPI_LOG_FATAL, "slapi_ldap_bind",
+                        "Error: could not read bind results for id "
+                        "[%s] authentication mechanism [%s]: error %d (%s) errno %d (%s)\n",
+                        bindid ? bindid : "(anon)",
+                        mech ? mech : "SIMPLE",
+                        rc, ldap_err2string(rc), errno, slapd_system_strerror(errno));
+                goto done;
+            }
+        }
     } else {
-	/* a SASL mech - set the sasl ssf to 0 if using TLS/SSL */
-	/* openldap supports tls + sasl security */
+        /*
+         * a SASL mech - set the sasl ssf to 0 if using TLS/SSL.
+         * openldap supports tls + sasl security
+         */
 #if !defined(USE_OPENLDAP)
-	if (secure) {
-	    sasl_ssf_t max_ssf = 0;
-	    ldap_set_option(ld, LDAP_OPT_X_SASL_SSF_MAX, &max_ssf);
-	}
-#endif
-	rc = slapd_ldap_sasl_interactive_bind(ld, bindid, creds, mech,
-					      serverctrls, returnedctrls,
-					      msgidp);
-	if (LDAP_SUCCESS != rc) {
-	    slapi_log_error(SLAPI_LOG_FATAL, "slapi_ldap_bind",
-			    "Error: could not perform interactive bind for id "
-			    "[%s] authentication mechanism [%s]: error %d (%s)\n",
-			    bindid ? bindid : "(anon)",
-			    mech, /* mech cannot be SIMPLE here */
-			    rc, ldap_err2string(rc));
-#ifdef HAVE_KRB5
-        if(mech && !strcmp(mech, "GSSAPI") && rc == 49){
-            /* only on err 49 should we clear out the credential cache */
-            clear_krb5_ccache();
+        if (secure) {
+            sasl_ssf_t max_ssf = 0;
+            ldap_set_option(ld, LDAP_OPT_X_SASL_SSF_MAX, &max_ssf);
         }
 #endif
-	}
+        rc = slapd_ldap_sasl_interactive_bind(ld, bindid, creds, mech,
+                 serverctrls, returnedctrls, msgidp);
+        if (LDAP_SUCCESS != rc) {
+            slapi_log_error(SLAPI_LOG_CONNS, "slapi_ldap_bind",
+                "Error: could not perform interactive bind for id "
+                "[%s] authentication mechanism [%s]: error %d (%s)\n",
+                bindid ? bindid : "(anon)",
+                mech, /* mech cannot be SIMPLE here */
+                rc, ldap_err2string(rc));
+#ifdef HAVE_KRB5
+            if(mech && !strcmp(mech, "GSSAPI") && rc == 49){
+                /* only on err 49 should we clear out the credential cache */
+                clear_krb5_ccache();
+            }
+#endif
+        }
     }
 
 done:
@@ -1365,7 +1414,7 @@ ldap_sasl_set_interact_vals(LDAP *ld, const char *mech, const char *authid,
     } else { /* use option value if any */
         ldap_get_option(ld, LDAP_OPT_X_SASL_AUTHCID, &vals->authid);
         if (!vals->authid) {
-/* get server user id? */
+            /* get server user id? */
             vals->authid = slapi_ch_strdup("");
         }
     }
@@ -1532,7 +1581,7 @@ slapd_ldap_sasl_interactive_bind(
         if (LDAP_SUCCESS != rc) {
             char *errmsg = NULL;
             rc = slapi_ldap_get_lderrno(ld, NULL, &errmsg);
-            slapi_log_error(SLAPI_LOG_FATAL, "slapd_ldap_sasl_interactive_bind",
+            slapi_log_error(SLAPI_LOG_CONNS, "slapd_ldap_sasl_interactive_bind",
                             "Error: could not perform interactive bind for id "
                             "[%s] mech [%s]: LDAP error %d (%s) (%s) "
                             "errno %d (%s)\n",
@@ -2223,11 +2272,13 @@ mozldap_ldap_explode( const char *dn, const int notypes, const int nametype )
 					return NULL;
 				}
 				if ( (*p == ',' || *p == ';') && !goteq ) {
-                                   /* If we get here, we have a case similar
-				    * to <attr>=<value>,<string>,<attr>=<value>
-				    * This is not a valid dn */
-				    charray_free( rdns );
-				    return NULL;
+					/*
+					 * If we get here, we have a case similar
+					 * to <attr>=<value>,<string>,<attr>=<value>
+					 * This is not a valid dn .
+					 */
+					charray_free( rdns );
+					return NULL;
 				}
 				goteq = 0;
 				++count;
@@ -2367,3 +2418,47 @@ slapi_berval_get_msg_len(struct berval *bv, int strict)
 
     return len;
 }
+
+int
+slapi_client_uses_non_nss(LDAP *ld)
+{
+    static int not_nss = 0;
+#if defined(USE_OPENLDAP)
+    static int initialized = 0;
+    char *package_name = NULL;
+    int rc;
+
+    if (initialized) {
+        return not_nss;
+    }
+    rc = ldap_get_option(ld, LDAP_OPT_X_TLS_PACKAGE, &package_name);
+    if (!rc && PL_strcasecmp(package_name, "MozNSS")) {
+        not_nss = 1;
+        slapi_ch_free_string(&package_name);
+    }
+    initialized = 1;
+#endif
+    return not_nss;
+}
+
+int
+slapi_client_uses_openssl(LDAP *ld)
+{
+    static int is_openssl = 0;
+#if defined(USE_OPENLDAP)
+    static int initialized = 0;
+    char *package_name = NULL;
+    int rc;
+
+    if (initialized) {
+        return is_openssl;
+    }
+    rc = ldap_get_option(ld, LDAP_OPT_X_TLS_PACKAGE, &package_name);
+    if (!rc && !PL_strcasecmp(package_name, "OpenSSL")) {
+        is_openssl = 1;
+        slapi_ch_free_string(&package_name);
+    }
+    initialized = 1;
+#endif
+    return is_openssl;
+}
