@@ -395,7 +395,7 @@ op_shared_rename(Slapi_PBlock *pb, int passin_args)
 	int				internal_op, repl_op, lastmod;
 	Slapi_Operation *operation;
 	Slapi_Entry *referral;
-	char errorbuf[BUFSIZ];
+	char errorbuf[SLAPI_DSE_RETURNTEXT_SIZE];
 	int			err;
 	char			*proxydn = NULL;
 	char			*proxystr = NULL;
@@ -571,7 +571,8 @@ op_shared_rename(Slapi_PBlock *pb, int passin_args)
 	 */
 	/* slapi_mapping_tree_select_and_check ignores the case of newdn
 	 * which is generated using newrdn above. */
-	if ((err = slapi_mapping_tree_select_and_check(pb, newdn, &be, &referral, errorbuf)) != LDAP_SUCCESS)
+	errorbuf[0] = '\0';
+	if ((err = slapi_mapping_tree_select_and_check(pb, newdn, &be, &referral, errorbuf, sizeof(errorbuf))) != LDAP_SUCCESS)
 	{
 		send_ldap_result(pb, err, NULL, errorbuf, 0, NULL);
 		goto free_and_return_nolock;
@@ -641,6 +642,12 @@ op_shared_rename(Slapi_PBlock *pb, int passin_args)
 				slapi_pblock_get(pb, SLAPI_ENTRY_PRE_OP, &ecopy);
 				/* GGOODREPL persistent search system needs the changenumber, oops. */
 				do_ps_service(pse, ecopy, LDAP_CHANGETYPE_MODDN, 0);
+			} else {
+				/* Should we also be doing a disk space check here? */
+				if (operation_is_flag_set(operation,OP_FLAG_ACTION_LOG_AUDIT))
+				{ 
+					write_auditfail_log_entry(pb); /* Record the operation in the audit log */
+				}
 			}
 		}
 		else
