@@ -225,7 +225,6 @@ op_shared_search (Slapi_PBlock *pb, int send_result)
   char            *proxystr = NULL;
   int             proxy_err = LDAP_SUCCESS;
   char            *errtext = NULL;
-  char            errorbuf[BUFSIZ];
   int             nentries,pnentries;
   int             flag_search_base_found = 0;
   int             flag_no_such_object = 0;
@@ -434,9 +433,11 @@ op_shared_search (Slapi_PBlock *pb, int send_result)
   }
 
   if (be_name == NULL) {
+      char errorbuf[SLAPI_DSE_RETURNTEXT_SIZE];
       /* no specific backend was requested, use the mapping tree
        */
-      err_code = slapi_mapping_tree_select_all(pb, be_list, referral_list, errorbuf);
+      errorbuf[0] = '\0';
+      err_code = slapi_mapping_tree_select_all(pb, be_list, referral_list, errorbuf, sizeof(errorbuf));
       if (((err_code != LDAP_SUCCESS) && (err_code != LDAP_OPERATIONS_ERROR) && (err_code != LDAP_REFERRAL))
           || ((err_code == LDAP_OPERATIONS_ERROR) && (be_list[0] == NULL))) {
           send_ldap_result(pb, err_code, NULL, errorbuf, 0, NULL);
@@ -1458,9 +1459,13 @@ iterate(Slapi_PBlock *pb, Slapi_Backend *be, int send_result,
                 done = 1;
                 continue;
             }
+            /* Adding shadow password attrs. */
+            add_shadow_ext_password_attrs(pb, &e);
             if (process_entry(pb, e, send_result)) 
             {
                 /* shouldn't  send this entry */
+                slapi_entry_free(pb->pb_pw_entry);
+                pb->pb_pw_entry = NULL;
                 continue;
             }
 
@@ -1486,6 +1491,8 @@ iterate(Slapi_PBlock *pb, Slapi_Backend *be, int send_result,
                     pb->pb_op->o_status = SLAPI_OP_STATUS_ABANDONED;
                     break;
             }
+            slapi_entry_free(pb->pb_pw_entry);
+            pb->pb_pw_entry = NULL;
             if (pagesize == *pnentries)
             { 
                 /* PAGED RESULTS: reached the pagesize */
