@@ -38,8 +38,8 @@ void do_add( Slapi_PBlock *pb );
 void attr_done(Slapi_Attr *a);
 int attr_add_valuearray(Slapi_Attr *a, Slapi_Value **vals, const char *dn);
 int attr_replace(Slapi_Attr *a, Slapi_Value **vals);
-int attr_check_onoff ( const char *attr_name, char *value, long minval, long maxval, char *errorbuf );
-int attr_check_minmax ( const char *attr_name, char *value, long minval, long maxval, char *errorbuf );
+int attr_check_onoff(const char *attr_name, char *value, long minval, long maxval, char *errorbuf, size_t ebuflen);
+int attr_check_minmax(const char *attr_name, char *value, long minval, long maxval, char *errorbuf, size_t ebuflen);
 /**
  * Returns the function which can be used to compare (like memcmp/strcmp)
  * two values of this type of attribute.  The comparison function will use
@@ -293,6 +293,7 @@ int config_set_timelimit(const char *attrname, char *value, char *errorbuf, int
 int config_set_errorlog_level(const char *attrname,  char *value, char *errorbuf, int apply );
 int config_set_accesslog_level(const char *attrname,  char *value, char *errorbuf, int apply );
 int config_set_auditlog(const char *attrname,  char *value, char *errorbuf, int apply );
+int config_set_auditfaillog(const char *attrname,  char *value, char *errorbuf, int apply );
 int config_set_userat(const char *attrname,  char *value, char *errorbuf, int apply );
 int config_set_accesslog(const char *attrname,  char *value, char *errorbuf, int apply );
 int config_set_errorlog(const char *attrname, char *value, char *errorbuf, int apply );
@@ -300,6 +301,7 @@ int config_set_pw_change(const char *attrname,  char *value, char *errorbuf, int
 int config_set_pw_must_change(const char *attrname,  char *value, char *errorbuf, int apply );
 int config_set_pwpolicy_local(const char *attrname,  char *value, char *errorbuf, int apply );
 int config_set_allow_hashed_pw( const char *attrname, char *value, char *errorbuf, int apply );
+int config_set_pwpolicy_inherit_global(const char *attrname,  char *value, char *errorbuf, int apply );
 int config_set_pw_syntax(const char *attrname,  char *value, char *errorbuf, int apply );
 int config_set_pw_minlength(const char *attrname,  char *value, char *errorbuf, int apply );
 int config_set_pw_mindigits(const char *attrname,  char *value, char *errorbuf, int apply );
@@ -373,6 +375,7 @@ int config_set_disk_threshold( const char *attrname, char *value, char *errorbuf
 int config_set_disk_grace_period( const char *attrname, char *value, char *errorbuf, int apply );
 int config_set_disk_logging_critical( const char *attrname, char *value, char *errorbuf, int apply );
 int config_set_auditlog_unhashed_pw(const char *attrname, char *value, char *errorbuf, int apply);
+int config_set_auditfaillog_unhashed_pw(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_ndn_cache_enabled(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_ndn_cache_max_size(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_unhashed_pw_switch(const char *attrname, char *value, char *errorbuf, int apply); 
@@ -396,6 +399,14 @@ int config_set_mempool_maxfreelist( const char *attrname, char *value, char *err
 
 int config_set_maxsimplepaged_per_conn( const char *attrname, char *value, char *errorbuf, int apply );
 
+int log_set_backend(const char *attrname, char *value, int logtype, char *errorbuf, int apply);
+
+#ifdef HAVE_CLOCK_GETTIME
+int config_set_logging_hr_timestamps(const char *attrname, char *value, char *errorbuf, int apply);
+void log_enable_hr_timestamps();
+void log_disable_hr_timestamps();
+#endif
+
 int config_get_SSLclientAuth();
 int config_get_ssl_check_hostname();
 char *config_get_SSL3ciphers();
@@ -442,6 +453,7 @@ int config_get_pw_exp();
 int config_get_pw_unlock();
 int config_get_pw_lockout();
 int config_get_pw_gracelimit();
+int config_get_pwpolicy_inherit_global();
 int config_get_lastmod();
 int config_get_nagle();
 int config_get_accesscontrol();
@@ -477,12 +489,14 @@ char* config_get_useroc();
 char *config_get_accesslog();
 char *config_get_errorlog();
 char *config_get_auditlog();
-long config_get_pw_maxage();
-long config_get_pw_minage();
-long config_get_pw_warning();
+char *config_get_auditfaillog();
+long long config_get_pw_maxage();
+long long config_get_pw_minage();
+long long config_get_pw_warning();
 int config_get_errorlog_level();
 int config_get_accesslog_level();
 int config_get_auditlog_logging_enabled();
+int config_get_auditfaillog_logging_enabled();
 char *config_get_referral_mode(void);
 int config_get_conntablesize(void);
 int config_check_referral_mode(void);
@@ -504,6 +518,7 @@ char *config_get_saslpath();
 char **config_get_errorlog_list();
 char **config_get_accesslog_list();
 char **config_get_auditlog_list();
+char **config_get_auditfaillog_list();
 int config_get_attrname_exceptions();
 int config_get_hash_filters();
 int config_get_rewrite_rfc1274();
@@ -530,6 +545,7 @@ char *config_get_default_naming_context(void);
 int config_allowed_to_delete_attrs(const char *attr_type);
 void config_set_accesslog_enabled(int value);
 void config_set_auditlog_enabled(int value);
+void config_set_auditfaillog_enabled(int value);
 int config_get_accesslog_logging_enabled();
 int config_get_disk_monitoring();
 PRInt64 config_get_disk_threshold();
@@ -565,6 +581,7 @@ int config_get_cn_uses_dn_syntax_in_dns();
 int config_get_enable_nunc_stans(void);
 int config_set_enable_nunc_stans(const char *attrname, char *value, char *errorbuf, int apply);
 #endif
+int config_set_extract_pem(const char *attrname, char *value, char *errorbuf, int apply);
 
 PLHashNumber hashNocaseString(const void *key);
 PRIntn hashNocaseCompare(const void *v1, const void *v2);
@@ -578,6 +595,7 @@ int config_get_malloc_mmap_threshold();
 #endif
 
 int config_get_maxsimplepaged_per_conn();
+int config_get_extract_pem();
 
 int is_abspath(const char *);
 char* rel2abspath( char * );
@@ -640,6 +658,11 @@ void *sym_load( char *libpath, char *symbol, char *plugin, int report_errors );
  */
 void *sym_load_with_flags( char *libpath, char *symbol, char *plugin, int report_errors, PRBool load_now, PRBool load_global );
 
+/*
+ * features.c
+ */
+
+void init_features( void );
 
 /*
  * filter.c
@@ -743,19 +766,24 @@ int slapi_log_access( int level, char *fmt, ... )
 #else
         ;
 #endif
-int slapd_log_audit_proc(char *buffer, int buf_len);
+int slapd_log_audit(char *buffer, int buf_len, int sourcelog);
+int slapd_log_audit_internal(char *buffer, int buf_len, int state);
+int slapd_log_auditfail(char *buffer, int buf_len);
+int slapd_log_auditfail_internal(char *buffer, int buf_len);
 void log_access_flush();
 
 
 int access_log_openf( char *pathname, int locked);
 int error_log_openf( char *pathname, int locked);
 int audit_log_openf( char *pathname, int locked);
+int auditfail_log_openf( char *pathname, int locked);
 
 void g_set_detached(int);
 void g_log_init(int log_enabled);
 char *g_get_access_log();
 char *g_get_error_log();
 char *g_get_audit_log();
+char *g_get_auditfail_log();
 void g_set_accesslog_level(int val);
 
 int log_set_mode(const char *attrname, char *mode_str, int logtype, char *errorbuf, int apply);
@@ -774,6 +802,7 @@ char **log_get_loglist(int logtype);
 int  log_update_accesslogdir(char *pathname, int apply);
 int  log_update_errorlogdir(char *pathname, int apply);
 int  log_update_auditlogdir(char *pathname, int apply);
+int  log_update_auditfaillogdir(char *pathname, int apply);
 int  log_set_logging (const char *attrname, char *value, int logtype, char *errorbuf, int apply);
 int check_log_max_size(
                     char *maxdiskspace_str,
@@ -850,9 +879,12 @@ void global_plugin_init();
 int plugin_call_plugins( Slapi_PBlock *, int );
 int plugin_setup(Slapi_Entry *plugin_entry, struct slapi_componentid *group,
 	slapi_plugin_init_fnptr initfunc, int add_to_dit, char *returntext);
-int plugin_call_exop_plugins( Slapi_PBlock *pb, char *oid );
+int plugin_determine_exop_plugins( const char *oid, struct slapdplugin **plugin );
+int plugin_call_exop_plugins( Slapi_PBlock *pb, struct slapdplugin *p );
+Slapi_Backend * plugin_extended_op_getbackend( Slapi_PBlock *pb, struct slapdplugin *p);
 const char *plugin_extended_op_oid2string( const char *oid );
 void plugin_closeall(int close_backends, int close_globals);
+void plugin_dependency_freeall();
 void plugin_startall(int argc, char **argv, char **plugin_list);
 void plugin_get_plugin_dependencies(char *plugin_name, char ***names);
 struct slapdplugin *get_plugin_list(int plugin_list_index);
@@ -919,9 +951,8 @@ void get_old_pw( Slapi_PBlock *pb, const Slapi_DN *sdn, char **old_pw);
 int check_account_lock( Slapi_PBlock *pb, Slapi_Entry * bind_target_entry, int pwresponse_req, int account_inactivation_only /*no wire/no pw policy*/);
 int check_pw_minage( Slapi_PBlock *pb, const Slapi_DN *sdn, struct berval **vals) ;
 void add_password_attrs( Slapi_PBlock *pb, Operation *op, Slapi_Entry *e );
-void mod_allowchange_aci(char *val);
-void pw_mod_allowchange_aci(int pw_prohibit_change);
-void pw_add_allowchange_aci(Slapi_Entry *e, int pw_prohibit_change);
+
+int add_shadow_ext_password_attrs(Slapi_PBlock *pb, Slapi_Entry **e);
 
 /*
  * pw_retry.c
@@ -1129,6 +1160,8 @@ void free_timestring(char *timestr);
 time_t current_time();
 time_t poll_current_time();
 char* format_localTime (time_t from);
+int format_localTime_log(time_t t, int initsize, char *buf, int *bufsize);
+int format_localTime_hr_log(time_t t, long nsec, int initsize, char *buf, int *bufsize);
 time_t parse_localTime (char* from);
 
 #ifndef HAVE_TIME_R
@@ -1249,6 +1282,10 @@ void write_audit_log_entry( Slapi_PBlock *pb);
 void auditlog_hide_unhashed_pw();
 void auditlog_expose_unhashed_pw();
 
+void write_auditfail_log_entry( Slapi_PBlock *pb);
+void auditfaillog_hide_unhashed_pw();
+void auditfaillog_expose_unhashed_pw();
+
 /*
  * eventq.c
  */
