@@ -239,7 +239,7 @@ int send_ldap_intermediate( Slapi_PBlock *pb,  LDAPControl **ectrls,
 		rc = ber_put_seq( ber );
 	}
 	if ( rc == LBER_ERROR ) {
-		LDAPDebug( LDAP_DEBUG_ANY, "ber_printf failed\n", 0, 0, 0 );
+		LDAPDebug( LDAP_DEBUG_ANY, "ber_printf failed 0\n", 0, 0, 0 );
 		ber_free( ber, 1 /* freebuf */ );
 		goto log_and_return;
 	}
@@ -255,17 +255,19 @@ log_and_return:
 	 * set o_status
 	 */
 
+	if (rc == LBER_ERROR) {
+		rc = LDAP_OPERATIONS_ERROR;
+	} else {
+		rc = LDAP_SUCCESS;
+	}
+
 	if ( logit && operation_is_flag_set( operation,
 	    OP_FLAG_ACTION_LOG_ACCESS )) {
 		log_result( pb, operation, rc, tag, 0 );
 	}
 
 	LDAPDebug( LDAP_DEBUG_TRACE, "<= send_ldap_intermediate\n", 0, 0, 0 );
-	if (rc == LBER_ERROR) {
-		return(1);
-	} else {
-		return(0);
-	}
+	return rc;
 }
 
 static int
@@ -596,7 +598,7 @@ send_ldap_result_ext(
 	}
 
 	if ( rc == LBER_ERROR ) {
-		LDAPDebug( LDAP_DEBUG_ANY, "ber_printf failed\n", 0, 0, 0 );
+		LDAPDebug( LDAP_DEBUG_ANY, "ber_printf failed 1\n", 0, 0, 0 );
                 if (flush_ber_element == 1) {
                     /* we alloced the ber */
                     ber_free( ber, 1 /* freebuf */ );
@@ -858,13 +860,13 @@ send_ldapv3_referral(
 		rc = ber_printf( ber, "s", urls[i]->bv_val );
 	}
 	if ( rc == LBER_ERROR ) {
-		LDAPDebug( LDAP_DEBUG_ANY, "ber_printf failed\n", 0, 0, 0 );
+		LDAPDebug( LDAP_DEBUG_ANY, "ber_printf failed 2\n", 0, 0, 0 );
 		send_ldap_result( pb, LDAP_OPERATIONS_ERROR, NULL,
 		    "ber_printf", 0, NULL );
 		return( -1 );
 	}
 	if ( ber_printf( ber, "}}" ) == LBER_ERROR ) {
-		LDAPDebug( LDAP_DEBUG_ANY, "ber_printf failed\n", 0, 0, 0 );
+		LDAPDebug( LDAP_DEBUG_ANY, "ber_printf failed 3\n", 0, 0, 0 );
 		send_ldap_result( pb, LDAP_OPERATIONS_ERROR, NULL,
 		    "ber_printf", 0, NULL );
 		return( -1 );
@@ -981,7 +983,7 @@ encode_attr_2(
 #endif
 
 	if (ber_printf(ber, "{s[", returned_type?returned_type:attribute_type) == -1) {
-		LDAPDebug( LDAP_DEBUG_ANY, "ber_printf failed\n", 0, 0, 0 );
+		LDAPDebug( LDAP_DEBUG_ANY, "ber_printf failed 4\n", 0, 0, 0 );
 		ber_free( ber, 1 );
 		send_ldap_result(pb, LDAP_OPERATIONS_ERROR, NULL,
 		                 "ber_printf type", 0, NULL);
@@ -995,7 +997,7 @@ encode_attr_2(
 			if ( ber_printf( ber, "o", v->bv.bv_val,v->bv.bv_len ) == -1 )
 			{
 				LDAPDebug( LDAP_DEBUG_ANY,
-				    "ber_printf failed\n", 0, 0, 0 );
+				    "ber_printf failed 5\n", 0, 0, 0 );
 				ber_free( ber, 1 );
 				send_ldap_result( pb, LDAP_OPERATIONS_ERROR,
 				    NULL, "ber_printf value", 0, NULL );
@@ -1006,7 +1008,7 @@ encode_attr_2(
 	}
 
 	if ( ber_printf( ber, "]}" ) == -1 ) {
-		LDAPDebug( LDAP_DEBUG_ANY, "ber_printf failed\n", 0, 0, 0 );
+		LDAPDebug( LDAP_DEBUG_ANY, "ber_printf failed 6\n", 0, 0, 0 );
 		ber_free( ber, 1 );
 		send_ldap_result( pb, LDAP_OPERATIONS_ERROR, NULL,
 		    "ber_printf type end", 0, NULL );
@@ -1120,7 +1122,7 @@ static const char *idds_map_attrt_v3(
 
 /* Helper functions */
 
-static int send_all_attrs(Slapi_Entry *e,char **attrs,Slapi_Operation *op,Slapi_PBlock *pb,BerElement *ber,int attrsonly,int ldapversion, int real_attrs_only, int some_named_attrs)
+static int send_all_attrs(Slapi_Entry *e,char **attrs,Slapi_Operation *op,Slapi_PBlock *pb,BerElement *ber,int attrsonly,int ldapversion, int real_attrs_only, int some_named_attrs, int alloperationalattrs, int alluserattrs )
 {
 	int i = 0;
 	int rc = 0;
@@ -1143,7 +1145,7 @@ static int send_all_attrs(Slapi_Entry *e,char **attrs,Slapi_Operation *op,Slapi_
 			vattr_flags |= SLAPI_VIRTUALATTRS_ONLY;
 	}
 
-	if (some_named_attrs) {
+	if (some_named_attrs || alloperationalattrs) {
 		/*
 		 * If the client listed some attribute types by name, one or
 		 * more of the requested types MAY be operational.  Inform the
@@ -1190,11 +1192,11 @@ static int send_all_attrs(Slapi_Entry *e,char **attrs,Slapi_Operation *op,Slapi_
 
 		name_to_return = current_type_name;
 		/* We only return operational attributes if the client is LDAPv2 and the attribute is one of a special set,
-		   OR if the client also requested the attribute by name. If it did, we use the specified name rather than
-		   the base name.
+		   OR if all operational attrs are requested, OR if the client also requested the attribute by name.
+		   If it did, we use the specified name rather than the base name.
 		 */
 		if ( current_type_flags & SLAPI_ATTR_FLAG_OPATTR ) {
-			if ( LDAP_VERSION2 == ldapversion && LASTMODATTR( current_type_name) ) {
+			if ( (LDAP_VERSION2 == ldapversion && LASTMODATTR( current_type_name)) || alloperationalattrs ) {
 				sendit = 1;
 			} else {
 				for ( i = 0; attrs != NULL && attrs[i] != NULL; i++ ) {
@@ -1216,7 +1218,7 @@ static int send_all_attrs(Slapi_Entry *e,char **attrs,Slapi_Operation *op,Slapi_
 		/*
 		 * it's a user attribute. send it.
 		 */
-		} else {
+		} else if ( alluserattrs ) {
 			sendit = 1;
 		}
 		/* Now send to the client */
@@ -1475,7 +1477,10 @@ send_ldap_search_entry_ext(
 	Operation	*op = pb->pb_op;
 	BerElement	*ber = NULL;
 	int		i, rc = 0, logit = 0;
-	int		alluserattrs, noattrs, some_named_attrs;
+	int		alluserattrs;
+	int 	noattrs;
+	int 	some_named_attrs;
+	int 	alloperationalattrs;
 	Slapi_Operation *operation;
 	int real_attrs_only = 0;
 	LDAPControl		**ctrlp = 0;
@@ -1550,7 +1555,7 @@ send_ldap_search_entry_ext(
 	    LDAP_RES_SEARCH_ENTRY, slapi_entry_get_dn_const(e) );
 
 	if ( rc == -1 ) {
-		LDAPDebug( LDAP_DEBUG_ANY, "ber_printf failed\n", 0, 0, 0 );
+		LDAPDebug( LDAP_DEBUG_ANY, "ber_printf failed 7\n", 0, 0, 0 );
 		send_ldap_result( pb, LDAP_OPERATIONS_ERROR, NULL,
 		    "ber_printf dn", 0, NULL );
 		goto cleanup;
@@ -1558,15 +1563,17 @@ send_ldap_search_entry_ext(
 
 	/*
 	 * in ldapv3, the special attribute "*" means all user attributes,
-	 * NULL means all user attributes, and "1.1" means no attributes.
+	 * NULL means all user attributes, "1.1" means no attributes, and
+	 * "+" means all operational attributes (rfc3673)
 	 * operational attributes are only retrieved if they are named
-	 * specifically.
+	 * specifically or when "+" is specified.
 	 */
 
 	/* figure out if we want all user attributes or no attributes at all */
 	alluserattrs = 0;
 	noattrs = 0;
 	some_named_attrs = 0;
+	alloperationalattrs = 0;
 	if ( attrs == NULL ) {
 		alluserattrs = 1;
 	} else {
@@ -1575,6 +1582,8 @@ send_ldap_search_entry_ext(
 				alluserattrs = 1;
 			} else if ( strcmp( LDAP_NO_ATTRS, attrs[i] ) == 0 ) {
 				noattrs = 1;
+			} else if ( strcmp( LDAP_ALL_OPERATIONAL_ATTRS, attrs[i] ) == 0 ) {
+				alloperationalattrs = 1;
 			} else {
 				some_named_attrs = 1;
 			}
@@ -1612,9 +1621,9 @@ send_ldap_search_entry_ext(
 	}
 
 	/* look through each attribute in the entry */
-	if ( alluserattrs ) {
+	if ( alluserattrs || alloperationalattrs ) {
 		rc = send_all_attrs(e, attrs, op, pb, ber, attrsonly, conn->c_ldapversion,
-		                    real_attrs_only, some_named_attrs);
+		                    real_attrs_only, some_named_attrs, alloperationalattrs, alluserattrs);
 	}
 	
 	/* if the client explicitly specified a list of attributes look through each attribute requested */
@@ -1664,7 +1673,7 @@ send_ldap_search_entry_ext(
 	}
 
 	if ( rc == -1 ) {
-		LDAPDebug( LDAP_DEBUG_ANY, "ber_printf failed\n", 0, 0, 0 );
+		LDAPDebug( LDAP_DEBUG_ANY, "ber_printf failed 8\n", 0, 0, 0 );
 		send_ldap_result( pb, LDAP_OPERATIONS_ERROR, NULL,
 		    "ber_printf entry end", 0, NULL );
 		goto cleanup;
@@ -2228,7 +2237,7 @@ encode_read_entry (Slapi_PBlock *pb, Slapi_Entry *e, char **attrs, int alluserat
     /* Send all the attributes */
     if ( alluserattrs ) {
         rc = send_all_attrs(e, attrs, op, pb, ber, 0, conn->c_ldapversion,
-                            real_attrs_only, attr_count);
+                            real_attrs_only, attr_count, 0, 1);
         if(rc){
             goto cleanup;
         }
