@@ -1,41 +1,12 @@
 #ident "ldclt @(#)scalab01.c	1.8 01/05/03"
 
 /** BEGIN COPYRIGHT BLOCK
- * This Program is free software; you can redistribute it and/or modify it under
- * the terms of the GNU General Public License as published by the Free Software
- * Foundation; version 2 of the License.
- * 
- * This Program is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
- * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License along with
- * this Program; if not, write to the Free Software Foundation, Inc., 59 Temple
- * Place, Suite 330, Boston, MA 02111-1307 USA.
- * 
- * In addition, as a special exception, Red Hat, Inc. gives You the additional
- * right to link the code of this Program with code not covered under the GNU
- * General Public License ("Non-GPL Code") and to distribute linked combinations
- * including the two, subject to the limitations in this paragraph. Non-GPL Code
- * permitted under this exception must only link to the code of this Program
- * through those well defined interfaces identified in the file named EXCEPTION
- * found in the source code files (the "Approved Interfaces"). The files of
- * Non-GPL Code may instantiate templates or use macros or inline functions from
- * the Approved Interfaces without causing the resulting work to be covered by
- * the GNU General Public License. Only Red Hat, Inc. may make changes or
- * additions to the list of Approved Interfaces. You must obey the GNU General
- * Public License in all respects for all of the Program code and other code used
- * in conjunction with the Program except the Non-GPL Code covered by this
- * exception. If you modify this file, you may extend this exception to your
- * version of the file, but you are not obligated to do so. If you do not wish to
- * provide this exception without modification, you must delete this exception
- * statement from your version and license this file solely under the GPL without
- * exception. 
- * 
- * 
  * Copyright (C) 2001 Sun Microsystems, Inc. Used by permission.
  * Copyright (C) 2006 Red Hat, Inc.
  * All rights reserved.
+ *
+ * License: GPL (version 3 or any later version).
+ * See LICENSE for details. 
  * END COPYRIGHT BLOCK **/
 
 #ifdef HAVE_CONFIG_H
@@ -85,9 +56,7 @@ dd/mm/yy | Author	| Comments
 #include <stdlib.h>	/* malloc(), etc... */
 #include <string.h>	/* strcpy(), etc... */
 #include <errno.h>	/* perror(), etc... */
-#ifndef _WIN32
 #include <pthread.h>	/* pthreads(), etc... */
-#endif
 
 #include <lber.h>	/* ldap C-API BER declarations */
 #include <ldap.h>	/* ldap C-API declarations */
@@ -101,18 +70,12 @@ dd/mm/yy | Author	| Comments
 #include "scalab01.h"	/* Scalab01 specific definitions */
 
 
-
-
-
 /*
  * Private data structures.
  */
 scalab01_context	 s1ctx;
 
 
-
-
-
 /* ****************************************************************************
 	FUNCTION :	scalab01_init
 	PURPOSE :	Initiates the scalab01 scenario.
@@ -162,11 +125,6 @@ scalab01_init (void)
 }
 
 
-
-
-
-
-
 /* ****************************************************************************
 	FUNCTION :	scalab01Lock
 	PURPOSE :	Lock for single user trying to connect.
@@ -234,12 +192,6 @@ scalab01Lock (
 }
 
 
-
-
-
-
-
-
 /* ****************************************************************************
 	FUNCTION :	scalab01Unlock
 	PURPOSE :	Unlock for single user trying to connect.
@@ -292,13 +244,6 @@ scalab01Unlock (
 }
 
 
-
-
-
-
-
-
-
 /* ****************************************************************************
 	FUNCTION :	scalab01_modemIncr
 	PURPOSE :	Increments the modem nb of cnx
@@ -392,11 +337,6 @@ scalab01_modemDecr (
 }
 
 
-
-
-
-
-
 /* ****************************************************************************
 	FUNCTION :	scalab01_addLogin
 	PURPOSE :	Add a new user login to the s1ctx structure.
@@ -515,13 +455,6 @@ done:
 }
 
 
-
-
-
-
-
-
-
 /* ****************************************************************************
 	FUNCTION :	scalab01_connectSuperuser
 	PURPOSE :	Purpose of the fct
@@ -559,12 +492,6 @@ scalab01_connectSuperuser (void)
 }
 
 
-
-
-
-
-
-
 /* ****************************************************************************
 	FUNCTION :	readAttrValue
 	PURPOSE :	This function will ldap_search the given entry for the
@@ -671,11 +598,6 @@ readAttrValue (
 }
 
 
-
-
-
-
-
 /* ****************************************************************************
 	FUNCTION :	writeAttrValue
 	PURPOSE :	This function will ldap_modify the given entry to
@@ -729,11 +651,6 @@ writeAttrValue (
 }
 
 
-
-
-
-
-
 /* ****************************************************************************
 	FUNCTION :	scalab01_unlock
 	PURPOSE :	Unlock the user given in argument.
@@ -814,12 +731,6 @@ scalab01_unlock (
 }
 
 
-
-
-
-
-
-
 /* ****************************************************************************
 	FUNCTION :	scalab01_control
 	PURPOSE :	This function implements the control loop/thread of
@@ -948,11 +859,6 @@ scalab01_control (
 }
 
 
-
-
-
-
-
 /* ****************************************************************************
 	FUNCTION :	doScalab01
 	PURPOSE :	Implements the client part of the scalab01 scenario.
@@ -1105,10 +1011,3 @@ TBC - this is done in the next loop... - cf connectToServer()
 
   return (0);
 }
-
-
-
-
-
-
-/* End of file */
